#pragma once
#include <unordered_map>
#include <string>
#include <ATen/ATen.h>
#include <caffe2/core/context.h>
#include <caffe2/core/operator.h>
#include <caffe2/utils/math.h>
#include <iostream>

// a map from descriptor strings (see [DESCRIPTORS])
// to the key in the switch statement that implements them
static std::unordered_map<std::string, int> op_to_key = {
  { "_cast_Byte-non_blocking-1", 0 },
  { "_cast_Byte-1", 1 },
  { "_cast_Char-non_blocking-1", 2 },
  { "_cast_Char-1", 3 },
  { "_cast_Double-non_blocking-1", 4 },
  { "_cast_Double-1", 5 },
  { "_cast_Float-non_blocking-1", 6 },
  { "_cast_Float-1", 7 },
  { "_cast_Int-non_blocking-1", 8 },
  { "_cast_Int-1", 9 },
  { "_cast_Long-non_blocking-1", 10 },
  { "_cast_Long-1", 11 },
  { "_cast_Short-non_blocking-1", 12 },
  { "_cast_Short-1", 13 },
  { "_cast_Half-non_blocking-1", 14 },
  { "_cast_Half-1", 15 },
  { "data-1", 16 },
  { "is_leaf-1", 17 },
  { "output_nr-1", 18 },
  { "_version-1", 19 },
  { "align_as-2", 20 },
  { "align_tensors-*", 21 },
  { "_use_cudnn_ctc_loss-blank-input_lengths-target_lengths-2", 22 },
  { "_cudnn_ctc_loss-blank-deterministic-input_lengths-target_lengths-zero_infinity-2", 23 },
  { "_use_cudnn_rnn_flatten_weight-0", 24 },
  { "_cudnn_rnn_flatten_weight-batch_first-bidirectional-hidden_size-input_size-mode-num_layers-weight_stride0-*", 25 },
  { "_cudnn_rnn-batch_first-batch_sizes-bidirectional-dropout-hidden_size-mode-num_layers-train-weight_stride0-*", 26 },
  { "_debug_has_internal_overlap-1", 27 },
  { "_fused_dropout-p-1", 28 },
  { "_masked_scale-scale-2", 29 },
  { "_reshape_from_tensor-2", 30 },
  { "_shape_as_tensor-1", 31 },
  { "dropout-p-train-1", 32 },
  { "feature_dropout-p-train-1", 33 },
  { "alpha_dropout-p-train-1", 34 },
  { "feature_alpha_dropout-p-train-1", 35 },
  { "abs-1", 36 },
  { "absolute-1", 37 },
  { "angle-1", 38 },
  { "view_as_real-1", 39 },
  { "view_as_complex-1", 40 },
  { "real-1", 41 },
  { "imag-1", 42 },
  { "conj-1", 43 },
  { "acos-1", 44 },
  { "avg_pool1d-ceil_mode-count_include_pad-kernel_size-padding-stride-1", 45 },
  { "avg_pool1d-ceil_mode-kernel_size-padding-stride-1", 46 },
  { "avg_pool1d-kernel_size-padding-stride-1", 47 },
  { "avg_pool1d-kernel_size-stride-1", 48 },
  { "avg_pool1d-kernel_size-1", 49 },
  { "adaptive_avg_pool1d-output_size-1", 50 },
  { "adaptive_max_pool1d-output_size-1", 51 },
  { "add-alpha-2", 52 },
  { "add-2", 53 },
  { "add-alpha-other-1", 54 },
  { "add-other-1", 55 },
  { "addmv-alpha-beta-3", 56 },
  { "addmv-beta-3", 57 },
  { "addmv-3", 58 },
  { "addr-alpha-beta-3", 59 },
  { "addr-beta-3", 60 },
  { "addr-3", 61 },
  { "affine_grid_generator-align_corners-size-1", 62 },
  { "affine_grid_generator_backward-align_corners-size-1", 63 },
  { "all-dim-keepdim-1", 64 },
  { "all-dim-1", 65 },
  { "allclose-atol-equal_nan-rtol-2", 66 },
  { "allclose-atol-rtol-2", 67 },
  { "allclose-rtol-2", 68 },
  { "allclose-2", 69 },
  { "any-dim-keepdim-1", 70 },
  { "any-dim-1", 71 },
  { "_dim_arange-dim-1", 72 },
  { "argmax-1", 73 },
  { "argmin-1", 74 },
  { "acosh-1", 75 },
  { "asinh-1", 76 },
  { "atanh-1", 77 },
  { "as_strided-size-stride-1", 78 },
  { "asin-1", 79 },
  { "atan-1", 80 },
  { "baddbmm-alpha-beta-3", 81 },
  { "baddbmm-beta-3", 82 },
  { "baddbmm-3", 83 },
  { "batch_norm-cudnn_enabled-eps-momentum-training-5", 84 },
  { "quantized_batch_norm-eps-output_scale-output_zero_point-5", 85 },
  { "_batch_norm_impl_index-cudnn_enabled-eps-momentum-training-5", 86 },
  { "_batch_norm_impl_index_backward-eps-impl_index-output_mask-train-8", 87 },
  { "bernoulli-1", 88 },
  { "bernoulli-p-1", 89 },
  { "bilinear-4", 90 },
  { "binary_cross_entropy-reduction-3", 91 },
  { "binary_cross_entropy-3", 92 },
  { "binary_cross_entropy-2", 93 },
  { "binary_cross_entropy_backward-reduction-4", 94 },
  { "binary_cross_entropy_backward-4", 95 },
  { "binary_cross_entropy_backward-3", 96 },
  { "binary_cross_entropy_with_logits-reduction-4", 97 },
  { "binary_cross_entropy_with_logits-4", 98 },
  { "binary_cross_entropy_with_logits-3", 99 },
  { "binary_cross_entropy_with_logits-2", 100 },
  { "binary_cross_entropy_with_logits_backward-reduction-5", 101 },
  { "binary_cross_entropy_with_logits_backward-5", 102 },
  { "binary_cross_entropy_with_logits_backward-4", 103 },
  { "binary_cross_entropy_with_logits_backward-3", 104 },
  { "bincount-minlength-2", 105 },
  { "bincount-2", 106 },
  { "bincount-1", 107 },
  { "bitwise_not-1", 108 },
  { "logical_not-1", 109 },
  { "logical_xor-2", 110 },
  { "logical_and-2", 111 },
  { "logical_or-2", 112 },
  { "bmm-2", 113 },
  { "_bmm-deterministic-2", 114 },
  { "_bmm-2", 115 },
  { "broadcast_tensors-*", 116 },
  { "cat-dim-*", 117 },
  { "cat-*", 118 },
  { "block_diag-*", 119 },
  { "ceil-1", 120 },
  { "chain_matmul-*", 121 },
  { "chunk-chunks-dim-1", 122 },
  { "chunk-chunks-1", 123 },
  { "clamp-1", 124 },
  { "clamp_max-max-1", 125 },
  { "clamp_min-min-1", 126 },
  { "cudnn_is_acceptable-1", 127 },
  { "constant_pad_nd-pad-value-1", 128 },
  { "constant_pad_nd-pad-1", 129 },
  { "contiguous-1", 130 },
  { "convolution-dilation-groups-output_padding-padding-stride-transposed-3", 131 },
  { "convolution_overrideable-dilation-groups-output_padding-padding-stride-transposed-3", 132 },
  { "convolution_backward_overrideable-dilation-groups-output_mask-output_padding-padding-stride-transposed-3", 133 },
  { "_convolution-benchmark-cudnn_enabled-deterministic-dilation-groups-output_padding-padding-stride-transposed-3", 134 },
  { "_convolution_nogroup-dilation-output_padding-padding-stride-transposed-3", 135 },
  { "_convolution_double_backward-benchmark-cudnn_enabled-deterministic-dilation-groups-output_mask-output_padding-padding-stride-transposed-6", 136 },
  { "conv1d-dilation-groups-padding-stride-3", 137 },
  { "conv1d-dilation-padding-stride-3", 138 },
  { "conv1d-padding-stride-3", 139 },
  { "conv1d-stride-3", 140 },
  { "conv1d-3", 141 },
  { "conv1d-2", 142 },
  { "conv2d-dilation-groups-padding-stride-3", 143 },
  { "conv2d-dilation-padding-stride-3", 144 },
  { "conv2d-padding-stride-3", 145 },
  { "conv2d-stride-3", 146 },
  { "conv2d-3", 147 },
  { "conv2d-2", 148 },
  { "conv3d-dilation-groups-padding-stride-3", 149 },
  { "conv3d-dilation-padding-stride-3", 150 },
  { "conv3d-padding-stride-3", 151 },
  { "conv3d-stride-3", 152 },
  { "conv3d-3", 153 },
  { "conv3d-2", 154 },
  { "conv_tbc-pad-3", 155 },
  { "conv_tbc-3", 156 },
  { "conv_tbc_backward-pad-4", 157 },
  { "conv_transpose1d-dilation-groups-output_padding-padding-stride-3", 158 },
  { "conv_transpose1d-groups-output_padding-padding-stride-3", 159 },
  { "conv_transpose1d-output_padding-padding-stride-3", 160 },
  { "conv_transpose1d-padding-stride-3", 161 },
  { "conv_transpose1d-stride-3", 162 },
  { "conv_transpose1d-3", 163 },
  { "conv_transpose1d-2", 164 },
  { "conv_transpose2d-dilation-groups-output_padding-padding-stride-3", 165 },
  { "conv_transpose2d-groups-output_padding-padding-stride-3", 166 },
  { "conv_transpose2d-output_padding-padding-stride-3", 167 },
  { "conv_transpose2d-padding-stride-3", 168 },
  { "conv_transpose2d-stride-3", 169 },
  { "conv_transpose2d-3", 170 },
  { "conv_transpose2d-2", 171 },
  { "conv_transpose3d-dilation-groups-output_padding-padding-stride-3", 172 },
  { "conv_transpose3d-groups-output_padding-padding-stride-3", 173 },
  { "conv_transpose3d-output_padding-padding-stride-3", 174 },
  { "conv_transpose3d-padding-stride-3", 175 },
  { "conv_transpose3d-stride-3", 176 },
  { "conv_transpose3d-3", 177 },
  { "conv_transpose3d-2", 178 },
  { "_copy_from-non_blocking-2", 179 },
  { "_copy_from-2", 180 },
  { "cos-1", 181 },
  { "cosh-1", 182 },
  { "cosine_embedding_loss-margin-reduction-3", 183 },
  { "cosine_embedding_loss-margin-3", 184 },
  { "cosine_embedding_loss-3", 185 },
  { "cudnn_affine_grid_generator-C-H-N-W-1", 186 },
  { "cudnn_affine_grid_generator_backward-C-H-N-W-1", 187 },
  { "cudnn_batch_norm-epsilon-exponential_average_factor-training-5", 188 },
  { "cudnn_batch_norm_backward-epsilon-8", 189 },
  { "cudnn_convolution-benchmark-deterministic-dilation-groups-padding-stride-3", 190 },
  { "cudnn_convolution-benchmark-deterministic-dilation-groups-padding-stride-2", 191 },
  { "cudnn_convolution_backward_input-benchmark-deterministic-dilation-groups-padding-self_size-stride-2", 192 },
  { "cudnn_convolution_backward-benchmark-deterministic-dilation-groups-output_mask-padding-stride-3", 193 },
  { "cudnn_convolution_backward_weight-benchmark-deterministic-dilation-groups-padding-stride-weight_size-2", 194 },
  { "cudnn_convolution_transpose-benchmark-deterministic-dilation-groups-output_padding-padding-stride-3", 195 },
  { "cudnn_convolution_transpose-benchmark-deterministic-dilation-groups-output_padding-padding-stride-2", 196 },
  { "cudnn_convolution_transpose_backward-benchmark-deterministic-dilation-groups-output_mask-output_padding-padding-stride-3", 197 },
  { "cudnn_convolution_transpose_backward_input-benchmark-deterministic-dilation-groups-padding-stride-2", 198 },
  { "cudnn_convolution_transpose_backward_weight-benchmark-deterministic-dilation-groups-padding-stride-weight_size-2", 199 },
  { "cudnn_grid_sampler-2", 200 },
  { "cudnn_grid_sampler_backward-3", 201 },
  { "cummax-dim-1", 202 },
  { "cummin-dim-1", 203 },
  { "cumprod-dim-1", 204 },
  { "cumsum-dim-1", 205 },
  { "ctc_loss-blank-input_lengths-reduction-target_lengths-zero_infinity-2", 206 },
  { "ctc_loss-blank-input_lengths-reduction-target_lengths-2", 207 },
  { "ctc_loss-blank-input_lengths-target_lengths-2", 208 },
  { "ctc_loss-input_lengths-target_lengths-2", 209 },
  { "ctc_loss-blank-reduction-zero_infinity-4", 210 },
  { "ctc_loss-blank-reduction-4", 211 },
  { "ctc_loss-blank-4", 212 },
  { "ctc_loss-4", 213 },
  { "_ctc_loss-blank-input_lengths-target_lengths-zero_infinity-2", 214 },
  { "_ctc_loss-blank-input_lengths-target_lengths-2", 215 },
  { "_ctc_loss-input_lengths-target_lengths-2", 216 },
  { "_ctc_loss_backward-blank-input_lengths-target_lengths-zero_infinity-5", 217 },
  { "_ctc_loss_backward-blank-input_lengths-target_lengths-5", 218 },
  { "det-1", 219 },
  { "diag_embed-dim1-dim2-offset-1", 220 },
  { "diag_embed-dim1-offset-1", 221 },
  { "diag_embed-offset-1", 222 },
  { "diag_embed-1", 223 },
  { "diagflat-offset-1", 224 },
  { "diagflat-1", 225 },
  { "diagonal-dim1-dim2-offset-1", 226 },
  { "diagonal-dim1-offset-1", 227 },
  { "diagonal-offset-1", 228 },
  { "diagonal-1", 229 },
  { "div-2", 230 },
  { "div-other-1", 231 },
  { "dot-2", 232 },
  { "embedding-padding_idx-scale_grad_by_freq-sparse-2", 233 },
  { "embedding-padding_idx-scale_grad_by_freq-2", 234 },
  { "embedding-padding_idx-2", 235 },
  { "embedding-2", 236 },
  { "embedding_backward-num_weights-padding_idx-scale_grad_by_freq-sparse-2", 237 },
  { "embedding_dense_backward-num_weights-padding_idx-scale_grad_by_freq-2", 238 },
  { "embedding_sparse_backward-num_weights-padding_idx-scale_grad_by_freq-2", 239 },
  { "embedding_bag-include_last_offset-mode-scale_grad_by_freq-sparse-4", 240 },
  { "embedding_bag-mode-scale_grad_by_freq-sparse-4", 241 },
  { "embedding_bag-mode-scale_grad_by_freq-sparse-3", 242 },
  { "embedding_bag-mode-scale_grad_by_freq-3", 243 },
  { "embedding_bag-scale_grad_by_freq-3", 244 },
  { "embedding_bag-3", 245 },
  { "_embedding_bag-include_last_offset-mode-scale_grad_by_freq-sparse-4", 246 },
  { "_embedding_bag-mode-scale_grad_by_freq-sparse-4", 247 },
  { "_embedding_bag-mode-scale_grad_by_freq-sparse-3", 248 },
  { "_embedding_bag-mode-scale_grad_by_freq-3", 249 },
  { "_embedding_bag-scale_grad_by_freq-3", 250 },
  { "_embedding_bag-3", 251 },
  { "_embedding_bag_backward-mode-num_weights-scale_grad_by_freq-sparse-7", 252 },
  { "_embedding_bag_sparse_backward-mode-num_weights-scale_grad_by_freq-6", 253 },
  { "_embedding_bag_dense_backward-mode-num_weights-scale_grad_by_freq-7", 254 },
  { "_embedding_bag_per_sample_weights_backward-mode-5", 255 },
  { "empty_quantized-size-1", 256 },
  { "erf-1", 257 },
  { "erfc-1", 258 },
  { "exp-1", 259 },
  { "expm1-1", 260 },
  { "expand-implicit-size-1", 261 },
  { "expand-size-1", 262 },
  { "expand_as-2", 263 },
  { "flatten-end_dim-start_dim-1", 264 },
  { "flatten-start_dim-1", 265 },
  { "flatten-1", 266 },
  { "floor-1", 267 },
  { "floor_divide-2", 268 },
  { "floor_divide-other-1", 269 },
  { "frac-1", 270 },
  { "grid_sampler-align_corners-interpolation_mode-padding_mode-2", 271 },
  { "grid_sampler_2d-align_corners-interpolation_mode-padding_mode-2", 272 },
  { "grid_sampler_2d_backward-align_corners-interpolation_mode-padding_mode-3", 273 },
  { "grid_sampler_3d-align_corners-interpolation_mode-padding_mode-2", 274 },
  { "grid_sampler_3d_backward-align_corners-interpolation_mode-padding_mode-3", 275 },
  { "hinge_embedding_loss-margin-reduction-2", 276 },
  { "hinge_embedding_loss-margin-2", 277 },
  { "hinge_embedding_loss-2", 278 },
  { "ger-2", 279 },
  { "group_norm-cudnn_enabled-eps-num_groups-3", 280 },
  { "group_norm-eps-num_groups-3", 281 },
  { "group_norm-num_groups-3", 282 },
  { "group_norm-num_groups-2", 283 },
  { "group_norm-num_groups-1", 284 },
  { "native_group_norm-C-HxW-N-eps-group-3", 285 },
  { "native_group_norm_backward-C-HxW-N-group-output_mask-5", 286 },
  { "fft-normalized-signal_ndim-1", 287 },
  { "fft-signal_ndim-1", 288 },
  { "ifft-normalized-signal_ndim-1", 289 },
  { "ifft-signal_ndim-1", 290 },
  { "rfft-normalized-onesided-signal_ndim-1", 291 },
  { "rfft-normalized-signal_ndim-1", 292 },
  { "rfft-signal_ndim-1", 293 },
  { "irfft-normalized-onesided-signal_ndim-signal_sizes-1", 294 },
  { "irfft-normalized-onesided-signal_ndim-1", 295 },
  { "irfft-normalized-signal_ndim-1", 296 },
  { "irfft-signal_ndim-1", 297 },
  { "_fft_with_size-checked_signal_sizes-complex_input-complex_output-inverse-normalized-onesided-output_sizes-signal_ndim-1", 298 },
  { "_cufft_get_plan_cache_size-device_index-0", 299 },
  { "_cufft_get_plan_cache_max_size-device_index-0", 300 },
  { "index-*", 301 },
  { "index_copy-dim-3", 302 },
  { "index_put-accumulate-*", 303 },
  { "index_put-*", 304 },
  { "instance_norm-cudnn_enabled-eps-momentum-use_input_stats-5", 305 },
  { "inverse-1", 306 },
  { "_inverse_helper-1", 307 },
  { "isclose-atol-equal_nan-rtol-2", 308 },
  { "isclose-atol-rtol-2", 309 },
  { "isclose-rtol-2", 310 },
  { "isclose-2", 311 },
  { "isnan-1", 312 },
  { "is_distributed-1", 313 },
  { "is_floating_point-1", 314 },
  { "is_complex-1", 315 },
  { "is_nonzero-1", 316 },
  { "is_same_size-2", 317 },
  { "is_signed-1", 318 },
  { "kl_div-log_target-reduction-2", 319 },
  { "kl_div-reduction-2", 320 },
  { "kl_div-2", 321 },
  { "kl_div_backward-log_target-reduction-3", 322 },
  { "kl_div_backward-reduction-3", 323 },
  { "kl_div_backward-3", 324 },
  { "kthvalue-dim-k-keepdim-1", 325 },
  { "kthvalue-dim-k-1", 326 },
  { "kthvalue-k-1", 327 },
  { "layer_norm-cudnn_enable-eps-normalized_shape-3", 328 },
  { "layer_norm-eps-normalized_shape-3", 329 },
  { "layer_norm-normalized_shape-3", 330 },
  { "layer_norm-normalized_shape-2", 331 },
  { "layer_norm-normalized_shape-1", 332 },
  { "native_layer_norm-M-N-eps-3", 333 },
  { "native_layer_norm_backward-M-N-output_mask-5", 334 },
  { "linear-3", 335 },
  { "linear-2", 336 },
  { "mkldnn_linear-3", 337 },
  { "mkldnn_linear-2", 338 },
  { "fbgemm_linear_int8_weight_fp32_activation-weight_scale-weight_zero_point-5", 339 },
  { "fbgemm_linear_int8_weight-weight_scale-weight_zero_point-5", 340 },
  { "fbgemm_pack_gemm_matrix_fp16-1", 341 },
  { "fbgemm_linear_fp16_weight_fp32_activation-3", 342 },
  { "fbgemm_linear_fp16_weight-3", 343 },
  { "fbgemm_pack_quantized_matrix-1", 344 },
  { "fbgemm_pack_quantized_matrix-K-N-1", 345 },
  { "log-1", 346 },
  { "log10-1", 347 },
  { "log1p-1", 348 },
  { "log2-1", 349 },
  { "logaddexp-2", 350 },
  { "logaddexp2-2", 351 },
  { "logdet-1", 352 },
  { "log_softmax-dim-1", 353 },
  { "_log_softmax-dim-half_to_float-1", 354 },
  { "_log_softmax_backward_data-dim-3", 355 },
  { "_logcumsumexp-dim-1", 356 },
  { "logcumsumexp-dim-1", 357 },
  { "logsumexp-dim-keepdim-1", 358 },
  { "logsumexp-dim-1", 359 },
  { "margin_ranking_loss-margin-reduction-3", 360 },
  { "margin_ranking_loss-margin-3", 361 },
  { "margin_ranking_loss-3", 362 },
  { "matmul-2", 363 },
  { "matrix_rank-symmetric-tol-1", 364 },
  { "matrix_rank-tol-1", 365 },
  { "matrix_rank-symmetric-1", 366 },
  { "matrix_rank-1", 367 },
  { "matrix_power-n-1", 368 },
  { "max-dim-keepdim-1", 369 },
  { "max-dim-1", 370 },
  { "max_values-dim-keepdim-1", 371 },
  { "max_values-dim-1", 372 },
  { "max_pool1d_with_indices-ceil_mode-dilation-kernel_size-padding-stride-1", 373 },
  { "max_pool1d_with_indices-dilation-kernel_size-padding-stride-1", 374 },
  { "max_pool1d_with_indices-kernel_size-padding-stride-1", 375 },
  { "max_pool1d_with_indices-kernel_size-stride-1", 376 },
  { "max_pool1d_with_indices-kernel_size-1", 377 },
  { "max_pool1d-ceil_mode-dilation-kernel_size-padding-stride-1", 378 },
  { "max_pool1d-dilation-kernel_size-padding-stride-1", 379 },
  { "max_pool1d-kernel_size-padding-stride-1", 380 },
  { "max_pool1d-kernel_size-stride-1", 381 },
  { "max_pool1d-kernel_size-1", 382 },
  { "max_pool2d-ceil_mode-dilation-kernel_size-padding-stride-1", 383 },
  { "max_pool2d-dilation-kernel_size-padding-stride-1", 384 },
  { "max_pool2d-kernel_size-padding-stride-1", 385 },
  { "max_pool2d-kernel_size-stride-1", 386 },
  { "max_pool2d-kernel_size-1", 387 },
  { "mkldnn_max_pool2d-ceil_mode-dilation-kernel_size-padding-stride-1", 388 },
  { "mkldnn_max_pool2d-dilation-kernel_size-padding-stride-1", 389 },
  { "mkldnn_max_pool2d-kernel_size-padding-stride-1", 390 },
  { "mkldnn_max_pool2d-kernel_size-stride-1", 391 },
  { "mkldnn_max_pool2d-kernel_size-1", 392 },
  { "quantized_max_pool2d-ceil_mode-dilation-kernel_size-padding-stride-1", 393 },
  { "quantized_max_pool2d-dilation-kernel_size-padding-stride-1", 394 },
  { "quantized_max_pool2d-kernel_size-padding-stride-1", 395 },
  { "quantized_max_pool2d-kernel_size-stride-1", 396 },
  { "quantized_max_pool2d-kernel_size-1", 397 },
  { "max_pool3d-ceil_mode-dilation-kernel_size-padding-stride-1", 398 },
  { "max_pool3d-dilation-kernel_size-padding-stride-1", 399 },
  { "max_pool3d-kernel_size-padding-stride-1", 400 },
  { "max_pool3d-kernel_size-stride-1", 401 },
  { "max_pool3d-kernel_size-1", 402 },
  { "mean-1", 403 },
  { "mean-dim-keepdim-1", 404 },
  { "mean-dim-1", 405 },
  { "median-dim-keepdim-1", 406 },
  { "median-dim-1", 407 },
  { "min-dim-keepdim-1", 408 },
  { "min-dim-1", 409 },
  { "min_values-dim-keepdim-1", 410 },
  { "min_values-dim-1", 411 },
  { "mkldnn_convolution-dilation-groups-padding-stride-3", 412 },
  { "mkldnn_convolution_backward_input-bias_defined-dilation-groups-padding-self_size-stride-2", 413 },
  { "mkldnn_convolution_backward_weights-bias_defined-dilation-groups-padding-stride-weight_size-2", 414 },
  { "mkldnn_convolution_backward-dilation-groups-output_mask-padding-stride-3", 415 },
  { "miopen_batch_norm-epsilon-exponential_average_factor-training-5", 416 },
  { "miopen_batch_norm_backward-epsilon-7", 417 },
  { "miopen_convolution-benchmark-deterministic-dilation-groups-padding-stride-3", 418 },
  { "miopen_convolution_backward_input-benchmark-deterministic-dilation-groups-padding-self_size-stride-2", 419 },
  { "miopen_convolution_backward-benchmark-deterministic-dilation-groups-output_mask-padding-stride-3", 420 },
  { "miopen_convolution_backward_bias-1", 421 },
  { "miopen_convolution_backward_weight-benchmark-deterministic-dilation-groups-padding-stride-weight_size-2", 422 },
  { "miopen_convolution_transpose-benchmark-deterministic-dilation-groups-output_padding-padding-stride-3", 423 },
  { "miopen_convolution_transpose_backward-benchmark-deterministic-dilation-groups-output_mask-output_padding-padding-stride-3", 424 },
  { "miopen_convolution_transpose_backward_input-benchmark-deterministic-dilation-groups-padding-stride-2", 425 },
  { "miopen_convolution_transpose_backward_weight-benchmark-deterministic-dilation-groups-padding-stride-weight_size-2", 426 },
  { "miopen_depthwise_convolution-benchmark-deterministic-dilation-groups-padding-stride-3", 427 },
  { "miopen_depthwise_convolution_backward_input-benchmark-deterministic-dilation-groups-padding-self_size-stride-2", 428 },
  { "miopen_depthwise_convolution_backward-benchmark-deterministic-dilation-groups-output_mask-padding-stride-3", 429 },
  { "miopen_depthwise_convolution_backward_weight-benchmark-deterministic-dilation-groups-padding-stride-weight_size-2", 430 },
  { "miopen_rnn-batch_first-batch_sizes-bidirectional-dropout-hidden_size-mode-num_layers-train-weight_stride0-*", 431 },
  { "mm-2", 432 },
  { "_sparse_mm-2", 433 },
  { "mode-dim-keepdim-1", 434 },
  { "mode-dim-1", 435 },
  { "mode-1", 436 },
  { "mul-2", 437 },
  { "mul-other-1", 438 },
  { "mv-2", 439 },
  { "mvlgamma-p-1", 440 },
  { "narrow_copy-dim-length-start-1", 441 },
  { "narrow-dim-length-start-1", 442 },
  { "narrow-dim-length-2", 443 },
  { "native_batch_norm-eps-momentum-training-5", 444 },
  { "batch_norm_stats-eps-1", 445 },
  { "batch_norm_elemt-eps-5", 446 },
  { "batch_norm_gather_stats-count-eps-momentum-5", 447 },
  { "batch_norm_gather_stats_with_counts-eps-momentum-6", 448 },
  { "native_batch_norm_backward-eps-output_mask-train-7", 449 },
  { "batch_norm_backward_reduce-bias_g-input_g-weight_g-5", 450 },
  { "batch_norm_backward_elemt-7", 451 },
  { "batch_norm_update_stats-momentum-3", 452 },
  { "is_vulkan_available-0", 453 },
  { "_nnpack_available-0", 454 },
  { "_nnpack_spatial_convolution-padding-stride-3", 455 },
  { "_nnpack_spatial_convolution-padding-3", 456 },
  { "_nnpack_spatial_convolution_backward-output_mask-padding-3", 457 },
  { "_nnpack_spatial_convolution_backward_input-padding-3", 458 },
  { "_nnpack_spatial_convolution_backward_weight-padding-weightsize-2", 459 },
  { "pairwise_distance-eps-keepdim-p-2", 460 },
  { "pairwise_distance-eps-p-2", 461 },
  { "pairwise_distance-p-2", 462 },
  { "pairwise_distance-2", 463 },
  { "cdist-p-2", 464 },
  { "cdist-2", 465 },
  { "_euclidean_dist-2", 466 },
  { "_cdist_backward-p-4", 467 },
  { "pdist-p-1", 468 },
  { "pdist-1", 469 },
  { "_pdist_forward-p-1", 470 },
  { "_pdist_forward-1", 471 },
  { "_pdist_backward-p-3", 472 },
  { "cosine_similarity-dim-eps-2", 473 },
  { "cosine_similarity-dim-2", 474 },
  { "cosine_similarity-2", 475 },
  { "permute-dims-1", 476 },
  { "numpy_T-1", 477 },
  { "pixel_shuffle-upscale_factor-1", 478 },
  { "channel_shuffle-groups-1", 479 },
  { "is_pinned-1", 480 },
  { "pin_memory-1", 481 },
  { "pinverse-rcond-1", 482 },
  { "pinverse-1", 483 },
  { "poisson_nll_loss-eps-full-log_input-reduction-2", 484 },
  { "rad2deg-1", 485 },
  { "deg2rad-1", 486 },
  { "reciprocal-1", 487 },
  { "neg-1", 488 },
  { "repeat-repeats-1", 489 },
  { "repeat_interleave-1", 490 },
  { "repeat_interleave-2", 491 },
  { "repeat_interleave-repeats-1", 492 },
  { "reshape-shape-1", 493 },
  { "_mkldnn_reshape-shape-1", 494 },
  { "reshape_as-2", 495 },
  { "round-1", 496 },
  { "rrelu-lower-training-upper-1", 497 },
  { "rrelu-lower-upper-1", 498 },
  { "rrelu-lower-1", 499 },
  { "rrelu-1", 500 },
  { "relu-1", 501 },
  { "prelu-2", 502 },
  { "prelu_backward-3", 503 },
  { "gelu-1", 504 },
  { "gelu_backward-2", 505 },
  { "hardshrink-lambd-1", 506 },
  { "hardshrink-1", 507 },
  { "hardshrink_backward-lambd-2", 508 },
  { "rsqrt-1", 509 },
  { "select-dim-index-1", 510 },
  { "selu-1", 511 },
  { "celu-alpha-1", 512 },
  { "celu-1", 513 },
  { "sigmoid-1", 514 },
  { "sin-1", 515 },
  { "sinh-1", 516 },
  { "detach-1", 517 },
  { "size-dim-1", 518 },
  { "slice-dim-end-start-step-1", 519 },
  { "slice-dim-end-start-1", 520 },
  { "slice-dim-start-1", 521 },
  { "slice-dim-1", 522 },
  { "slice-1", 523 },
  { "slogdet-1", 524 },
  { "smm-2", 525 },
  { "softmax-dim-1", 526 },
  { "_softmax-dim-half_to_float-1", 527 },
  { "_softmax_backward_data-dim-3", 528 },
  { "split-dim-split_size-1", 529 },
  { "split-split_size-1", 530 },
  { "split_with_sizes-dim-split_sizes-1", 531 },
  { "split_with_sizes-split_sizes-1", 532 },
  { "squeeze-1", 533 },
  { "squeeze-dim-1", 534 },
  { "sspaddmm-alpha-beta-3", 535 },
  { "sspaddmm-beta-3", 536 },
  { "sspaddmm-3", 537 },
  { "stack-dim-*", 538 },
  { "stack-*", 539 },
  { "stft-n_fft-1", 540 },
  { "istft-n_fft-1", 541 },
  { "stride-dim-1", 542 },
  { "sum-1", 543 },
  { "sum-dim-keepdim-1", 544 },
  { "sum-dim-1", 545 },
  { "sum_to_size-size-1", 546 },
  { "sqrt-1", 547 },
  { "square-1", 548 },
  { "std-unbiased-1", 549 },
  { "std-1", 550 },
  { "std-dim-keepdim-unbiased-1", 551 },
  { "std-dim-unbiased-1", 552 },
  { "std-dim-1", 553 },
  { "std_mean-unbiased-1", 554 },
  { "std_mean-1", 555 },
  { "std_mean-dim-keepdim-unbiased-1", 556 },
  { "std_mean-dim-unbiased-1", 557 },
  { "std_mean-dim-1", 558 },
  { "prod-1", 559 },
  { "prod-dim-keepdim-1", 560 },
  { "prod-dim-1", 561 },
  { "t-1", 562 },
  { "tan-1", 563 },
  { "tanh-1", 564 },
  { "tensordot-dims_other-dims_self-2", 565 },
  { "threshold-threshold-value-1", 566 },
  { "threshold_backward-threshold-2", 567 },
  { "transpose-dim0-dim1-1", 568 },
  { "_mkldnn_transpose-dim0-dim1-1", 569 },
  { "one_hot-num_classes-1", 570 },
  { "one_hot-1", 571 },
  { "flip-dims-1", 572 },
  { "fliplr-1", 573 },
  { "flipud-1", 574 },
  { "roll-dims-shifts-1", 575 },
  { "roll-shifts-1", 576 },
  { "rot90-dims-k-1", 577 },
  { "rot90-k-1", 578 },
  { "rot90-1", 579 },
  { "trapz-dim-2", 580 },
  { "trapz-2", 581 },
  { "trapz-dim-dx-1", 582 },
  { "trapz-dx-1", 583 },
  { "trapz-1", 584 },
  { "_trilinear-expand1-expand2-expand3-sumdim-unroll_dim-3", 585 },
  { "_trilinear-expand1-expand2-expand3-sumdim-3", 586 },
  { "triplet_margin_loss-eps-margin-p-reduction-swap-3", 587 },
  { "triplet_margin_loss-eps-margin-p-swap-3", 588 },
  { "triplet_margin_loss-eps-margin-p-3", 589 },
  { "triplet_margin_loss-margin-p-3", 590 },
  { "triplet_margin_loss-margin-3", 591 },
  { "triplet_margin_loss-3", 592 },
  { "true_divide-2", 593 },
  { "true_divide-other-1", 594 },
  { "trunc-1", 595 },
  { "type_as-2", 596 },
  { "_has_compatible_shallow_copy_type-2", 597 },
  { "_unique-return_inverse-sorted-1", 598 },
  { "_unique-sorted-1", 599 },
  { "_unique-1", 600 },
  { "unique_dim-dim-return_counts-return_inverse-sorted-1", 601 },
  { "unique_dim-dim-return_inverse-sorted-1", 602 },
  { "unique_dim-dim-sorted-1", 603 },
  { "unique_dim-dim-1", 604 },
  { "unique_consecutive-return_counts-return_inverse-1", 605 },
  { "unique_consecutive-return_inverse-1", 606 },
  { "unique_consecutive-1", 607 },
  { "unique_dim_consecutive-dim-return_counts-return_inverse-1", 608 },
  { "unique_dim_consecutive-dim-return_inverse-1", 609 },
  { "unique_dim_consecutive-dim-1", 610 },
  { "_unique2-return_counts-return_inverse-sorted-1", 611 },
  { "_unique2-return_inverse-sorted-1", 612 },
  { "_unique2-sorted-1", 613 },
  { "_unique2-1", 614 },
  { "_unsafe_view-size-1", 615 },
  { "unsqueeze-dim-1", 616 },
  { "vander-1", 617 },
  { "var-unbiased-1", 618 },
  { "var-1", 619 },
  { "var-dim-keepdim-unbiased-1", 620 },
  { "var-dim-unbiased-1", 621 },
  { "var-dim-1", 622 },
  { "var_mean-unbiased-1", 623 },
  { "var_mean-1", 624 },
  { "var_mean-dim-keepdim-unbiased-1", 625 },
  { "var_mean-dim-unbiased-1", 626 },
  { "var_mean-dim-1", 627 },
  { "view_as-2", 628 },
  { "where-3", 629 },
  { "where-1", 630 },
  { "_s_where-3", 631 },
  { "norm_except_dim-dim-pow-1", 632 },
  { "norm_except_dim-pow-1", 633 },
  { "norm_except_dim-1", 634 },
  { "_weight_norm-dim-2", 635 },
  { "_weight_norm-2", 636 },
  { "_weight_norm_cuda_interface-dim-2", 637 },
  { "_weight_norm_cuda_interface-2", 638 },
  { "_weight_norm_cuda_interface_backward-dim-4", 639 },
  { "_weight_norm_differentiable_backward-dim-4", 640 },
  { "_standard_gamma_grad-2", 641 },
  { "_standard_gamma-1", 642 },
  { "_dirichlet_grad-3", 643 },
  { "_sample_dirichlet-1", 644 },
  { "poisson-1", 645 },
  { "binomial-2", 646 },
  { "native_norm-p-1", 647 },
  { "native_norm-1", 648 },
  { "_sparse_sum-1", 649 },
  { "_sparse_sum-dim-1", 650 },
  { "_sparse_sum_backward-dim-2", 651 },
  { "_sparse_softmax-dim-1", 652 },
  { "_sparse_softmax-dim-half_to_float-1", 653 },
  { "_sparse_softmax_backward_data-dim-3", 654 },
  { "_sparse_log_softmax-dim-1", 655 },
  { "_sparse_log_softmax-dim-half_to_float-1", 656 },
  { "_sparse_log_softmax_backward_data-dim-3", 657 },
  { "norm-p-1", 658 },
  { "norm-1", 659 },
  { "frobenius_norm-1", 660 },
  { "frobenius_norm-dim-keepdim-1", 661 },
  { "frobenius_norm-dim-1", 662 },
  { "nuclear_norm-keepdim-1", 663 },
  { "nuclear_norm-1", 664 },
  { "nuclear_norm-dim-keepdim-1", 665 },
  { "nuclear_norm-dim-1", 666 },
  { "clone-1", 667 },
  { "pow-exponent-1", 668 },
  { "sub-alpha-2", 669 },
  { "sub-2", 670 },
  { "sub-alpha-other-1", 671 },
  { "sub-other-1", 672 },
  { "rsub-alpha-2", 673 },
  { "rsub-2", 674 },
  { "rsub-alpha-other-1", 675 },
  { "rsub-other-1", 676 },
  { "_sparse_addmm-alpha-beta-3", 677 },
  { "_sparse_addmm-beta-3", 678 },
  { "_sparse_addmm-3", 679 },
  { "addmm-alpha-beta-3", 680 },
  { "addmm-beta-3", 681 },
  { "addmm-3", 682 },
  { "sparse_mask-2", 683 },
  { "to_dense-1", 684 },
  { "to_dense_backward-2", 685 },
  { "sparse_dim-1", 686 },
  { "_dimI-1", 687 },
  { "dense_dim-1", 688 },
  { "_dimV-1", 689 },
  { "_nnz-1", 690 },
  { "coalesce-1", 691 },
  { "is_coalesced-1", 692 },
  { "_indices-1", 693 },
  { "_values-1", 694 },
  { "indices-1", 695 },
  { "values-1", 696 },
  { "hspmm-2", 697 },
  { "unbind-dim-1", 698 },
  { "unbind-1", 699 },
  { "to_sparse-sparse_dim-1", 700 },
  { "to_sparse-1", 701 },
  { "to_mkldnn-1", 702 },
  { "mkldnn_reorder_conv2d_weight-dilation-groups-padding-stride-1", 703 },
  { "mkldnn_reorder_conv2d_weight-dilation-padding-stride-1", 704 },
  { "mkldnn_reorder_conv2d_weight-padding-stride-1", 705 },
  { "mkldnn_reorder_conv2d_weight-padding-1", 706 },
  { "mkldnn_reorder_conv2d_weight-1", 707 },
  { "to_mkldnn_backward-2", 708 },
  { "dequantize-1", 709 },
  { "dequantize-*", 710 },
  { "q_zero_point-1", 711 },
  { "q_per_channel_scales-1", 712 },
  { "q_per_channel_zero_points-1", 713 },
  { "q_per_channel_axis-1", 714 },
  { "int_repr-1", 715 },
  { "_make_per_tensor_quantized_tensor-scale-zero_point-1", 716 },
  { "_make_per_channel_quantized_tensor-axis-3", 717 },
  { "fake_quantize_per_tensor_affine-quant_max-quant_min-scale-zero_point-1", 718 },
  { "fake_quantize_per_tensor_affine_backward-quant_max-quant_min-scale-zero_point-2", 719 },
  { "fake_quantize_per_channel_affine-axis-quant_max-quant_min-3", 720 },
  { "fake_quantize_per_channel_affine_backward-axis-quant_max-quant_min-4", 721 },
  { "meshgrid-*", 722 },
  { "cartesian_prod-*", 723 },
  { "combinations-r-with_replacement-1", 724 },
  { "combinations-r-1", 725 },
  { "combinations-1", 726 },
  { "item-1", 727 },
  { "_local_scalar_dense-1", 728 },
  { "_thnn_fused_lstm_cell-5", 729 },
  { "_thnn_fused_lstm_cell-4", 730 },
  { "_thnn_fused_lstm_cell-3", 731 },
  { "_thnn_fused_lstm_cell_backward-has_bias-5", 732 },
  { "_thnn_differentiable_lstm_cell_backward-8", 733 },
  { "_thnn_fused_gru_cell-5", 734 },
  { "_thnn_fused_gru_cell-4", 735 },
  { "_thnn_fused_gru_cell-3", 736 },
  { "_thnn_fused_gru_cell_backward-has_bias-2", 737 },
  { "_thnn_differentiable_gru_cell_backward-6", 738 },
  { "lstm-batch_first-bidirectional-dropout-has_biases-num_layers-train-*", 739 },
  { "lstm-bidirectional-dropout-has_biases-num_layers-train-*", 740 },
  { "gru-batch_first-bidirectional-dropout-has_biases-num_layers-train-*", 741 },
  { "gru-bidirectional-dropout-has_biases-num_layers-train-*", 742 },
  { "rnn_tanh-batch_first-bidirectional-dropout-has_biases-num_layers-train-*", 743 },
  { "rnn_tanh-bidirectional-dropout-has_biases-num_layers-train-*", 744 },
  { "rnn_relu-batch_first-bidirectional-dropout-has_biases-num_layers-train-*", 745 },
  { "rnn_relu-bidirectional-dropout-has_biases-num_layers-train-*", 746 },
  { "lstm_cell-*", 747 },
  { "gru_cell-6", 748 },
  { "gru_cell-5", 749 },
  { "gru_cell-4", 750 },
  { "rnn_tanh_cell-6", 751 },
  { "rnn_tanh_cell-5", 752 },
  { "rnn_tanh_cell-4", 753 },
  { "rnn_relu_cell-6", 754 },
  { "rnn_relu_cell-5", 755 },
  { "rnn_relu_cell-4", 756 },
  { "quantized_lstm_cell-scale_hh-scale_ih-zero_point_hh-zero_point_ih-*", 757 },
  { "quantized_gru_cell-scale_hh-scale_ih-zero_point_hh-zero_point_ih-10", 758 },
  { "quantized_rnn_relu_cell-scale_hh-scale_ih-zero_point_hh-zero_point_ih-10", 759 },
  { "quantized_rnn_tanh_cell-scale_hh-scale_ih-zero_point_hh-zero_point_ih-10", 760 },
  { "_pack_padded_sequence-batch_first-2", 761 },
  { "_pack_padded_sequence_backward-batch_first-input_size-2", 762 },
  { "_pad_packed_sequence-batch_first-padding_value-total_length-2", 763 },
  { "is_set_to-2", 764 },
  { "masked_fill-value-2", 765 },
  { "masked_fill-3", 766 },
  { "masked_scatter-3", 767 },
  { "view-size-1", 768 },
  { "index_add-dim-3", 769 },
  { "index_fill-dim-value-2", 770 },
  { "index_fill-dim-3", 771 },
  { "scatter-dim-3", 772 },
  { "scatter-dim-value-2", 773 },
  { "scatter_add-dim-3", 774 },
  { "bitwise_and-other-1", 775 },
  { "bitwise_and-2", 776 },
  { "__and__-other-1", 777 },
  { "__and__-2", 778 },
  { "bitwise_or-other-1", 779 },
  { "bitwise_or-2", 780 },
  { "__or__-other-1", 781 },
  { "__or__-2", 782 },
  { "bitwise_xor-other-1", 783 },
  { "bitwise_xor-2", 784 },
  { "__xor__-other-1", 785 },
  { "__xor__-2", 786 },
  { "__lshift__-other-1", 787 },
  { "__lshift__-2", 788 },
  { "__rshift__-other-1", 789 },
  { "__rshift__-2", 790 },
  { "addbmm-alpha-beta-3", 791 },
  { "addbmm-beta-3", 792 },
  { "addbmm-3", 793 },
  { "diag-diagonal-1", 794 },
  { "diag-1", 795 },
  { "cross-2", 796 },
  { "triu-diagonal-1", 797 },
  { "triu-1", 798 },
  { "tril-diagonal-1", 799 },
  { "tril-1", 800 },
  { "trace-1", 801 },
  { "ne-other-1", 802 },
  { "ne-2", 803 },
  { "eq-other-1", 804 },
  { "eq-2", 805 },
  { "ge-other-1", 806 },
  { "ge-2", 807 },
  { "le-other-1", 808 },
  { "le-2", 809 },
  { "gt-other-1", 810 },
  { "gt-2", 811 },
  { "lt-other-1", 812 },
  { "lt-2", 813 },
  { "take-2", 814 },
  { "index_select-dim-2", 815 },
  { "masked_select-2", 816 },
  { "nonzero-1", 817 },
  { "nonzero_numpy-1", 818 },
  { "gather-dim-sparse_grad-2", 819 },
  { "gather-dim-2", 820 },
  { "_gather_sparse_backward-dim-3", 821 },
  { "addcmul-value-3", 822 },
  { "addcmul-3", 823 },
  { "addcdiv-value-3", 824 },
  { "addcdiv-3", 825 },
  { "lstsq-2", 826 },
  { "triangular_solve-transpose-unitriangular-upper-2", 827 },
  { "triangular_solve-transpose-upper-2", 828 },
  { "triangular_solve-upper-2", 829 },
  { "triangular_solve-2", 830 },
  { "_triangular_solve_helper-transpose-unitriangular-upper-2", 831 },
  { "symeig-eigenvectors-upper-1", 832 },
  { "symeig-eigenvectors-1", 833 },
  { "symeig-1", 834 },
  { "_symeig_helper-eigenvectors-upper-1", 835 },
  { "eig-eigenvectors-1", 836 },
  { "eig-1", 837 },
  { "svd-compute_uv-some-1", 838 },
  { "svd-some-1", 839 },
  { "svd-1", 840 },
  { "_svd_helper-compute_uv-some-1", 841 },
  { "cholesky-upper-1", 842 },
  { "cholesky-1", 843 },
  { "_cholesky_helper-upper-1", 844 },
  { "cholesky_solve-upper-2", 845 },
  { "cholesky_solve-2", 846 },
  { "_cholesky_solve_helper-upper-2", 847 },
  { "solve-2", 848 },
  { "_solve_helper-2", 849 },
  { "cholesky_inverse-upper-1", 850 },
  { "cholesky_inverse-1", 851 },
  { "qr-some-1", 852 },
  { "qr-1", 853 },
  { "_qr_helper-some-1", 854 },
  { "geqrf-1", 855 },
  { "orgqr-2", 856 },
  { "ormqr-left-transpose-3", 857 },
  { "ormqr-left-3", 858 },
  { "ormqr-3", 859 },
  { "_lu_with_info-check_errors-pivot-1", 860 },
  { "_lu_with_info-pivot-1", 861 },
  { "_lu_with_info-1", 862 },
  { "lu_solve-3", 863 },
  { "_lu_solve_helper-3", 864 },
  { "multinomial-num_samples-replacement-1", 865 },
  { "multinomial-num_samples-1", 866 },
  { "_multinomial_alias_setup-1", 867 },
  { "_multinomial_alias_draw-num_samples-2", 868 },
  { "lgamma-1", 869 },
  { "digamma-1", 870 },
  { "polygamma-n-1", 871 },
  { "erfinv-1", 872 },
  { "sign-1", 873 },
  { "dist-p-2", 874 },
  { "dist-2", 875 },
  { "atan2-2", 876 },
  { "lerp-weight-2", 877 },
  { "lerp-3", 878 },
  { "histc-bins-max-min-1", 879 },
  { "histc-bins-min-1", 880 },
  { "histc-bins-1", 881 },
  { "histc-1", 882 },
  { "fmod-other-1", 883 },
  { "fmod-2", 884 },
  { "remainder-other-1", 885 },
  { "remainder-2", 886 },
  { "min-2", 887 },
  { "min-1", 888 },
  { "max-2", 889 },
  { "max-1", 890 },
  { "median-1", 891 },
  { "sort-descending-dim-1", 892 },
  { "sort-dim-1", 893 },
  { "sort-1", 894 },
  { "argsort-descending-dim-1", 895 },
  { "argsort-dim-1", 896 },
  { "argsort-1", 897 },
  { "topk-dim-k-largest-sorted-1", 898 },
  { "topk-dim-k-largest-1", 899 },
  { "topk-dim-k-1", 900 },
  { "topk-k-1", 901 },
  { "all-1", 902 },
  { "any-1", 903 },
  { "renorm-dim-maxnorm-p-1", 904 },
  { "unfold-dimension-size-step-1", 905 },
  { "unfold_backward-dim-input_sizes-size-step-1", 906 },
  { "equal-2", 907 },
  { "pow-2", 908 },
  { "pow-self-1", 909 },
  { "alias-1", 910 },
  { "_addr-alpha-beta-3", 911 },
  { "_addr-beta-3", 912 },
  { "_addr-3", 913 },
  { "_cumsum-dim-1", 914 },
  { "_cumprod-dim-1", 915 },
  { "_amp_update_scale-growth_interval-scale_backoff_factor-scale_growth_factor-3", 916 },
  { "_cat-dim-*", 917 },
  { "_cat-*", 918 },
  { "_mode-dim-keepdim-1", 919 },
  { "_mode-dim-1", 920 },
  { "_mode-1", 921 },
  { "bucketize-out_int32-right-2", 922 },
  { "bucketize-out_int32-2", 923 },
  { "bucketize-2", 924 },
  { "bucketize-out_int32-right-self-1", 925 },
  { "bucketize-out_int32-self-1", 926 },
  { "bucketize-self-1", 927 },
  { "searchsorted-out_int32-right-2", 928 },
  { "searchsorted-out_int32-2", 929 },
  { "searchsorted-2", 930 },
  { "searchsorted-out_int32-right-self-1", 931 },
  { "searchsorted-out_int32-self-1", 932 },
  { "searchsorted-self-1", 933 },
  { "mse_loss-reduction-2", 934 },
  { "mse_loss-2", 935 },
  { "mse_loss_backward-reduction-3", 936 },
  { "l1_loss-reduction-2", 937 },
  { "l1_loss-2", 938 },
  { "l1_loss_backward-reduction-3", 939 },
  { "multi_margin_loss-margin-p-reduction-3", 940 },
  { "multi_margin_loss-margin-p-3", 941 },
  { "multi_margin_loss-margin-p-2", 942 },
  { "multi_margin_loss-p-2", 943 },
  { "multi_margin_loss-2", 944 },
  { "multi_margin_loss_backward-margin-p-reduction-4", 945 },
  { "multi_margin_loss_backward-margin-p-4", 946 },
  { "multi_margin_loss_backward-margin-p-3", 947 },
  { "multilabel_margin_loss-reduction-2", 948 },
  { "multilabel_margin_loss-2", 949 },
  { "multilabel_margin_loss_forward-reduction-2", 950 },
  { "multilabel_margin_loss_backward-reduction-4", 951 },
  { "nll_loss-ignore_index-reduction-3", 952 },
  { "nll_loss-reduction-3", 953 },
  { "nll_loss-3", 954 },
  { "nll_loss-2", 955 },
  { "nll_loss_forward-ignore_index-reduction-3", 956 },
  { "nll_loss_backward-ignore_index-reduction-5", 957 },
  { "nll_loss2d-ignore_index-reduction-3", 958 },
  { "nll_loss2d-reduction-3", 959 },
  { "nll_loss2d-3", 960 },
  { "nll_loss2d-2", 961 },
  { "nll_loss2d_forward-ignore_index-reduction-3", 962 },
  { "nll_loss2d_backward-ignore_index-reduction-5", 963 },
  { "smooth_l1_loss-reduction-2", 964 },
  { "smooth_l1_loss-2", 965 },
  { "smooth_l1_loss_backward-reduction-3", 966 },
  { "soft_margin_loss-reduction-2", 967 },
  { "soft_margin_loss-2", 968 },
  { "soft_margin_loss_backward-reduction-3", 969 },
  { "elu-alpha-input_scale-scale-1", 970 },
  { "elu-alpha-scale-1", 971 },
  { "elu-alpha-1", 972 },
  { "elu-1", 973 },
  { "elu_backward-alpha-input_scale-scale-2", 974 },
  { "glu-dim-1", 975 },
  { "glu-1", 976 },
  { "glu_backward-dim-2", 977 },
  { "hardsigmoid-1", 978 },
  { "hardsigmoid_backward-2", 979 },
  { "hardtanh-max_val-min_val-1", 980 },
  { "hardtanh-min_val-1", 981 },
  { "hardtanh-1", 982 },
  { "hardtanh_backward-max_val-min_val-2", 983 },
  { "hardswish-1", 984 },
  { "hardswish_backward-2", 985 },
  { "leaky_relu-negative_slope-1", 986 },
  { "leaky_relu-1", 987 },
  { "leaky_relu_backward-negative_slope-self_is_result-2", 988 },
  { "log_sigmoid-1", 989 },
  { "log_sigmoid_forward-1", 990 },
  { "log_sigmoid_backward-3", 991 },
  { "rrelu_with_noise-lower-training-upper-2", 992 },
  { "rrelu_with_noise-lower-upper-2", 993 },
  { "rrelu_with_noise-lower-2", 994 },
  { "rrelu_with_noise-2", 995 },
  { "rrelu_with_noise_backward-lower-self_is_result-training-upper-3", 996 },
  { "softplus-beta-threshold-1", 997 },
  { "softplus-beta-1", 998 },
  { "softplus-1", 999 },
  { "softplus_backward-beta-threshold-3", 1000 },
  { "softshrink-lambd-1", 1001 },
  { "softshrink-1", 1002 },
  { "softshrink_backward-lambd-2", 1003 },
  { "adaptive_avg_pool2d-output_size-1", 1004 },
  { "mkldnn_adaptive_avg_pool2d-output_size-1", 1005 },
  { "_adaptive_avg_pool2d-output_size-1", 1006 },
  { "_adaptive_avg_pool2d_backward-2", 1007 },
  { "adaptive_avg_pool3d-output_size-1", 1008 },
  { "adaptive_avg_pool3d_backward-2", 1009 },
  { "adaptive_max_pool2d-output_size-1", 1010 },
  { "adaptive_max_pool2d_backward-3", 1011 },
  { "adaptive_max_pool3d-output_size-1", 1012 },
  { "adaptive_max_pool3d_backward-3", 1013 },
  { "avg_pool2d-ceil_mode-count_include_pad-kernel_size-padding-stride-1", 1014 },
  { "avg_pool2d-ceil_mode-kernel_size-padding-stride-1", 1015 },
  { "avg_pool2d-kernel_size-padding-stride-1", 1016 },
  { "avg_pool2d-kernel_size-stride-1", 1017 },
  { "avg_pool2d-kernel_size-1", 1018 },
  { "avg_pool3d-ceil_mode-count_include_pad-kernel_size-padding-stride-1", 1019 },
  { "avg_pool3d-ceil_mode-kernel_size-padding-stride-1", 1020 },
  { "avg_pool3d-kernel_size-padding-stride-1", 1021 },
  { "avg_pool3d-kernel_size-stride-1", 1022 },
  { "avg_pool3d-kernel_size-1", 1023 },
  { "fractional_max_pool2d-kernel_size-output_size-2", 1024 },
  { "fractional_max_pool2d_backward-kernel_size-output_size-3", 1025 },
  { "fractional_max_pool3d-kernel_size-output_size-2", 1026 },
  { "fractional_max_pool3d_backward-kernel_size-output_size-3", 1027 },
  { "max_pool2d_with_indices-ceil_mode-dilation-kernel_size-padding-stride-1", 1028 },
  { "max_pool2d_with_indices-dilation-kernel_size-padding-stride-1", 1029 },
  { "max_pool2d_with_indices-kernel_size-padding-stride-1", 1030 },
  { "max_pool2d_with_indices-kernel_size-stride-1", 1031 },
  { "max_pool2d_with_indices-kernel_size-1", 1032 },
  { "max_pool2d_with_indices_backward-ceil_mode-dilation-kernel_size-padding-stride-3", 1033 },
  { "max_pool3d_with_indices-ceil_mode-dilation-kernel_size-padding-stride-1", 1034 },
  { "max_pool3d_with_indices-dilation-kernel_size-padding-stride-1", 1035 },
  { "max_pool3d_with_indices-kernel_size-padding-stride-1", 1036 },
  { "max_pool3d_with_indices-kernel_size-stride-1", 1037 },
  { "max_pool3d_with_indices-kernel_size-1", 1038 },
  { "max_pool3d_with_indices_backward-ceil_mode-dilation-kernel_size-padding-stride-3", 1039 },
  { "max_unpool2d-output_size-2", 1040 },
  { "max_unpool2d_backward-output_size-3", 1041 },
  { "max_unpool3d-output_size-padding-stride-2", 1042 },
  { "max_unpool3d_backward-output_size-padding-stride-3", 1043 },
  { "reflection_pad1d-padding-1", 1044 },
  { "reflection_pad1d_backward-padding-2", 1045 },
  { "reflection_pad2d-padding-1", 1046 },
  { "reflection_pad2d_backward-padding-2", 1047 },
  { "replication_pad1d-padding-1", 1048 },
  { "replication_pad1d_backward-padding-2", 1049 },
  { "replication_pad2d-padding-1", 1050 },
  { "replication_pad2d_backward-padding-2", 1051 },
  { "replication_pad3d-padding-1", 1052 },
  { "replication_pad3d_backward-padding-2", 1053 },
  { "upsample_linear1d-align_corners-output_size-1", 1054 },
  { "upsample_linear1d_backward-align_corners-input_size-output_size-1", 1055 },
  { "upsample_bilinear2d-align_corners-output_size-1", 1056 },
  { "upsample_bilinear2d_backward-align_corners-input_size-output_size-1", 1057 },
  { "upsample_bicubic2d-align_corners-output_size-1", 1058 },
  { "upsample_bicubic2d_backward-align_corners-input_size-output_size-1", 1059 },
  { "upsample_trilinear3d-align_corners-output_size-1", 1060 },
  { "upsample_trilinear3d_backward-align_corners-input_size-output_size-1", 1061 },
  { "upsample_nearest1d-output_size-1", 1062 },
  { "upsample_nearest1d_backward-input_size-output_size-1", 1063 },
  { "upsample_nearest2d-output_size-1", 1064 },
  { "upsample_nearest2d_backward-input_size-output_size-1", 1065 },
  { "upsample_nearest3d-output_size-1", 1066 },
  { "upsample_nearest3d_backward-input_size-output_size-1", 1067 },
  { "sigmoid_backward-2", 1068 },
  { "tanh_backward-2", 1069 },
  { "slow_conv_transpose2d-dilation-kernel_size-output_padding-padding-stride-3", 1070 },
  { "slow_conv_transpose2d-kernel_size-output_padding-padding-stride-3", 1071 },
  { "slow_conv_transpose2d-kernel_size-padding-stride-3", 1072 },
  { "slow_conv_transpose2d-kernel_size-stride-3", 1073 },
  { "slow_conv_transpose2d-kernel_size-3", 1074 },
  { "slow_conv_transpose2d-kernel_size-2", 1075 },
  { "slow_conv_transpose2d_backward-dilation-kernel_size-output_mask-output_padding-padding-stride-5", 1076 },
  { "slow_conv_transpose3d-dilation-kernel_size-output_padding-padding-stride-3", 1077 },
  { "slow_conv_transpose3d-kernel_size-output_padding-padding-stride-3", 1078 },
  { "slow_conv_transpose3d-kernel_size-padding-stride-3", 1079 },
  { "slow_conv_transpose3d-kernel_size-stride-3", 1080 },
  { "slow_conv_transpose3d-kernel_size-3", 1081 },
  { "slow_conv_transpose3d-kernel_size-2", 1082 },
  { "slow_conv_transpose3d_backward-dilation-kernel_size-output_mask-output_padding-padding-stride-5", 1083 },
  { "thnn_conv2d-kernel_size-padding-stride-3", 1084 },
  { "thnn_conv2d-kernel_size-stride-3", 1085 },
  { "thnn_conv2d-kernel_size-3", 1086 },
  { "thnn_conv2d-kernel_size-2", 1087 },
  { "thnn_conv2d_forward-kernel_size-padding-stride-3", 1088 },
  { "thnn_conv2d_backward-kernel_size-output_mask-padding-stride-5", 1089 },
  { "thnn_conv_depthwise2d-dilation-kernel_size-padding-stride-3", 1090 },
  { "thnn_conv_depthwise2d-kernel_size-padding-stride-3", 1091 },
  { "thnn_conv_depthwise2d-kernel_size-stride-3", 1092 },
  { "thnn_conv_depthwise2d-kernel_size-3", 1093 },
  { "thnn_conv_depthwise2d-kernel_size-2", 1094 },
  { "thnn_conv_depthwise2d_forward-dilation-kernel_size-padding-stride-3", 1095 },
  { "thnn_conv_depthwise2d_backward-dilation-kernel_size-output_mask-padding-stride-3", 1096 },
  { "slow_conv3d-kernel_size-padding-stride-3", 1097 },
  { "slow_conv3d-kernel_size-stride-3", 1098 },
  { "slow_conv3d-kernel_size-3", 1099 },
  { "slow_conv3d-kernel_size-2", 1100 },
  { "slow_conv3d_forward-kernel_size-padding-stride-3", 1101 },
  { "slow_conv3d_backward-kernel_size-output_mask-padding-stride-5", 1102 },
  { "slow_conv_dilated2d-dilation-kernel_size-padding-stride-3", 1103 },
  { "slow_conv_dilated2d-kernel_size-padding-stride-3", 1104 },
  { "slow_conv_dilated2d-kernel_size-stride-3", 1105 },
  { "slow_conv_dilated2d-kernel_size-3", 1106 },
  { "slow_conv_dilated2d-kernel_size-2", 1107 },
  { "slow_conv_dilated2d_backward-dilation-kernel_size-output_mask-padding-stride-3", 1108 },
  { "slow_conv_dilated3d-dilation-kernel_size-padding-stride-3", 1109 },
  { "slow_conv_dilated3d-kernel_size-padding-stride-3", 1110 },
  { "slow_conv_dilated3d-kernel_size-stride-3", 1111 },
  { "slow_conv_dilated3d-kernel_size-3", 1112 },
  { "slow_conv_dilated3d-kernel_size-2", 1113 },
  { "slow_conv_dilated3d_backward-dilation-kernel_size-output_mask-padding-stride-3", 1114 },
  { "col2im-dilation-kernel_size-output_size-padding-stride-1", 1115 },
  { "col2im_backward-dilation-kernel_size-padding-stride-1", 1116 },
  { "im2col-dilation-kernel_size-padding-stride-1", 1117 },
  { "im2col_backward-dilation-input_size-kernel_size-padding-stride-1", 1118 },
  { "isfinite-1", 1119 },
  { "isinf-1", 1120 },
  { "_test_serialization_subcmul-alpha-2", 1121 },
  { "_test_serialization_subcmul-2", 1122 },
};

namespace caffe2 {

using at::Half; // for AT_FORALL_SCALAR_TYPES_AND3(Bool, Half, BFloat16, ...)

namespace internal {
CAFFE2_API at::Tensor index_with_uint8_handling(
    const at::Tensor& self,
    at::TensorList indices);
}

template <class Context>
class ATenOp : public Operator<Context> {
 public:
  ATenOp(const OperatorDef& operator_def, Workspace* ws)
  : Operator<Context>(operator_def, ws) {
    VLOG(2) << "ATen OpDef: " << ProtoDebugString(operator_def) << "\n";
    switch(findImplementation(operator_def)) {
      case 0: { // _cast_Byte
          bool non_blocking = readAttribute<int64_t>("non_blocking");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cast_Byte(self, non_blocking);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1: { // _cast_Byte
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cast_Byte(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 2: { // _cast_Char
          bool non_blocking = readAttribute<int64_t>("non_blocking");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cast_Char(self, non_blocking);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 3: { // _cast_Char
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cast_Char(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 4: { // _cast_Double
          bool non_blocking = readAttribute<int64_t>("non_blocking");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cast_Double(self, non_blocking);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 5: { // _cast_Double
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cast_Double(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 6: { // _cast_Float
          bool non_blocking = readAttribute<int64_t>("non_blocking");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cast_Float(self, non_blocking);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 7: { // _cast_Float
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cast_Float(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 8: { // _cast_Int
          bool non_blocking = readAttribute<int64_t>("non_blocking");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cast_Int(self, non_blocking);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 9: { // _cast_Int
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cast_Int(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 10: { // _cast_Long
          bool non_blocking = readAttribute<int64_t>("non_blocking");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cast_Long(self, non_blocking);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 11: { // _cast_Long
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cast_Long(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 12: { // _cast_Short
          bool non_blocking = readAttribute<int64_t>("non_blocking");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cast_Short(self, non_blocking);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 13: { // _cast_Short
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cast_Short(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 14: { // _cast_Half
          bool non_blocking = readAttribute<int64_t>("non_blocking");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cast_Half(self, non_blocking);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 15: { // _cast_Half
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cast_Half(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 16: { // data
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.data();
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 17: { // is_leaf
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.is_leaf();
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 18: { // output_nr
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.output_nr();
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 19: { // _version
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self._version();
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 20: { // align_as
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = self.align_as(other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 21: { // align_tensors
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto tensors = peekSlice(0, InputSize() - 0, InputSize());
              auto the_result = at::align_tensors(tensors);
                if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
              return true;
          };
      } break;
      case 22: { // _use_cudnn_ctc_loss
          auto input_lengths = readIntArrayRef("input_lengths");
          auto target_lengths = readIntArrayRef("target_lengths");
          int64_t blank = readAttribute<int64_t>("blank");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto log_probs = peek(0, 2);
              auto targets = peek(1, 2);
              auto the_result = at::_use_cudnn_ctc_loss(log_probs, targets, input_lengths, target_lengths, blank);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 23: { // _cudnn_ctc_loss
          auto input_lengths = readIntArrayRef("input_lengths");
          auto target_lengths = readIntArrayRef("target_lengths");
          int64_t blank = readAttribute<int64_t>("blank");
          bool deterministic = readAttribute<int64_t>("deterministic");
          bool zero_infinity = readAttribute<int64_t>("zero_infinity");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto log_probs = peek(0, 2);
              auto targets = peek(1, 2);
              auto the_result = at::_cudnn_ctc_loss(log_probs, targets, input_lengths, target_lengths, blank, deterministic, zero_infinity);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 24: { // _use_cudnn_rnn_flatten_weight
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
      
              auto the_result = at::_use_cudnn_rnn_flatten_weight();
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 25: { // _cudnn_rnn_flatten_weight
          int64_t weight_stride0 = readAttribute<int64_t>("weight_stride0");
          int64_t input_size = readAttribute<int64_t>("input_size");
          int64_t mode = readAttribute<int64_t>("mode");
          int64_t hidden_size = readAttribute<int64_t>("hidden_size");
          int64_t num_layers = readAttribute<int64_t>("num_layers");
          bool batch_first = readAttribute<int64_t>("batch_first");
          bool bidirectional = readAttribute<int64_t>("bidirectional");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto weight_arr = peekSlice(0, InputSize() - 0, InputSize());
              auto the_result = at::_cudnn_rnn_flatten_weight(weight_arr, weight_stride0, input_size, mode, hidden_size, num_layers, batch_first, bidirectional);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 26: { // _cudnn_rnn
          int64_t weight_stride0 = readAttribute<int64_t>("weight_stride0");
          int64_t mode = readAttribute<int64_t>("mode");
          int64_t hidden_size = readAttribute<int64_t>("hidden_size");
          int64_t num_layers = readAttribute<int64_t>("num_layers");
          bool batch_first = readAttribute<int64_t>("batch_first");
          double dropout = readAttribute<float>("dropout");
          bool train = readAttribute<int64_t>("train");
          bool bidirectional = readAttribute<int64_t>("bidirectional");
          auto batch_sizes = readIntArrayRef("batch_sizes");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, InputSize());
              auto weight = peekSlice(1, InputSize() - 5, InputSize());
              auto weight_buf = peek(1, 5);
              auto hx = peek(2, 5);
              auto cx = peek(3, 5);
              auto dropout_state = peek(4, 5);
              auto the_result = at::_cudnn_rnn(input, weight, weight_stride0, weight_buf, hx, cx, mode, hidden_size, num_layers, batch_first, dropout, train, bidirectional, batch_sizes, dropout_state);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
                if(OutputSize() > 4) {assignTo(Output(4),std::get<4>(the_result));}
              return true;
          };
      } break;
      case 27: { // _debug_has_internal_overlap
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_debug_has_internal_overlap(self);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 28: { // _fused_dropout
          double p = readAttribute<float>("p");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_fused_dropout(self, p);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 29: { // _masked_scale
          double scale = readAttribute<float>("scale");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto mask = peek(1, 2);
              auto the_result = at::_masked_scale(self, mask, scale);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 30: { // _reshape_from_tensor
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto shape = peek(1, 2);
              auto the_result = at::_reshape_from_tensor(self, shape);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 31: { // _shape_as_tensor
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_shape_as_tensor(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 32: { // dropout
          double p = readAttribute<float>("p");
          bool train = readAttribute<int64_t>("train");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 1);
              auto the_result = at::dropout(input, p, train);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 33: { // feature_dropout
          double p = readAttribute<float>("p");
          bool train = readAttribute<int64_t>("train");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 1);
              auto the_result = at::feature_dropout(input, p, train);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 34: { // alpha_dropout
          double p = readAttribute<float>("p");
          bool train = readAttribute<int64_t>("train");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 1);
              auto the_result = at::alpha_dropout(input, p, train);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 35: { // feature_alpha_dropout
          double p = readAttribute<float>("p");
          bool train = readAttribute<int64_t>("train");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 1);
              auto the_result = at::feature_alpha_dropout(input, p, train);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 36: { // abs
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::abs(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 37: { // absolute
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::absolute(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 38: { // angle
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::angle(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 39: { // view_as_real
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::view_as_real(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 40: { // view_as_complex
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::view_as_complex(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 41: { // real
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::real(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 42: { // imag
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::imag(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 43: { // conj
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::conj(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 44: { // acos
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::acos(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 45: { // avg_pool1d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          bool ceil_mode = readAttribute<int64_t>("ceil_mode");
          bool count_include_pad = readAttribute<int64_t>("count_include_pad");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::avg_pool1d(self, kernel_size, stride, padding, ceil_mode, count_include_pad);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 46: { // avg_pool1d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          bool ceil_mode = readAttribute<int64_t>("ceil_mode");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::avg_pool1d(self, kernel_size, stride, padding, ceil_mode);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 47: { // avg_pool1d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::avg_pool1d(self, kernel_size, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 48: { // avg_pool1d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::avg_pool1d(self, kernel_size, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 49: { // avg_pool1d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::avg_pool1d(self, kernel_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 50: { // adaptive_avg_pool1d
          auto output_size = readIntArrayRef("output_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::adaptive_avg_pool1d(self, output_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 51: { // adaptive_max_pool1d
          auto output_size = readIntArrayRef("output_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::adaptive_max_pool1d(self, output_size);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 52: { // add
          at::Scalar alpha = readScalarAttribute("alpha");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::add(self, other, alpha);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 53: { // add
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::add(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 54: { // add
          at::Scalar other = readScalarAttribute("other");
          at::Scalar alpha = readScalarAttribute("alpha");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::add(self, other, alpha);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 55: { // add
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::add(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 56: { // addmv
          at::Scalar beta = readScalarAttribute("beta");
          at::Scalar alpha = readScalarAttribute("alpha");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto mat = peek(1, 3);
              auto vec = peek(2, 3);
              auto the_result = at::addmv(self, mat, vec, beta, alpha);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 57: { // addmv
          at::Scalar beta = readScalarAttribute("beta");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto mat = peek(1, 3);
              auto vec = peek(2, 3);
              auto the_result = at::addmv(self, mat, vec, beta);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 58: { // addmv
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto mat = peek(1, 3);
              auto vec = peek(2, 3);
              auto the_result = at::addmv(self, mat, vec);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 59: { // addr
          at::Scalar beta = readScalarAttribute("beta");
          at::Scalar alpha = readScalarAttribute("alpha");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto vec1 = peek(1, 3);
              auto vec2 = peek(2, 3);
              auto the_result = at::addr(self, vec1, vec2, beta, alpha);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 60: { // addr
          at::Scalar beta = readScalarAttribute("beta");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto vec1 = peek(1, 3);
              auto vec2 = peek(2, 3);
              auto the_result = at::addr(self, vec1, vec2, beta);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 61: { // addr
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto vec1 = peek(1, 3);
              auto vec2 = peek(2, 3);
              auto the_result = at::addr(self, vec1, vec2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 62: { // affine_grid_generator
          auto size = readIntArrayRef("size");
          bool align_corners = readAttribute<int64_t>("align_corners");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto theta = peek(0, 1);
              auto the_result = at::affine_grid_generator(theta, size, align_corners);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 63: { // affine_grid_generator_backward
          auto size = readIntArrayRef("size");
          bool align_corners = readAttribute<int64_t>("align_corners");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 1);
              auto the_result = at::affine_grid_generator_backward(grad, size, align_corners);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 64: { // all
          int64_t dim = readAttribute<int64_t>("dim");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::all(self, dim, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 65: { // all
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::all(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 66: { // allclose
          double rtol = readAttribute<float>("rtol");
          double atol = readAttribute<float>("atol");
          bool equal_nan = readAttribute<int64_t>("equal_nan");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::allclose(self, other, rtol, atol, equal_nan);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 67: { // allclose
          double rtol = readAttribute<float>("rtol");
          double atol = readAttribute<float>("atol");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::allclose(self, other, rtol, atol);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 68: { // allclose
          double rtol = readAttribute<float>("rtol");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::allclose(self, other, rtol);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 69: { // allclose
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::allclose(self, other);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 70: { // any
          int64_t dim = readAttribute<int64_t>("dim");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::any(self, dim, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 71: { // any
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::any(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 72: { // _dim_arange
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto like = peek(0, 1);
              auto the_result = at::_dim_arange(like, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 73: { // argmax
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::argmax(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 74: { // argmin
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::argmin(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 75: { // acosh
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::acosh(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 76: { // asinh
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::asinh(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 77: { // atanh
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::atanh(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 78: { // as_strided
          auto size = readIntArrayRef("size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::as_strided(self, size, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 79: { // asin
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::asin(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 80: { // atan
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::atan(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 81: { // baddbmm
          at::Scalar beta = readScalarAttribute("beta");
          at::Scalar alpha = readScalarAttribute("alpha");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto batch1 = peek(1, 3);
              auto batch2 = peek(2, 3);
              auto the_result = at::baddbmm(self, batch1, batch2, beta, alpha);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 82: { // baddbmm
          at::Scalar beta = readScalarAttribute("beta");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto batch1 = peek(1, 3);
              auto batch2 = peek(2, 3);
              auto the_result = at::baddbmm(self, batch1, batch2, beta);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 83: { // baddbmm
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto batch1 = peek(1, 3);
              auto batch2 = peek(2, 3);
              auto the_result = at::baddbmm(self, batch1, batch2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 84: { // batch_norm
          bool training = readAttribute<int64_t>("training");
          double momentum = readAttribute<float>("momentum");
          double eps = readAttribute<float>("eps");
          bool cudnn_enabled = readAttribute<int64_t>("cudnn_enabled");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 5);
              auto weight = peek(1, 5);
              auto bias = peek(2, 5);
              auto running_mean = peek(3, 5);
              auto running_var = peek(4, 5);
              auto the_result = at::batch_norm(input, weight, bias, running_mean, running_var, training, momentum, eps, cudnn_enabled);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 85: { // quantized_batch_norm
          double eps = readAttribute<float>("eps");
          double output_scale = readAttribute<float>("output_scale");
          int64_t output_zero_point = readAttribute<int64_t>("output_zero_point");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 5);
              auto weight = peek(1, 5);
              auto bias = peek(2, 5);
              auto mean = peek(3, 5);
              auto var = peek(4, 5);
              auto the_result = at::quantized_batch_norm(input, weight, bias, mean, var, eps, output_scale, output_zero_point);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 86: { // _batch_norm_impl_index
          bool training = readAttribute<int64_t>("training");
          double momentum = readAttribute<float>("momentum");
          double eps = readAttribute<float>("eps");
          bool cudnn_enabled = readAttribute<int64_t>("cudnn_enabled");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 5);
              auto weight = peek(1, 5);
              auto bias = peek(2, 5);
              auto running_mean = peek(3, 5);
              auto running_var = peek(4, 5);
              auto the_result = at::_batch_norm_impl_index(input, weight, bias, running_mean, running_var, training, momentum, eps, cudnn_enabled);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
                if(OutputSize() > 4) {assignToValue<int64_t>(Output(4),std::get<4>(the_result));}
              return true;
          };
      } break;
      case 87: { // _batch_norm_impl_index_backward
          int64_t impl_index = readAttribute<int64_t>("impl_index");
          bool train = readAttribute<int64_t>("train");
          double eps = readAttribute<float>("eps");
          auto output_mask = readBoolMask<3>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 8);
              auto grad_output = peek(1, 8);
              auto weight = peek(2, 8);
              auto running_mean = peek(3, 8);
              auto running_var = peek(4, 8);
              auto save_mean = peek(5, 8);
              auto save_var_transform = peek(6, 8);
              auto reservedSpace = peek(7, 8);
              auto the_result = at::_batch_norm_impl_index_backward(impl_index, input, grad_output, weight, running_mean, running_var, save_mean, save_var_transform, train, eps, output_mask, reservedSpace);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 88: { // bernoulli
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::bernoulli(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 89: { // bernoulli
          double p = readAttribute<float>("p");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::bernoulli(self, p);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 90: { // bilinear
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input1 = peek(0, 4);
              auto input2 = peek(1, 4);
              auto weight = peek(2, 4);
              auto bias = peek(3, 4);
              auto the_result = at::bilinear(input1, input2, weight, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 91: { // binary_cross_entropy
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto target = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::binary_cross_entropy(self, target, weight, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 92: { // binary_cross_entropy
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto target = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::binary_cross_entropy(self, target, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 93: { // binary_cross_entropy
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::binary_cross_entropy(self, target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 94: { // binary_cross_entropy_backward
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 4);
              auto self = peek(1, 4);
              auto target = peek(2, 4);
              auto weight = peek(3, 4);
              auto the_result = at::binary_cross_entropy_backward(grad_output, self, target, weight, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 95: { // binary_cross_entropy_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 4);
              auto self = peek(1, 4);
              auto target = peek(2, 4);
              auto weight = peek(3, 4);
              auto the_result = at::binary_cross_entropy_backward(grad_output, self, target, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 96: { // binary_cross_entropy_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto target = peek(2, 3);
              auto the_result = at::binary_cross_entropy_backward(grad_output, self, target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 97: { // binary_cross_entropy_with_logits
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 4);
              auto target = peek(1, 4);
              auto weight = peek(2, 4);
              auto pos_weight = peek(3, 4);
              auto the_result = at::binary_cross_entropy_with_logits(self, target, weight, pos_weight, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 98: { // binary_cross_entropy_with_logits
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 4);
              auto target = peek(1, 4);
              auto weight = peek(2, 4);
              auto pos_weight = peek(3, 4);
              auto the_result = at::binary_cross_entropy_with_logits(self, target, weight, pos_weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 99: { // binary_cross_entropy_with_logits
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto target = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::binary_cross_entropy_with_logits(self, target, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 100: { // binary_cross_entropy_with_logits
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::binary_cross_entropy_with_logits(self, target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 101: { // binary_cross_entropy_with_logits_backward
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 5);
              auto self = peek(1, 5);
              auto target = peek(2, 5);
              auto weight = peek(3, 5);
              auto pos_weight = peek(4, 5);
              auto the_result = at::binary_cross_entropy_with_logits_backward(grad_output, self, target, weight, pos_weight, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 102: { // binary_cross_entropy_with_logits_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 5);
              auto self = peek(1, 5);
              auto target = peek(2, 5);
              auto weight = peek(3, 5);
              auto pos_weight = peek(4, 5);
              auto the_result = at::binary_cross_entropy_with_logits_backward(grad_output, self, target, weight, pos_weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 103: { // binary_cross_entropy_with_logits_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 4);
              auto self = peek(1, 4);
              auto target = peek(2, 4);
              auto weight = peek(3, 4);
              auto the_result = at::binary_cross_entropy_with_logits_backward(grad_output, self, target, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 104: { // binary_cross_entropy_with_logits_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto target = peek(2, 3);
              auto the_result = at::binary_cross_entropy_with_logits_backward(grad_output, self, target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 105: { // bincount
          int64_t minlength = readAttribute<int64_t>("minlength");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto weights = peek(1, 2);
              auto the_result = at::bincount(self, weights, minlength);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 106: { // bincount
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto weights = peek(1, 2);
              auto the_result = at::bincount(self, weights);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 107: { // bincount
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::bincount(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 108: { // bitwise_not
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::bitwise_not(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 109: { // logical_not
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::logical_not(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 110: { // logical_xor
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::logical_xor(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 111: { // logical_and
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::logical_and(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 112: { // logical_or
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::logical_or(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 113: { // bmm
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto mat2 = peek(1, 2);
              auto the_result = at::bmm(self, mat2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 114: { // _bmm
          bool deterministic = readAttribute<int64_t>("deterministic");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto mat2 = peek(1, 2);
              auto the_result = at::_bmm(self, mat2, deterministic);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 115: { // _bmm
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto mat2 = peek(1, 2);
              auto the_result = at::_bmm(self, mat2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 116: { // broadcast_tensors
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto tensors = peekSlice(0, InputSize() - 0, InputSize());
              auto the_result = at::broadcast_tensors(tensors);
                if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
              return true;
          };
      } break;
      case 117: { // cat
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto tensors = peekSlice(0, InputSize() - 0, InputSize());
              auto the_result = at::cat(tensors, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 118: { // cat
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto tensors = peekSlice(0, InputSize() - 0, InputSize());
              auto the_result = at::cat(tensors);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 119: { // block_diag
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto tensors = peekSlice(0, InputSize() - 0, InputSize());
              auto the_result = at::block_diag(tensors);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 120: { // ceil
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::ceil(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 121: { // chain_matmul
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto matrices = peekSlice(0, InputSize() - 0, InputSize());
              auto the_result = at::chain_matmul(matrices);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 122: { // chunk
          int64_t chunks = readAttribute<int64_t>("chunks");
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::chunk(self, chunks, dim);
                if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
              return true;
          };
      } break;
      case 123: { // chunk
          int64_t chunks = readAttribute<int64_t>("chunks");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::chunk(self, chunks);
                if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
              return true;
          };
      } break;
      case 124: { // clamp
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::clamp(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 125: { // clamp_max
          at::Scalar max = readScalarAttribute("max");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::clamp_max(self, max);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 126: { // clamp_min
          at::Scalar min = readScalarAttribute("min");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::clamp_min(self, min);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 127: { // cudnn_is_acceptable
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::cudnn_is_acceptable(self);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 128: { // constant_pad_nd
          auto pad = readIntArrayRef("pad");
          at::Scalar value = readScalarAttribute("value");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::constant_pad_nd(self, pad, value);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 129: { // constant_pad_nd
          auto pad = readIntArrayRef("pad");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::constant_pad_nd(self, pad);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 130: { // contiguous
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.contiguous();
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 131: { // convolution
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          bool transposed = readAttribute<int64_t>("transposed");
          auto output_padding = readIntArrayRef("output_padding");
          int64_t groups = readAttribute<int64_t>("groups");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::convolution(input, weight, bias, stride, padding, dilation, transposed, output_padding, groups);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 132: { // convolution_overrideable
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          bool transposed = readAttribute<int64_t>("transposed");
          auto output_padding = readIntArrayRef("output_padding");
          int64_t groups = readAttribute<int64_t>("groups");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::convolution_overrideable(input, weight, bias, stride, padding, dilation, transposed, output_padding, groups);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 133: { // convolution_backward_overrideable
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          bool transposed = readAttribute<int64_t>("transposed");
          auto output_padding = readIntArrayRef("output_padding");
          int64_t groups = readAttribute<int64_t>("groups");
          auto output_mask = readBoolMask<3>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto input = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::convolution_backward_overrideable(grad_output, input, weight, stride, padding, dilation, transposed, output_padding, groups, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 134: { // _convolution
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          bool transposed = readAttribute<int64_t>("transposed");
          auto output_padding = readIntArrayRef("output_padding");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          bool cudnn_enabled = readAttribute<int64_t>("cudnn_enabled");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::_convolution(input, weight, bias, stride, padding, dilation, transposed, output_padding, groups, benchmark, deterministic, cudnn_enabled);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 135: { // _convolution_nogroup
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          bool transposed = readAttribute<int64_t>("transposed");
          auto output_padding = readIntArrayRef("output_padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::_convolution_nogroup(input, weight, bias, stride, padding, dilation, transposed, output_padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 136: { // _convolution_double_backward
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          bool transposed = readAttribute<int64_t>("transposed");
          auto output_padding = readIntArrayRef("output_padding");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          bool cudnn_enabled = readAttribute<int64_t>("cudnn_enabled");
          auto output_mask = readBoolMask<3>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto ggI = peek(0, 6);
              auto ggW = peek(1, 6);
              auto ggb = peek(2, 6);
              auto gO = peek(3, 6);
              auto weight = peek(4, 6);
              auto self = peek(5, 6);
              auto the_result = at::_convolution_double_backward(ggI, ggW, ggb, gO, weight, self, stride, padding, dilation, transposed, output_padding, groups, benchmark, deterministic, cudnn_enabled, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 137: { // conv1d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv1d(input, weight, bias, stride, padding, dilation, groups);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 138: { // conv1d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv1d(input, weight, bias, stride, padding, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 139: { // conv1d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv1d(input, weight, bias, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 140: { // conv1d
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv1d(input, weight, bias, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 141: { // conv1d
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv1d(input, weight, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 142: { // conv1d
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::conv1d(input, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 143: { // conv2d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv2d(input, weight, bias, stride, padding, dilation, groups);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 144: { // conv2d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv2d(input, weight, bias, stride, padding, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 145: { // conv2d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv2d(input, weight, bias, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 146: { // conv2d
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv2d(input, weight, bias, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 147: { // conv2d
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv2d(input, weight, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 148: { // conv2d
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::conv2d(input, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 149: { // conv3d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv3d(input, weight, bias, stride, padding, dilation, groups);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 150: { // conv3d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv3d(input, weight, bias, stride, padding, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 151: { // conv3d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv3d(input, weight, bias, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 152: { // conv3d
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv3d(input, weight, bias, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 153: { // conv3d
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv3d(input, weight, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 154: { // conv3d
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::conv3d(input, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 155: { // conv_tbc
          int64_t pad = readAttribute<int64_t>("pad");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_tbc(self, weight, bias, pad);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 156: { // conv_tbc
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_tbc(self, weight, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 157: { // conv_tbc_backward
          int64_t pad = readAttribute<int64_t>("pad");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 4);
              auto input = peek(1, 4);
              auto weight = peek(2, 4);
              auto bias = peek(3, 4);
              auto the_result = at::conv_tbc_backward(self, input, weight, bias, pad);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 158: { // conv_transpose1d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          int64_t groups = readAttribute<int64_t>("groups");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_transpose1d(input, weight, bias, stride, padding, output_padding, groups, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 159: { // conv_transpose1d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          int64_t groups = readAttribute<int64_t>("groups");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_transpose1d(input, weight, bias, stride, padding, output_padding, groups);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 160: { // conv_transpose1d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_transpose1d(input, weight, bias, stride, padding, output_padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 161: { // conv_transpose1d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_transpose1d(input, weight, bias, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 162: { // conv_transpose1d
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_transpose1d(input, weight, bias, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 163: { // conv_transpose1d
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_transpose1d(input, weight, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 164: { // conv_transpose1d
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::conv_transpose1d(input, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 165: { // conv_transpose2d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          int64_t groups = readAttribute<int64_t>("groups");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_transpose2d(input, weight, bias, stride, padding, output_padding, groups, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 166: { // conv_transpose2d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          int64_t groups = readAttribute<int64_t>("groups");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_transpose2d(input, weight, bias, stride, padding, output_padding, groups);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 167: { // conv_transpose2d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_transpose2d(input, weight, bias, stride, padding, output_padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 168: { // conv_transpose2d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_transpose2d(input, weight, bias, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 169: { // conv_transpose2d
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_transpose2d(input, weight, bias, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 170: { // conv_transpose2d
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_transpose2d(input, weight, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 171: { // conv_transpose2d
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::conv_transpose2d(input, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 172: { // conv_transpose3d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          int64_t groups = readAttribute<int64_t>("groups");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_transpose3d(input, weight, bias, stride, padding, output_padding, groups, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 173: { // conv_transpose3d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          int64_t groups = readAttribute<int64_t>("groups");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_transpose3d(input, weight, bias, stride, padding, output_padding, groups);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 174: { // conv_transpose3d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_transpose3d(input, weight, bias, stride, padding, output_padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 175: { // conv_transpose3d
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_transpose3d(input, weight, bias, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 176: { // conv_transpose3d
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_transpose3d(input, weight, bias, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 177: { // conv_transpose3d
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::conv_transpose3d(input, weight, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 178: { // conv_transpose3d
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::conv_transpose3d(input, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 179: { // _copy_from
          bool non_blocking = readAttribute<int64_t>("non_blocking");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto dst = peek(1, 2);
              auto the_result = at::_copy_from(self, dst, non_blocking);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 180: { // _copy_from
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto dst = peek(1, 2);
              auto the_result = at::_copy_from(self, dst);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 181: { // cos
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::cos(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 182: { // cosh
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::cosh(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 183: { // cosine_embedding_loss
          double margin = readAttribute<float>("margin");
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input1 = peek(0, 3);
              auto input2 = peek(1, 3);
              auto target = peek(2, 3);
              auto the_result = at::cosine_embedding_loss(input1, input2, target, margin, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 184: { // cosine_embedding_loss
          double margin = readAttribute<float>("margin");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input1 = peek(0, 3);
              auto input2 = peek(1, 3);
              auto target = peek(2, 3);
              auto the_result = at::cosine_embedding_loss(input1, input2, target, margin);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 185: { // cosine_embedding_loss
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input1 = peek(0, 3);
              auto input2 = peek(1, 3);
              auto target = peek(2, 3);
              auto the_result = at::cosine_embedding_loss(input1, input2, target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 186: { // cudnn_affine_grid_generator
          int64_t N = readAttribute<int64_t>("N");
          int64_t C = readAttribute<int64_t>("C");
          int64_t H = readAttribute<int64_t>("H");
          int64_t W = readAttribute<int64_t>("W");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto theta = peek(0, 1);
              auto the_result = at::cudnn_affine_grid_generator(theta, N, C, H, W);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 187: { // cudnn_affine_grid_generator_backward
          int64_t N = readAttribute<int64_t>("N");
          int64_t C = readAttribute<int64_t>("C");
          int64_t H = readAttribute<int64_t>("H");
          int64_t W = readAttribute<int64_t>("W");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 1);
              auto the_result = at::cudnn_affine_grid_generator_backward(grad, N, C, H, W);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 188: { // cudnn_batch_norm
          bool training = readAttribute<int64_t>("training");
          double exponential_average_factor = readAttribute<float>("exponential_average_factor");
          double epsilon = readAttribute<float>("epsilon");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 5);
              auto weight = peek(1, 5);
              auto bias = peek(2, 5);
              auto running_mean = peek(3, 5);
              auto running_var = peek(4, 5);
              auto the_result = at::cudnn_batch_norm(input, weight, bias, running_mean, running_var, training, exponential_average_factor, epsilon);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
              return true;
          };
      } break;
      case 189: { // cudnn_batch_norm_backward
          double epsilon = readAttribute<float>("epsilon");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 8);
              auto grad_output = peek(1, 8);
              auto weight = peek(2, 8);
              auto running_mean = peek(3, 8);
              auto running_var = peek(4, 8);
              auto save_mean = peek(5, 8);
              auto save_var = peek(6, 8);
              auto reserveSpace = peek(7, 8);
              auto the_result = at::cudnn_batch_norm_backward(input, grad_output, weight, running_mean, running_var, save_mean, save_var, epsilon, reserveSpace);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 190: { // cudnn_convolution
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::cudnn_convolution(self, weight, bias, padding, stride, dilation, groups, benchmark, deterministic);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 191: { // cudnn_convolution
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::cudnn_convolution(self, weight, padding, stride, dilation, groups, benchmark, deterministic);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 192: { // cudnn_convolution_backward_input
          auto self_size = readIntArrayRef("self_size");
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::cudnn_convolution_backward_input(self_size, grad_output, weight, padding, stride, dilation, groups, benchmark, deterministic);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 193: { // cudnn_convolution_backward
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          auto output_mask = readBoolMask<2>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto grad_output = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::cudnn_convolution_backward(self, grad_output, weight, padding, stride, dilation, groups, benchmark, deterministic, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 194: { // cudnn_convolution_backward_weight
          auto weight_size = readIntArrayRef("weight_size");
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::cudnn_convolution_backward_weight(weight_size, grad_output, self, padding, stride, dilation, groups, benchmark, deterministic);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 195: { // cudnn_convolution_transpose
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::cudnn_convolution_transpose(self, weight, bias, padding, output_padding, stride, dilation, groups, benchmark, deterministic);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 196: { // cudnn_convolution_transpose
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::cudnn_convolution_transpose(self, weight, padding, output_padding, stride, dilation, groups, benchmark, deterministic);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 197: { // cudnn_convolution_transpose_backward
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          auto output_mask = readBoolMask<2>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto grad_output = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::cudnn_convolution_transpose_backward(self, grad_output, weight, padding, output_padding, stride, dilation, groups, benchmark, deterministic, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 198: { // cudnn_convolution_transpose_backward_input
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::cudnn_convolution_transpose_backward_input(grad_output, weight, padding, stride, dilation, groups, benchmark, deterministic);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 199: { // cudnn_convolution_transpose_backward_weight
          auto weight_size = readIntArrayRef("weight_size");
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::cudnn_convolution_transpose_backward_weight(weight_size, grad_output, self, padding, stride, dilation, groups, benchmark, deterministic);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 200: { // cudnn_grid_sampler
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto grid = peek(1, 2);
              auto the_result = at::cudnn_grid_sampler(self, grid);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 201: { // cudnn_grid_sampler_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto grid = peek(1, 3);
              auto grad_output = peek(2, 3);
              auto the_result = at::cudnn_grid_sampler_backward(self, grid, grad_output);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 202: { // cummax
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::cummax(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 203: { // cummin
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::cummin(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 204: { // cumprod
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::cumprod(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 205: { // cumsum
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::cumsum(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 206: { // ctc_loss
          auto input_lengths = readIntArrayRef("input_lengths");
          auto target_lengths = readIntArrayRef("target_lengths");
          int64_t blank = readAttribute<int64_t>("blank");
          int64_t reduction = readAttribute<int64_t>("reduction");
          bool zero_infinity = readAttribute<int64_t>("zero_infinity");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto log_probs = peek(0, 2);
              auto targets = peek(1, 2);
              auto the_result = at::ctc_loss(log_probs, targets, input_lengths, target_lengths, blank, reduction, zero_infinity);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 207: { // ctc_loss
          auto input_lengths = readIntArrayRef("input_lengths");
          auto target_lengths = readIntArrayRef("target_lengths");
          int64_t blank = readAttribute<int64_t>("blank");
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto log_probs = peek(0, 2);
              auto targets = peek(1, 2);
              auto the_result = at::ctc_loss(log_probs, targets, input_lengths, target_lengths, blank, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 208: { // ctc_loss
          auto input_lengths = readIntArrayRef("input_lengths");
          auto target_lengths = readIntArrayRef("target_lengths");
          int64_t blank = readAttribute<int64_t>("blank");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto log_probs = peek(0, 2);
              auto targets = peek(1, 2);
              auto the_result = at::ctc_loss(log_probs, targets, input_lengths, target_lengths, blank);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 209: { // ctc_loss
          auto input_lengths = readIntArrayRef("input_lengths");
          auto target_lengths = readIntArrayRef("target_lengths");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto log_probs = peek(0, 2);
              auto targets = peek(1, 2);
              auto the_result = at::ctc_loss(log_probs, targets, input_lengths, target_lengths);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 210: { // ctc_loss
          int64_t blank = readAttribute<int64_t>("blank");
          int64_t reduction = readAttribute<int64_t>("reduction");
          bool zero_infinity = readAttribute<int64_t>("zero_infinity");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto log_probs = peek(0, 4);
              auto targets = peek(1, 4);
              auto input_lengths = peek(2, 4);
              auto target_lengths = peek(3, 4);
              auto the_result = at::ctc_loss(log_probs, targets, input_lengths, target_lengths, blank, reduction, zero_infinity);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 211: { // ctc_loss
          int64_t blank = readAttribute<int64_t>("blank");
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto log_probs = peek(0, 4);
              auto targets = peek(1, 4);
              auto input_lengths = peek(2, 4);
              auto target_lengths = peek(3, 4);
              auto the_result = at::ctc_loss(log_probs, targets, input_lengths, target_lengths, blank, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 212: { // ctc_loss
          int64_t blank = readAttribute<int64_t>("blank");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto log_probs = peek(0, 4);
              auto targets = peek(1, 4);
              auto input_lengths = peek(2, 4);
              auto target_lengths = peek(3, 4);
              auto the_result = at::ctc_loss(log_probs, targets, input_lengths, target_lengths, blank);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 213: { // ctc_loss
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto log_probs = peek(0, 4);
              auto targets = peek(1, 4);
              auto input_lengths = peek(2, 4);
              auto target_lengths = peek(3, 4);
              auto the_result = at::ctc_loss(log_probs, targets, input_lengths, target_lengths);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 214: { // _ctc_loss
          auto input_lengths = readIntArrayRef("input_lengths");
          auto target_lengths = readIntArrayRef("target_lengths");
          int64_t blank = readAttribute<int64_t>("blank");
          bool zero_infinity = readAttribute<int64_t>("zero_infinity");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto log_probs = peek(0, 2);
              auto targets = peek(1, 2);
              auto the_result = at::_ctc_loss(log_probs, targets, input_lengths, target_lengths, blank, zero_infinity);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 215: { // _ctc_loss
          auto input_lengths = readIntArrayRef("input_lengths");
          auto target_lengths = readIntArrayRef("target_lengths");
          int64_t blank = readAttribute<int64_t>("blank");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto log_probs = peek(0, 2);
              auto targets = peek(1, 2);
              auto the_result = at::_ctc_loss(log_probs, targets, input_lengths, target_lengths, blank);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 216: { // _ctc_loss
          auto input_lengths = readIntArrayRef("input_lengths");
          auto target_lengths = readIntArrayRef("target_lengths");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto log_probs = peek(0, 2);
              auto targets = peek(1, 2);
              auto the_result = at::_ctc_loss(log_probs, targets, input_lengths, target_lengths);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 217: { // _ctc_loss_backward
          auto input_lengths = readIntArrayRef("input_lengths");
          auto target_lengths = readIntArrayRef("target_lengths");
          int64_t blank = readAttribute<int64_t>("blank");
          bool zero_infinity = readAttribute<int64_t>("zero_infinity");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 5);
              auto log_probs = peek(1, 5);
              auto targets = peek(2, 5);
              auto neg_log_likelihood = peek(3, 5);
              auto log_alpha = peek(4, 5);
              auto the_result = at::_ctc_loss_backward(grad, log_probs, targets, input_lengths, target_lengths, neg_log_likelihood, log_alpha, blank, zero_infinity);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 218: { // _ctc_loss_backward
          auto input_lengths = readIntArrayRef("input_lengths");
          auto target_lengths = readIntArrayRef("target_lengths");
          int64_t blank = readAttribute<int64_t>("blank");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 5);
              auto log_probs = peek(1, 5);
              auto targets = peek(2, 5);
              auto neg_log_likelihood = peek(3, 5);
              auto log_alpha = peek(4, 5);
              auto the_result = at::_ctc_loss_backward(grad, log_probs, targets, input_lengths, target_lengths, neg_log_likelihood, log_alpha, blank);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 219: { // det
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::det(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 220: { // diag_embed
          int64_t offset = readAttribute<int64_t>("offset");
          int64_t dim1 = readAttribute<int64_t>("dim1");
          int64_t dim2 = readAttribute<int64_t>("dim2");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::diag_embed(self, offset, dim1, dim2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 221: { // diag_embed
          int64_t offset = readAttribute<int64_t>("offset");
          int64_t dim1 = readAttribute<int64_t>("dim1");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::diag_embed(self, offset, dim1);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 222: { // diag_embed
          int64_t offset = readAttribute<int64_t>("offset");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::diag_embed(self, offset);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 223: { // diag_embed
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::diag_embed(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 224: { // diagflat
          int64_t offset = readAttribute<int64_t>("offset");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::diagflat(self, offset);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 225: { // diagflat
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::diagflat(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 226: { // diagonal
          int64_t offset = readAttribute<int64_t>("offset");
          int64_t dim1 = readAttribute<int64_t>("dim1");
          int64_t dim2 = readAttribute<int64_t>("dim2");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::diagonal(self, offset, dim1, dim2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 227: { // diagonal
          int64_t offset = readAttribute<int64_t>("offset");
          int64_t dim1 = readAttribute<int64_t>("dim1");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::diagonal(self, offset, dim1);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 228: { // diagonal
          int64_t offset = readAttribute<int64_t>("offset");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::diagonal(self, offset);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 229: { // diagonal
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::diagonal(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 230: { // div
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::div(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 231: { // div
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::div(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 232: { // dot
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto tensor = peek(1, 2);
              auto the_result = at::dot(self, tensor);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 233: { // embedding
          int64_t padding_idx = readAttribute<int64_t>("padding_idx");
          bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
          bool sparse = readAttribute<int64_t>("sparse");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto weight = peek(0, 2);
              auto indices = peek(1, 2);
              auto the_result = at::embedding(weight, indices, padding_idx, scale_grad_by_freq, sparse);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 234: { // embedding
          int64_t padding_idx = readAttribute<int64_t>("padding_idx");
          bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto weight = peek(0, 2);
              auto indices = peek(1, 2);
              auto the_result = at::embedding(weight, indices, padding_idx, scale_grad_by_freq);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 235: { // embedding
          int64_t padding_idx = readAttribute<int64_t>("padding_idx");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto weight = peek(0, 2);
              auto indices = peek(1, 2);
              auto the_result = at::embedding(weight, indices, padding_idx);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 236: { // embedding
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto weight = peek(0, 2);
              auto indices = peek(1, 2);
              auto the_result = at::embedding(weight, indices);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 237: { // embedding_backward
          int64_t num_weights = readAttribute<int64_t>("num_weights");
          int64_t padding_idx = readAttribute<int64_t>("padding_idx");
          bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
          bool sparse = readAttribute<int64_t>("sparse");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 2);
              auto indices = peek(1, 2);
              auto the_result = at::embedding_backward(grad, indices, num_weights, padding_idx, scale_grad_by_freq, sparse);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 238: { // embedding_dense_backward
          int64_t num_weights = readAttribute<int64_t>("num_weights");
          int64_t padding_idx = readAttribute<int64_t>("padding_idx");
          bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto indices = peek(1, 2);
              auto the_result = at::embedding_dense_backward(grad_output, indices, num_weights, padding_idx, scale_grad_by_freq);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 239: { // embedding_sparse_backward
          int64_t num_weights = readAttribute<int64_t>("num_weights");
          int64_t padding_idx = readAttribute<int64_t>("padding_idx");
          bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 2);
              auto indices = peek(1, 2);
              auto the_result = at::embedding_sparse_backward(grad, indices, num_weights, padding_idx, scale_grad_by_freq);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 240: { // embedding_bag
          bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
          int64_t mode = readAttribute<int64_t>("mode");
          bool sparse = readAttribute<int64_t>("sparse");
          bool include_last_offset = readAttribute<int64_t>("include_last_offset");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto weight = peek(0, 4);
              auto indices = peek(1, 4);
              auto offsets = peek(2, 4);
              auto per_sample_weights = peek(3, 4);
              auto the_result = at::embedding_bag(weight, indices, offsets, scale_grad_by_freq, mode, sparse, per_sample_weights, include_last_offset);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
              return true;
          };
      } break;
      case 241: { // embedding_bag
          bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
          int64_t mode = readAttribute<int64_t>("mode");
          bool sparse = readAttribute<int64_t>("sparse");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto weight = peek(0, 4);
              auto indices = peek(1, 4);
              auto offsets = peek(2, 4);
              auto per_sample_weights = peek(3, 4);
              auto the_result = at::embedding_bag(weight, indices, offsets, scale_grad_by_freq, mode, sparse, per_sample_weights);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
              return true;
          };
      } break;
      case 242: { // embedding_bag
          bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
          int64_t mode = readAttribute<int64_t>("mode");
          bool sparse = readAttribute<int64_t>("sparse");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto weight = peek(0, 3);
              auto indices = peek(1, 3);
              auto offsets = peek(2, 3);
              auto the_result = at::embedding_bag(weight, indices, offsets, scale_grad_by_freq, mode, sparse);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
              return true;
          };
      } break;
      case 243: { // embedding_bag
          bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
          int64_t mode = readAttribute<int64_t>("mode");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto weight = peek(0, 3);
              auto indices = peek(1, 3);
              auto offsets = peek(2, 3);
              auto the_result = at::embedding_bag(weight, indices, offsets, scale_grad_by_freq, mode);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
              return true;
          };
      } break;
      case 244: { // embedding_bag
          bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto weight = peek(0, 3);
              auto indices = peek(1, 3);
              auto offsets = peek(2, 3);
              auto the_result = at::embedding_bag(weight, indices, offsets, scale_grad_by_freq);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
              return true;
          };
      } break;
      case 245: { // embedding_bag
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto weight = peek(0, 3);
              auto indices = peek(1, 3);
              auto offsets = peek(2, 3);
              auto the_result = at::embedding_bag(weight, indices, offsets);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
              return true;
          };
      } break;
      case 246: { // _embedding_bag
          bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
          int64_t mode = readAttribute<int64_t>("mode");
          bool sparse = readAttribute<int64_t>("sparse");
          bool include_last_offset = readAttribute<int64_t>("include_last_offset");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto weight = peek(0, 4);
              auto indices = peek(1, 4);
              auto offsets = peek(2, 4);
              auto per_sample_weights = peek(3, 4);
              auto the_result = at::_embedding_bag(weight, indices, offsets, scale_grad_by_freq, mode, sparse, per_sample_weights, include_last_offset);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
              return true;
          };
      } break;
      case 247: { // _embedding_bag
          bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
          int64_t mode = readAttribute<int64_t>("mode");
          bool sparse = readAttribute<int64_t>("sparse");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto weight = peek(0, 4);
              auto indices = peek(1, 4);
              auto offsets = peek(2, 4);
              auto per_sample_weights = peek(3, 4);
              auto the_result = at::_embedding_bag(weight, indices, offsets, scale_grad_by_freq, mode, sparse, per_sample_weights);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
              return true;
          };
      } break;
      case 248: { // _embedding_bag
          bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
          int64_t mode = readAttribute<int64_t>("mode");
          bool sparse = readAttribute<int64_t>("sparse");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto weight = peek(0, 3);
              auto indices = peek(1, 3);
              auto offsets = peek(2, 3);
              auto the_result = at::_embedding_bag(weight, indices, offsets, scale_grad_by_freq, mode, sparse);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
              return true;
          };
      } break;
      case 249: { // _embedding_bag
          bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
          int64_t mode = readAttribute<int64_t>("mode");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto weight = peek(0, 3);
              auto indices = peek(1, 3);
              auto offsets = peek(2, 3);
              auto the_result = at::_embedding_bag(weight, indices, offsets, scale_grad_by_freq, mode);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
              return true;
          };
      } break;
      case 250: { // _embedding_bag
          bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto weight = peek(0, 3);
              auto indices = peek(1, 3);
              auto offsets = peek(2, 3);
              auto the_result = at::_embedding_bag(weight, indices, offsets, scale_grad_by_freq);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
              return true;
          };
      } break;
      case 251: { // _embedding_bag
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto weight = peek(0, 3);
              auto indices = peek(1, 3);
              auto offsets = peek(2, 3);
              auto the_result = at::_embedding_bag(weight, indices, offsets);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
              return true;
          };
      } break;
      case 252: { // _embedding_bag_backward
          int64_t num_weights = readAttribute<int64_t>("num_weights");
          bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
          int64_t mode = readAttribute<int64_t>("mode");
          bool sparse = readAttribute<int64_t>("sparse");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 7);
              auto indices = peek(1, 7);
              auto offsets = peek(2, 7);
              auto offset2bag = peek(3, 7);
              auto bag_size = peek(4, 7);
              auto maximum_indices = peek(5, 7);
              auto per_sample_weights = peek(6, 7);
              auto the_result = at::_embedding_bag_backward(grad, indices, offsets, offset2bag, bag_size, maximum_indices, num_weights, scale_grad_by_freq, mode, sparse, per_sample_weights);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 253: { // _embedding_bag_sparse_backward
          int64_t num_weights = readAttribute<int64_t>("num_weights");
          bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
          int64_t mode = readAttribute<int64_t>("mode");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 6);
              auto indices = peek(1, 6);
              auto offsets = peek(2, 6);
              auto offset2bag = peek(3, 6);
              auto bag_size = peek(4, 6);
              auto per_sample_weights = peek(5, 6);
              auto the_result = at::_embedding_bag_sparse_backward(grad, indices, offsets, offset2bag, bag_size, num_weights, scale_grad_by_freq, mode, per_sample_weights);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 254: { // _embedding_bag_dense_backward
          int64_t num_weights = readAttribute<int64_t>("num_weights");
          bool scale_grad_by_freq = readAttribute<int64_t>("scale_grad_by_freq");
          int64_t mode = readAttribute<int64_t>("mode");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 7);
              auto indices = peek(1, 7);
              auto offsets = peek(2, 7);
              auto offset2bag = peek(3, 7);
              auto bag_size = peek(4, 7);
              auto maximum_indices = peek(5, 7);
              auto per_sample_weights = peek(6, 7);
              auto the_result = at::_embedding_bag_dense_backward(grad, indices, offsets, offset2bag, bag_size, maximum_indices, num_weights, scale_grad_by_freq, mode, per_sample_weights);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 255: { // _embedding_bag_per_sample_weights_backward
          int64_t mode = readAttribute<int64_t>("mode");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 5);
              auto weight = peek(1, 5);
              auto indices = peek(2, 5);
              auto offsets = peek(3, 5);
              auto offset2bag = peek(4, 5);
              auto the_result = at::_embedding_bag_per_sample_weights_backward(grad, weight, indices, offsets, offset2bag, mode);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 256: { // empty_quantized
          auto size = readIntArrayRef("size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto qtensor = peek(0, 1);
              auto the_result = at::empty_quantized(size, qtensor);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 257: { // erf
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::erf(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 258: { // erfc
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::erfc(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 259: { // exp
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::exp(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 260: { // expm1
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::expm1(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 261: { // expand
          auto size = readIntArrayRef("size");
          bool implicit = readAttribute<int64_t>("implicit");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.expand(size, implicit);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 262: { // expand
          auto size = readIntArrayRef("size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.expand(size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 263: { // expand_as
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = self.expand_as(other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 264: { // flatten
          int64_t start_dim = readAttribute<int64_t>("start_dim");
          int64_t end_dim = readAttribute<int64_t>("end_dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::flatten(self, start_dim, end_dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 265: { // flatten
          int64_t start_dim = readAttribute<int64_t>("start_dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::flatten(self, start_dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 266: { // flatten
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::flatten(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 267: { // floor
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::floor(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 268: { // floor_divide
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::floor_divide(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 269: { // floor_divide
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::floor_divide(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 270: { // frac
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::frac(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 271: { // grid_sampler
          int64_t interpolation_mode = readAttribute<int64_t>("interpolation_mode");
          int64_t padding_mode = readAttribute<int64_t>("padding_mode");
          bool align_corners = readAttribute<int64_t>("align_corners");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 2);
              auto grid = peek(1, 2);
              auto the_result = at::grid_sampler(input, grid, interpolation_mode, padding_mode, align_corners);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 272: { // grid_sampler_2d
          int64_t interpolation_mode = readAttribute<int64_t>("interpolation_mode");
          int64_t padding_mode = readAttribute<int64_t>("padding_mode");
          bool align_corners = readAttribute<int64_t>("align_corners");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 2);
              auto grid = peek(1, 2);
              auto the_result = at::grid_sampler_2d(input, grid, interpolation_mode, padding_mode, align_corners);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 273: { // grid_sampler_2d_backward
          int64_t interpolation_mode = readAttribute<int64_t>("interpolation_mode");
          int64_t padding_mode = readAttribute<int64_t>("padding_mode");
          bool align_corners = readAttribute<int64_t>("align_corners");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto input = peek(1, 3);
              auto grid = peek(2, 3);
              auto the_result = at::grid_sampler_2d_backward(grad_output, input, grid, interpolation_mode, padding_mode, align_corners);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 274: { // grid_sampler_3d
          int64_t interpolation_mode = readAttribute<int64_t>("interpolation_mode");
          int64_t padding_mode = readAttribute<int64_t>("padding_mode");
          bool align_corners = readAttribute<int64_t>("align_corners");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 2);
              auto grid = peek(1, 2);
              auto the_result = at::grid_sampler_3d(input, grid, interpolation_mode, padding_mode, align_corners);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 275: { // grid_sampler_3d_backward
          int64_t interpolation_mode = readAttribute<int64_t>("interpolation_mode");
          int64_t padding_mode = readAttribute<int64_t>("padding_mode");
          bool align_corners = readAttribute<int64_t>("align_corners");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto input = peek(1, 3);
              auto grid = peek(2, 3);
              auto the_result = at::grid_sampler_3d_backward(grad_output, input, grid, interpolation_mode, padding_mode, align_corners);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 276: { // hinge_embedding_loss
          double margin = readAttribute<float>("margin");
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::hinge_embedding_loss(self, target, margin, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 277: { // hinge_embedding_loss
          double margin = readAttribute<float>("margin");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::hinge_embedding_loss(self, target, margin);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 278: { // hinge_embedding_loss
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::hinge_embedding_loss(self, target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 279: { // ger
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto vec2 = peek(1, 2);
              auto the_result = at::ger(self, vec2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 280: { // group_norm
          int64_t num_groups = readAttribute<int64_t>("num_groups");
          double eps = readAttribute<float>("eps");
          bool cudnn_enabled = readAttribute<int64_t>("cudnn_enabled");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::group_norm(input, num_groups, weight, bias, eps, cudnn_enabled);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 281: { // group_norm
          int64_t num_groups = readAttribute<int64_t>("num_groups");
          double eps = readAttribute<float>("eps");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::group_norm(input, num_groups, weight, bias, eps);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 282: { // group_norm
          int64_t num_groups = readAttribute<int64_t>("num_groups");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::group_norm(input, num_groups, weight, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 283: { // group_norm
          int64_t num_groups = readAttribute<int64_t>("num_groups");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::group_norm(input, num_groups, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 284: { // group_norm
          int64_t num_groups = readAttribute<int64_t>("num_groups");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 1);
              auto the_result = at::group_norm(input, num_groups);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 285: { // native_group_norm
          int64_t N = readAttribute<int64_t>("N");
          int64_t C = readAttribute<int64_t>("C");
          int64_t HxW = readAttribute<int64_t>("HxW");
          int64_t group = readAttribute<int64_t>("group");
          double eps = readAttribute<float>("eps");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::native_group_norm(input, weight, bias, N, C, HxW, group, eps);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 286: { // native_group_norm_backward
          int64_t N = readAttribute<int64_t>("N");
          int64_t C = readAttribute<int64_t>("C");
          int64_t HxW = readAttribute<int64_t>("HxW");
          int64_t group = readAttribute<int64_t>("group");
          auto output_mask = readBoolMask<3>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_out = peek(0, 5);
              auto input = peek(1, 5);
              auto mean = peek(2, 5);
              auto rstd = peek(3, 5);
              auto weight = peek(4, 5);
              auto the_result = at::native_group_norm_backward(grad_out, input, mean, rstd, weight, N, C, HxW, group, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 287: { // fft
          int64_t signal_ndim = readAttribute<int64_t>("signal_ndim");
          bool normalized = readAttribute<int64_t>("normalized");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::fft(self, signal_ndim, normalized);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 288: { // fft
          int64_t signal_ndim = readAttribute<int64_t>("signal_ndim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::fft(self, signal_ndim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 289: { // ifft
          int64_t signal_ndim = readAttribute<int64_t>("signal_ndim");
          bool normalized = readAttribute<int64_t>("normalized");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::ifft(self, signal_ndim, normalized);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 290: { // ifft
          int64_t signal_ndim = readAttribute<int64_t>("signal_ndim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::ifft(self, signal_ndim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 291: { // rfft
          int64_t signal_ndim = readAttribute<int64_t>("signal_ndim");
          bool normalized = readAttribute<int64_t>("normalized");
          bool onesided = readAttribute<int64_t>("onesided");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::rfft(self, signal_ndim, normalized, onesided);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 292: { // rfft
          int64_t signal_ndim = readAttribute<int64_t>("signal_ndim");
          bool normalized = readAttribute<int64_t>("normalized");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::rfft(self, signal_ndim, normalized);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 293: { // rfft
          int64_t signal_ndim = readAttribute<int64_t>("signal_ndim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::rfft(self, signal_ndim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 294: { // irfft
          int64_t signal_ndim = readAttribute<int64_t>("signal_ndim");
          bool normalized = readAttribute<int64_t>("normalized");
          bool onesided = readAttribute<int64_t>("onesided");
          auto signal_sizes = readIntArrayRef("signal_sizes");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::irfft(self, signal_ndim, normalized, onesided, signal_sizes);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 295: { // irfft
          int64_t signal_ndim = readAttribute<int64_t>("signal_ndim");
          bool normalized = readAttribute<int64_t>("normalized");
          bool onesided = readAttribute<int64_t>("onesided");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::irfft(self, signal_ndim, normalized, onesided);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 296: { // irfft
          int64_t signal_ndim = readAttribute<int64_t>("signal_ndim");
          bool normalized = readAttribute<int64_t>("normalized");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::irfft(self, signal_ndim, normalized);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 297: { // irfft
          int64_t signal_ndim = readAttribute<int64_t>("signal_ndim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::irfft(self, signal_ndim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 298: { // _fft_with_size
          int64_t signal_ndim = readAttribute<int64_t>("signal_ndim");
          bool complex_input = readAttribute<int64_t>("complex_input");
          bool complex_output = readAttribute<int64_t>("complex_output");
          bool inverse = readAttribute<int64_t>("inverse");
          auto checked_signal_sizes = readIntArrayRef("checked_signal_sizes");
          bool normalized = readAttribute<int64_t>("normalized");
          bool onesided = readAttribute<int64_t>("onesided");
          auto output_sizes = readIntArrayRef("output_sizes");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_fft_with_size(self, signal_ndim, complex_input, complex_output, inverse, checked_signal_sizes, normalized, onesided, output_sizes);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 299: { // _cufft_get_plan_cache_size
          int64_t device_index = readAttribute<int64_t>("device_index");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
      
              auto the_result = at::_cufft_get_plan_cache_size(device_index);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 300: { // _cufft_get_plan_cache_max_size
          int64_t device_index = readAttribute<int64_t>("device_index");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
      
              auto the_result = at::_cufft_get_plan_cache_max_size(device_index);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 301: { // index
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, InputSize());
              auto indices = peekSlice(1, InputSize() - 1, InputSize());
              auto the_result = internal::index_with_uint8_handling(self,indices);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 302: { // index_copy
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto index = peek(1, 3);
              auto source = peek(2, 3);
              auto the_result = at::index_copy(self, dim, index, source);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 303: { // index_put
          bool accumulate = readAttribute<int64_t>("accumulate");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, InputSize());
              auto indices = peekSlice(1, InputSize() - 2, InputSize());
              auto values = peek(1, 2);
              auto the_result = at::index_put(self, indices, values, accumulate);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 304: { // index_put
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, InputSize());
              auto indices = peekSlice(1, InputSize() - 2, InputSize());
              auto values = peek(1, 2);
              auto the_result = at::index_put(self, indices, values);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 305: { // instance_norm
          bool use_input_stats = readAttribute<int64_t>("use_input_stats");
          double momentum = readAttribute<float>("momentum");
          double eps = readAttribute<float>("eps");
          bool cudnn_enabled = readAttribute<int64_t>("cudnn_enabled");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 5);
              auto weight = peek(1, 5);
              auto bias = peek(2, 5);
              auto running_mean = peek(3, 5);
              auto running_var = peek(4, 5);
              auto the_result = at::instance_norm(input, weight, bias, running_mean, running_var, use_input_stats, momentum, eps, cudnn_enabled);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 306: { // inverse
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::inverse(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 307: { // _inverse_helper
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_inverse_helper(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 308: { // isclose
          double rtol = readAttribute<float>("rtol");
          double atol = readAttribute<float>("atol");
          bool equal_nan = readAttribute<int64_t>("equal_nan");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::isclose(self, other, rtol, atol, equal_nan);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 309: { // isclose
          double rtol = readAttribute<float>("rtol");
          double atol = readAttribute<float>("atol");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::isclose(self, other, rtol, atol);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 310: { // isclose
          double rtol = readAttribute<float>("rtol");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::isclose(self, other, rtol);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 311: { // isclose
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::isclose(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 312: { // isnan
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::isnan(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 313: { // is_distributed
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::is_distributed(self);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 314: { // is_floating_point
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::is_floating_point(self);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 315: { // is_complex
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::is_complex(self);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 316: { // is_nonzero
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::is_nonzero(self);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 317: { // is_same_size
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::is_same_size(self, other);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 318: { // is_signed
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::is_signed(self);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 319: { // kl_div
          int64_t reduction = readAttribute<int64_t>("reduction");
          bool log_target = readAttribute<int64_t>("log_target");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::kl_div(self, target, reduction, log_target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 320: { // kl_div
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::kl_div(self, target, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 321: { // kl_div
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::kl_div(self, target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 322: { // kl_div_backward
          int64_t reduction = readAttribute<int64_t>("reduction");
          bool log_target = readAttribute<int64_t>("log_target");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto target = peek(2, 3);
              auto the_result = at::kl_div_backward(grad_output, self, target, reduction, log_target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 323: { // kl_div_backward
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto target = peek(2, 3);
              auto the_result = at::kl_div_backward(grad_output, self, target, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 324: { // kl_div_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto target = peek(2, 3);
              auto the_result = at::kl_div_backward(grad_output, self, target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 325: { // kthvalue
          int64_t k = readAttribute<int64_t>("k");
          int64_t dim = readAttribute<int64_t>("dim");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::kthvalue(self, k, dim, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 326: { // kthvalue
          int64_t k = readAttribute<int64_t>("k");
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::kthvalue(self, k, dim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 327: { // kthvalue
          int64_t k = readAttribute<int64_t>("k");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::kthvalue(self, k);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 328: { // layer_norm
          auto normalized_shape = readIntArrayRef("normalized_shape");
          double eps = readAttribute<float>("eps");
          bool cudnn_enable = readAttribute<int64_t>("cudnn_enable");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::layer_norm(input, normalized_shape, weight, bias, eps, cudnn_enable);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 329: { // layer_norm
          auto normalized_shape = readIntArrayRef("normalized_shape");
          double eps = readAttribute<float>("eps");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::layer_norm(input, normalized_shape, weight, bias, eps);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 330: { // layer_norm
          auto normalized_shape = readIntArrayRef("normalized_shape");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::layer_norm(input, normalized_shape, weight, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 331: { // layer_norm
          auto normalized_shape = readIntArrayRef("normalized_shape");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::layer_norm(input, normalized_shape, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 332: { // layer_norm
          auto normalized_shape = readIntArrayRef("normalized_shape");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 1);
              auto the_result = at::layer_norm(input, normalized_shape);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 333: { // native_layer_norm
          int64_t M = readAttribute<int64_t>("M");
          int64_t N = readAttribute<int64_t>("N");
          double eps = readAttribute<float>("eps");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::native_layer_norm(input, weight, bias, M, N, eps);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 334: { // native_layer_norm_backward
          int64_t M = readAttribute<int64_t>("M");
          int64_t N = readAttribute<int64_t>("N");
          auto output_mask = readBoolMask<3>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_out = peek(0, 5);
              auto input = peek(1, 5);
              auto mean = peek(2, 5);
              auto rstd = peek(3, 5);
              auto weight = peek(4, 5);
              auto the_result = at::native_layer_norm_backward(grad_out, input, mean, rstd, weight, M, N, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 335: { // linear
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::linear(input, weight, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 336: { // linear
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::linear(input, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 337: { // mkldnn_linear
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::mkldnn_linear(input, weight, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 338: { // mkldnn_linear
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::mkldnn_linear(input, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 339: { // fbgemm_linear_int8_weight_fp32_activation
          at::Scalar weight_scale = readScalarAttribute("weight_scale");
          at::Scalar weight_zero_point = readScalarAttribute("weight_zero_point");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 5);
              auto weight = peek(1, 5);
              auto packed = peek(2, 5);
              auto col_offsets = peek(3, 5);
              auto bias = peek(4, 5);
              auto the_result = at::fbgemm_linear_int8_weight_fp32_activation(input, weight, packed, col_offsets, weight_scale, weight_zero_point, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 340: { // fbgemm_linear_int8_weight
          at::Scalar weight_scale = readScalarAttribute("weight_scale");
          at::Scalar weight_zero_point = readScalarAttribute("weight_zero_point");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 5);
              auto weight = peek(1, 5);
              auto packed = peek(2, 5);
              auto col_offsets = peek(3, 5);
              auto bias = peek(4, 5);
              auto the_result = at::fbgemm_linear_int8_weight(input, weight, packed, col_offsets, weight_scale, weight_zero_point, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 341: { // fbgemm_pack_gemm_matrix_fp16
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 1);
              auto the_result = at::fbgemm_pack_gemm_matrix_fp16(input);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 342: { // fbgemm_linear_fp16_weight_fp32_activation
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto packed_weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::fbgemm_linear_fp16_weight_fp32_activation(input, packed_weight, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 343: { // fbgemm_linear_fp16_weight
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto packed_weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::fbgemm_linear_fp16_weight(input, packed_weight, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 344: { // fbgemm_pack_quantized_matrix
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 1);
              auto the_result = at::fbgemm_pack_quantized_matrix(input);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 345: { // fbgemm_pack_quantized_matrix
          int64_t K = readAttribute<int64_t>("K");
          int64_t N = readAttribute<int64_t>("N");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 1);
              auto the_result = at::fbgemm_pack_quantized_matrix(input, K, N);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 346: { // log
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::log(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 347: { // log10
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::log10(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 348: { // log1p
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::log1p(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 349: { // log2
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::log2(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 350: { // logaddexp
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::logaddexp(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 351: { // logaddexp2
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::logaddexp2(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 352: { // logdet
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::logdet(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 353: { // log_softmax
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::log_softmax(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 354: { // _log_softmax
          int64_t dim = readAttribute<int64_t>("dim");
          bool half_to_float = readAttribute<int64_t>("half_to_float");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_log_softmax(self, dim, half_to_float);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 355: { // _log_softmax_backward_data
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto output = peek(1, 3);
              auto self = peek(2, 3);
              auto the_result = at::_log_softmax_backward_data(grad_output, output, dim, self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 356: { // _logcumsumexp
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_logcumsumexp(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 357: { // logcumsumexp
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::logcumsumexp(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 358: { // logsumexp
          auto dim = readIntArrayRef("dim");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::logsumexp(self, dim, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 359: { // logsumexp
          auto dim = readIntArrayRef("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::logsumexp(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 360: { // margin_ranking_loss
          double margin = readAttribute<float>("margin");
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input1 = peek(0, 3);
              auto input2 = peek(1, 3);
              auto target = peek(2, 3);
              auto the_result = at::margin_ranking_loss(input1, input2, target, margin, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 361: { // margin_ranking_loss
          double margin = readAttribute<float>("margin");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input1 = peek(0, 3);
              auto input2 = peek(1, 3);
              auto target = peek(2, 3);
              auto the_result = at::margin_ranking_loss(input1, input2, target, margin);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 362: { // margin_ranking_loss
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input1 = peek(0, 3);
              auto input2 = peek(1, 3);
              auto target = peek(2, 3);
              auto the_result = at::margin_ranking_loss(input1, input2, target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 363: { // matmul
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::matmul(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 364: { // matrix_rank
          double tol = readAttribute<float>("tol");
          bool symmetric = readAttribute<int64_t>("symmetric");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::matrix_rank(self, tol, symmetric);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 365: { // matrix_rank
          double tol = readAttribute<float>("tol");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::matrix_rank(self, tol);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 366: { // matrix_rank
          bool symmetric = readAttribute<int64_t>("symmetric");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::matrix_rank(self, symmetric);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 367: { // matrix_rank
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::matrix_rank(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 368: { // matrix_power
          int64_t n = readAttribute<int64_t>("n");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::matrix_power(self, n);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 369: { // max
          int64_t dim = readAttribute<int64_t>("dim");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max(self, dim, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 370: { // max
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 371: { // max_values
          auto dim = readIntArrayRef("dim");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_values(self, dim, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 372: { // max_values
          auto dim = readIntArrayRef("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_values(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 373: { // max_pool1d_with_indices
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          bool ceil_mode = readAttribute<int64_t>("ceil_mode");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool1d_with_indices(self, kernel_size, stride, padding, dilation, ceil_mode);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 374: { // max_pool1d_with_indices
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool1d_with_indices(self, kernel_size, stride, padding, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 375: { // max_pool1d_with_indices
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool1d_with_indices(self, kernel_size, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 376: { // max_pool1d_with_indices
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool1d_with_indices(self, kernel_size, stride);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 377: { // max_pool1d_with_indices
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool1d_with_indices(self, kernel_size);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 378: { // max_pool1d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          bool ceil_mode = readAttribute<int64_t>("ceil_mode");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool1d(self, kernel_size, stride, padding, dilation, ceil_mode);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 379: { // max_pool1d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool1d(self, kernel_size, stride, padding, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 380: { // max_pool1d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool1d(self, kernel_size, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 381: { // max_pool1d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool1d(self, kernel_size, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 382: { // max_pool1d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool1d(self, kernel_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 383: { // max_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          bool ceil_mode = readAttribute<int64_t>("ceil_mode");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool2d(self, kernel_size, stride, padding, dilation, ceil_mode);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 384: { // max_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool2d(self, kernel_size, stride, padding, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 385: { // max_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool2d(self, kernel_size, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 386: { // max_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool2d(self, kernel_size, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 387: { // max_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool2d(self, kernel_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 388: { // mkldnn_max_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          bool ceil_mode = readAttribute<int64_t>("ceil_mode");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mkldnn_max_pool2d(self, kernel_size, stride, padding, dilation, ceil_mode);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 389: { // mkldnn_max_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mkldnn_max_pool2d(self, kernel_size, stride, padding, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 390: { // mkldnn_max_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mkldnn_max_pool2d(self, kernel_size, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 391: { // mkldnn_max_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mkldnn_max_pool2d(self, kernel_size, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 392: { // mkldnn_max_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mkldnn_max_pool2d(self, kernel_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 393: { // quantized_max_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          bool ceil_mode = readAttribute<int64_t>("ceil_mode");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::quantized_max_pool2d(self, kernel_size, stride, padding, dilation, ceil_mode);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 394: { // quantized_max_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::quantized_max_pool2d(self, kernel_size, stride, padding, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 395: { // quantized_max_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::quantized_max_pool2d(self, kernel_size, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 396: { // quantized_max_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::quantized_max_pool2d(self, kernel_size, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 397: { // quantized_max_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::quantized_max_pool2d(self, kernel_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 398: { // max_pool3d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          bool ceil_mode = readAttribute<int64_t>("ceil_mode");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool3d(self, kernel_size, stride, padding, dilation, ceil_mode);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 399: { // max_pool3d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool3d(self, kernel_size, stride, padding, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 400: { // max_pool3d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool3d(self, kernel_size, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 401: { // max_pool3d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool3d(self, kernel_size, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 402: { // max_pool3d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool3d(self, kernel_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 403: { // mean
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mean(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 404: { // mean
          auto dim = readIntArrayRef("dim");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mean(self, dim, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 405: { // mean
          auto dim = readIntArrayRef("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mean(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 406: { // median
          int64_t dim = readAttribute<int64_t>("dim");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::median(self, dim, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 407: { // median
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::median(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 408: { // min
          int64_t dim = readAttribute<int64_t>("dim");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::min(self, dim, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 409: { // min
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::min(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 410: { // min_values
          auto dim = readIntArrayRef("dim");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::min_values(self, dim, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 411: { // min_values
          auto dim = readIntArrayRef("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::min_values(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 412: { // mkldnn_convolution
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::mkldnn_convolution(self, weight, bias, padding, stride, dilation, groups);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 413: { // mkldnn_convolution_backward_input
          auto self_size = readIntArrayRef("self_size");
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool bias_defined = readAttribute<int64_t>("bias_defined");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::mkldnn_convolution_backward_input(self_size, grad_output, weight, padding, stride, dilation, groups, bias_defined);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 414: { // mkldnn_convolution_backward_weights
          auto weight_size = readIntArrayRef("weight_size");
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool bias_defined = readAttribute<int64_t>("bias_defined");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::mkldnn_convolution_backward_weights(weight_size, grad_output, self, padding, stride, dilation, groups, bias_defined);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 415: { // mkldnn_convolution_backward
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          auto output_mask = readBoolMask<3>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto grad_output = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::mkldnn_convolution_backward(self, grad_output, weight, padding, stride, dilation, groups, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 416: { // miopen_batch_norm
          bool training = readAttribute<int64_t>("training");
          double exponential_average_factor = readAttribute<float>("exponential_average_factor");
          double epsilon = readAttribute<float>("epsilon");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 5);
              auto weight = peek(1, 5);
              auto bias = peek(2, 5);
              auto running_mean = peek(3, 5);
              auto running_var = peek(4, 5);
              auto the_result = at::miopen_batch_norm(input, weight, bias, running_mean, running_var, training, exponential_average_factor, epsilon);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 417: { // miopen_batch_norm_backward
          double epsilon = readAttribute<float>("epsilon");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 7);
              auto grad_output = peek(1, 7);
              auto weight = peek(2, 7);
              auto running_mean = peek(3, 7);
              auto running_var = peek(4, 7);
              auto save_mean = peek(5, 7);
              auto save_var = peek(6, 7);
              auto the_result = at::miopen_batch_norm_backward(input, grad_output, weight, running_mean, running_var, save_mean, save_var, epsilon);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 418: { // miopen_convolution
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::miopen_convolution(self, weight, bias, padding, stride, dilation, groups, benchmark, deterministic);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 419: { // miopen_convolution_backward_input
          auto self_size = readIntArrayRef("self_size");
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::miopen_convolution_backward_input(self_size, grad_output, weight, padding, stride, dilation, groups, benchmark, deterministic);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 420: { // miopen_convolution_backward
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          auto output_mask = readBoolMask<3>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto grad_output = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::miopen_convolution_backward(self, grad_output, weight, padding, stride, dilation, groups, benchmark, deterministic, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 421: { // miopen_convolution_backward_bias
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 1);
              auto the_result = at::miopen_convolution_backward_bias(grad_output);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 422: { // miopen_convolution_backward_weight
          auto weight_size = readIntArrayRef("weight_size");
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::miopen_convolution_backward_weight(weight_size, grad_output, self, padding, stride, dilation, groups, benchmark, deterministic);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 423: { // miopen_convolution_transpose
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::miopen_convolution_transpose(self, weight, bias, padding, output_padding, stride, dilation, groups, benchmark, deterministic);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 424: { // miopen_convolution_transpose_backward
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          auto output_mask = readBoolMask<3>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto grad_output = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::miopen_convolution_transpose_backward(self, grad_output, weight, padding, output_padding, stride, dilation, groups, benchmark, deterministic, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 425: { // miopen_convolution_transpose_backward_input
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::miopen_convolution_transpose_backward_input(grad_output, weight, padding, stride, dilation, groups, benchmark, deterministic);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 426: { // miopen_convolution_transpose_backward_weight
          auto weight_size = readIntArrayRef("weight_size");
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::miopen_convolution_transpose_backward_weight(weight_size, grad_output, self, padding, stride, dilation, groups, benchmark, deterministic);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 427: { // miopen_depthwise_convolution
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::miopen_depthwise_convolution(self, weight, bias, padding, stride, dilation, groups, benchmark, deterministic);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 428: { // miopen_depthwise_convolution_backward_input
          auto self_size = readIntArrayRef("self_size");
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::miopen_depthwise_convolution_backward_input(self_size, grad_output, weight, padding, stride, dilation, groups, benchmark, deterministic);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 429: { // miopen_depthwise_convolution_backward
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          auto output_mask = readBoolMask<3>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto grad_output = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::miopen_depthwise_convolution_backward(self, grad_output, weight, padding, stride, dilation, groups, benchmark, deterministic, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 430: { // miopen_depthwise_convolution_backward_weight
          auto weight_size = readIntArrayRef("weight_size");
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          bool benchmark = readAttribute<int64_t>("benchmark");
          bool deterministic = readAttribute<int64_t>("deterministic");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::miopen_depthwise_convolution_backward_weight(weight_size, grad_output, self, padding, stride, dilation, groups, benchmark, deterministic);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 431: { // miopen_rnn
          int64_t weight_stride0 = readAttribute<int64_t>("weight_stride0");
          int64_t mode = readAttribute<int64_t>("mode");
          int64_t hidden_size = readAttribute<int64_t>("hidden_size");
          int64_t num_layers = readAttribute<int64_t>("num_layers");
          bool batch_first = readAttribute<int64_t>("batch_first");
          double dropout = readAttribute<float>("dropout");
          bool train = readAttribute<int64_t>("train");
          bool bidirectional = readAttribute<int64_t>("bidirectional");
          auto batch_sizes = readIntArrayRef("batch_sizes");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, InputSize());
              auto weight = peekSlice(1, InputSize() - 4, InputSize());
              auto hx = peek(1, 4);
              auto cx = peek(2, 4);
              auto dropout_state = peek(3, 4);
              auto the_result = at::miopen_rnn(input, weight, weight_stride0, hx, cx, mode, hidden_size, num_layers, batch_first, dropout, train, bidirectional, batch_sizes, dropout_state);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
                if(OutputSize() > 4) {assignTo(Output(4),std::get<4>(the_result));}
              return true;
          };
      } break;
      case 432: { // mm
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto mat2 = peek(1, 2);
              auto the_result = at::mm(self, mat2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 433: { // _sparse_mm
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto sparse = peek(0, 2);
              auto dense = peek(1, 2);
              auto the_result = at::_sparse_mm(sparse, dense);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 434: { // mode
          int64_t dim = readAttribute<int64_t>("dim");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mode(self, dim, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 435: { // mode
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mode(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 436: { // mode
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mode(self);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 437: { // mul
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::mul(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 438: { // mul
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mul(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 439: { // mv
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto vec = peek(1, 2);
              auto the_result = at::mv(self, vec);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 440: { // mvlgamma
          int64_t p = readAttribute<int64_t>("p");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mvlgamma(self, p);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 441: { // narrow_copy
          int64_t dim = readAttribute<int64_t>("dim");
          int64_t start = readAttribute<int64_t>("start");
          int64_t length = readAttribute<int64_t>("length");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.narrow_copy(dim, start, length);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 442: { // narrow
          int64_t dim = readAttribute<int64_t>("dim");
          int64_t start = readAttribute<int64_t>("start");
          int64_t length = readAttribute<int64_t>("length");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::narrow(self, dim, start, length);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 443: { // narrow
          int64_t dim = readAttribute<int64_t>("dim");
          int64_t length = readAttribute<int64_t>("length");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto start = peek(1, 2);
              auto the_result = at::narrow(self, dim, start, length);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 444: { // native_batch_norm
          bool training = readAttribute<int64_t>("training");
          double momentum = readAttribute<float>("momentum");
          double eps = readAttribute<float>("eps");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 5);
              auto weight = peek(1, 5);
              auto bias = peek(2, 5);
              auto running_mean = peek(3, 5);
              auto running_var = peek(4, 5);
              auto the_result = at::native_batch_norm(input, weight, bias, running_mean, running_var, training, momentum, eps);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 445: { // batch_norm_stats
          double eps = readAttribute<float>("eps");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 1);
              auto the_result = at::batch_norm_stats(input, eps);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 446: { // batch_norm_elemt
          double eps = readAttribute<float>("eps");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 5);
              auto weight = peek(1, 5);
              auto bias = peek(2, 5);
              auto mean = peek(3, 5);
              auto invstd = peek(4, 5);
              auto the_result = at::batch_norm_elemt(input, weight, bias, mean, invstd, eps);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 447: { // batch_norm_gather_stats
          double momentum = readAttribute<float>("momentum");
          double eps = readAttribute<float>("eps");
          int64_t count = readAttribute<int64_t>("count");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 5);
              auto mean = peek(1, 5);
              auto invstd = peek(2, 5);
              auto running_mean = peek(3, 5);
              auto running_var = peek(4, 5);
              auto the_result = at::batch_norm_gather_stats(input, mean, invstd, running_mean, running_var, momentum, eps, count);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 448: { // batch_norm_gather_stats_with_counts
          double momentum = readAttribute<float>("momentum");
          double eps = readAttribute<float>("eps");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 6);
              auto mean = peek(1, 6);
              auto invstd = peek(2, 6);
              auto running_mean = peek(3, 6);
              auto running_var = peek(4, 6);
              auto counts = peek(5, 6);
              auto the_result = at::batch_norm_gather_stats_with_counts(input, mean, invstd, running_mean, running_var, momentum, eps, counts);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 449: { // native_batch_norm_backward
          bool train = readAttribute<int64_t>("train");
          double eps = readAttribute<float>("eps");
          auto output_mask = readBoolMask<3>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_out = peek(0, 7);
              auto input = peek(1, 7);
              auto weight = peek(2, 7);
              auto running_mean = peek(3, 7);
              auto running_var = peek(4, 7);
              auto save_mean = peek(5, 7);
              auto save_invstd = peek(6, 7);
              auto the_result = at::native_batch_norm_backward(grad_out, input, weight, running_mean, running_var, save_mean, save_invstd, train, eps, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 450: { // batch_norm_backward_reduce
          bool input_g = readAttribute<int64_t>("input_g");
          bool weight_g = readAttribute<int64_t>("weight_g");
          bool bias_g = readAttribute<int64_t>("bias_g");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_out = peek(0, 5);
              auto input = peek(1, 5);
              auto mean = peek(2, 5);
              auto invstd = peek(3, 5);
              auto weight = peek(4, 5);
              auto the_result = at::batch_norm_backward_reduce(grad_out, input, mean, invstd, weight, input_g, weight_g, bias_g);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
              return true;
          };
      } break;
      case 451: { // batch_norm_backward_elemt
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_out = peek(0, 7);
              auto input = peek(1, 7);
              auto mean = peek(2, 7);
              auto invstd = peek(3, 7);
              auto weight = peek(4, 7);
              auto mean_dy = peek(5, 7);
              auto mean_dy_xmu = peek(6, 7);
              auto the_result = at::batch_norm_backward_elemt(grad_out, input, mean, invstd, weight, mean_dy, mean_dy_xmu);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 452: { // batch_norm_update_stats
          double momentum = readAttribute<float>("momentum");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto running_mean = peek(1, 3);
              auto running_var = peek(2, 3);
              auto the_result = at::batch_norm_update_stats(input, running_mean, running_var, momentum);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 453: { // is_vulkan_available
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
      
              auto the_result = at::is_vulkan_available();
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 454: { // _nnpack_available
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
      
              auto the_result = at::_nnpack_available();
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 455: { // _nnpack_spatial_convolution
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::_nnpack_spatial_convolution(input, weight, bias, padding, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 456: { // _nnpack_spatial_convolution
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::_nnpack_spatial_convolution(input, weight, bias, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 457: { // _nnpack_spatial_convolution_backward
          auto padding = readIntArrayRef("padding");
          auto output_mask = readBoolMask<3>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto grad_output = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::_nnpack_spatial_convolution_backward(input, grad_output, weight, padding, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 458: { // _nnpack_spatial_convolution_backward_input
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 3);
              auto grad_output = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::_nnpack_spatial_convolution_backward_input(input, grad_output, weight, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 459: { // _nnpack_spatial_convolution_backward_weight
          auto weightsize = readIntArrayRef("weightsize");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 2);
              auto grad_output = peek(1, 2);
              auto the_result = at::_nnpack_spatial_convolution_backward_weight(input, weightsize, grad_output, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 460: { // pairwise_distance
          double p = readAttribute<float>("p");
          double eps = readAttribute<float>("eps");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto x1 = peek(0, 2);
              auto x2 = peek(1, 2);
              auto the_result = at::pairwise_distance(x1, x2, p, eps, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 461: { // pairwise_distance
          double p = readAttribute<float>("p");
          double eps = readAttribute<float>("eps");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto x1 = peek(0, 2);
              auto x2 = peek(1, 2);
              auto the_result = at::pairwise_distance(x1, x2, p, eps);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 462: { // pairwise_distance
          double p = readAttribute<float>("p");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto x1 = peek(0, 2);
              auto x2 = peek(1, 2);
              auto the_result = at::pairwise_distance(x1, x2, p);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 463: { // pairwise_distance
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto x1 = peek(0, 2);
              auto x2 = peek(1, 2);
              auto the_result = at::pairwise_distance(x1, x2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 464: { // cdist
          double p = readAttribute<float>("p");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto x1 = peek(0, 2);
              auto x2 = peek(1, 2);
              auto the_result = at::cdist(x1, x2, p);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 465: { // cdist
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto x1 = peek(0, 2);
              auto x2 = peek(1, 2);
              auto the_result = at::cdist(x1, x2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 466: { // _euclidean_dist
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto x1 = peek(0, 2);
              auto x2 = peek(1, 2);
              auto the_result = at::_euclidean_dist(x1, x2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 467: { // _cdist_backward
          double p = readAttribute<float>("p");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 4);
              auto x1 = peek(1, 4);
              auto x2 = peek(2, 4);
              auto cdist = peek(3, 4);
              auto the_result = at::_cdist_backward(grad, x1, x2, p, cdist);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 468: { // pdist
          double p = readAttribute<float>("p");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::pdist(self, p);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 469: { // pdist
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::pdist(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 470: { // _pdist_forward
          double p = readAttribute<float>("p");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_pdist_forward(self, p);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 471: { // _pdist_forward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_pdist_forward(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 472: { // _pdist_backward
          double p = readAttribute<float>("p");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 3);
              auto self = peek(1, 3);
              auto pdist = peek(2, 3);
              auto the_result = at::_pdist_backward(grad, self, p, pdist);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 473: { // cosine_similarity
          int64_t dim = readAttribute<int64_t>("dim");
          double eps = readAttribute<float>("eps");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto x1 = peek(0, 2);
              auto x2 = peek(1, 2);
              auto the_result = at::cosine_similarity(x1, x2, dim, eps);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 474: { // cosine_similarity
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto x1 = peek(0, 2);
              auto x2 = peek(1, 2);
              auto the_result = at::cosine_similarity(x1, x2, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 475: { // cosine_similarity
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto x1 = peek(0, 2);
              auto x2 = peek(1, 2);
              auto the_result = at::cosine_similarity(x1, x2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 476: { // permute
          auto dims = readIntArrayRef("dims");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.permute(dims);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 477: { // numpy_T
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.numpy_T();
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 478: { // pixel_shuffle
          int64_t upscale_factor = readAttribute<int64_t>("upscale_factor");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::pixel_shuffle(self, upscale_factor);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 479: { // channel_shuffle
          int64_t groups = readAttribute<int64_t>("groups");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::channel_shuffle(self, groups);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 480: { // is_pinned
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.is_pinned();
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 481: { // pin_memory
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.pin_memory();
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 482: { // pinverse
          double rcond = readAttribute<float>("rcond");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::pinverse(self, rcond);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 483: { // pinverse
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::pinverse(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 484: { // poisson_nll_loss
          bool log_input = readAttribute<int64_t>("log_input");
          bool full = readAttribute<int64_t>("full");
          double eps = readAttribute<float>("eps");
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::poisson_nll_loss(input, target, log_input, full, eps, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 485: { // rad2deg
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::rad2deg(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 486: { // deg2rad
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::deg2rad(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 487: { // reciprocal
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::reciprocal(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 488: { // neg
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::neg(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 489: { // repeat
          auto repeats = readIntArrayRef("repeats");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.repeat(repeats);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 490: { // repeat_interleave
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto repeats = peek(0, 1);
              auto the_result = at::repeat_interleave(repeats);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 491: { // repeat_interleave
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto repeats = peek(1, 2);
              auto the_result = at::repeat_interleave(self, repeats);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 492: { // repeat_interleave
          int64_t repeats = readAttribute<int64_t>("repeats");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::repeat_interleave(self, repeats);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 493: { // reshape
          auto shape = readIntArrayRef("shape");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::reshape(self, shape);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 494: { // _mkldnn_reshape
          auto shape = readIntArrayRef("shape");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_mkldnn_reshape(self, shape);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 495: { // reshape_as
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = self.reshape_as(other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 496: { // round
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::round(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 497: { // rrelu
          at::Scalar lower = readScalarAttribute("lower");
          at::Scalar upper = readScalarAttribute("upper");
          bool training = readAttribute<int64_t>("training");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::rrelu(self, lower, upper, training);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 498: { // rrelu
          at::Scalar lower = readScalarAttribute("lower");
          at::Scalar upper = readScalarAttribute("upper");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::rrelu(self, lower, upper);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 499: { // rrelu
          at::Scalar lower = readScalarAttribute("lower");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::rrelu(self, lower);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 500: { // rrelu
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::rrelu(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 501: { // relu
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::relu(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 502: { // prelu
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::prelu(self, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 503: { // prelu_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::prelu_backward(grad_output, self, weight);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 504: { // gelu
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::gelu(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 505: { // gelu_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::gelu_backward(grad, self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 506: { // hardshrink
          at::Scalar lambd = readScalarAttribute("lambd");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::hardshrink(self, lambd);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 507: { // hardshrink
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::hardshrink(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 508: { // hardshrink_backward
          at::Scalar lambd = readScalarAttribute("lambd");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_out = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::hardshrink_backward(grad_out, self, lambd);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 509: { // rsqrt
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::rsqrt(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 510: { // select
          int64_t dim = readAttribute<int64_t>("dim");
          int64_t index = readAttribute<int64_t>("index");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::select(self, dim, index);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 511: { // selu
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::selu(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 512: { // celu
          at::Scalar alpha = readScalarAttribute("alpha");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::celu(self, alpha);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 513: { // celu
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::celu(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 514: { // sigmoid
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::sigmoid(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 515: { // sin
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::sin(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 516: { // sinh
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::sinh(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 517: { // detach
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::detach(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 518: { // size
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::size(self, dim);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 519: { // slice
          int64_t dim = readAttribute<int64_t>("dim");
          int64_t start = readAttribute<int64_t>("start");
          int64_t end = readAttribute<int64_t>("end");
          int64_t step = readAttribute<int64_t>("step");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::slice(self, dim, start, end, step);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 520: { // slice
          int64_t dim = readAttribute<int64_t>("dim");
          int64_t start = readAttribute<int64_t>("start");
          int64_t end = readAttribute<int64_t>("end");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::slice(self, dim, start, end);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 521: { // slice
          int64_t dim = readAttribute<int64_t>("dim");
          int64_t start = readAttribute<int64_t>("start");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::slice(self, dim, start);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 522: { // slice
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::slice(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 523: { // slice
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::slice(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 524: { // slogdet
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::slogdet(self);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 525: { // smm
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto mat2 = peek(1, 2);
              auto the_result = at::smm(self, mat2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 526: { // softmax
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::softmax(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 527: { // _softmax
          int64_t dim = readAttribute<int64_t>("dim");
          bool half_to_float = readAttribute<int64_t>("half_to_float");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_softmax(self, dim, half_to_float);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 528: { // _softmax_backward_data
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto output = peek(1, 3);
              auto self = peek(2, 3);
              auto the_result = at::_softmax_backward_data(grad_output, output, dim, self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 529: { // split
          int64_t split_size = readAttribute<int64_t>("split_size");
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::split(self, split_size, dim);
                if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
              return true;
          };
      } break;
      case 530: { // split
          int64_t split_size = readAttribute<int64_t>("split_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::split(self, split_size);
                if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
              return true;
          };
      } break;
      case 531: { // split_with_sizes
          auto split_sizes = readIntArrayRef("split_sizes");
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::split_with_sizes(self, split_sizes, dim);
                if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
              return true;
          };
      } break;
      case 532: { // split_with_sizes
          auto split_sizes = readIntArrayRef("split_sizes");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::split_with_sizes(self, split_sizes);
                if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
              return true;
          };
      } break;
      case 533: { // squeeze
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::squeeze(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 534: { // squeeze
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::squeeze(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 535: { // sspaddmm
          at::Scalar beta = readScalarAttribute("beta");
          at::Scalar alpha = readScalarAttribute("alpha");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto mat1 = peek(1, 3);
              auto mat2 = peek(2, 3);
              auto the_result = at::sspaddmm(self, mat1, mat2, beta, alpha);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 536: { // sspaddmm
          at::Scalar beta = readScalarAttribute("beta");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto mat1 = peek(1, 3);
              auto mat2 = peek(2, 3);
              auto the_result = at::sspaddmm(self, mat1, mat2, beta);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 537: { // sspaddmm
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto mat1 = peek(1, 3);
              auto mat2 = peek(2, 3);
              auto the_result = at::sspaddmm(self, mat1, mat2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 538: { // stack
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto tensors = peekSlice(0, InputSize() - 0, InputSize());
              auto the_result = at::stack(tensors, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 539: { // stack
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto tensors = peekSlice(0, InputSize() - 0, InputSize());
              auto the_result = at::stack(tensors);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 540: { // stft
          int64_t n_fft = readAttribute<int64_t>("n_fft");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::stft(self, n_fft);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 541: { // istft
          int64_t n_fft = readAttribute<int64_t>("n_fft");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::istft(self, n_fft);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 542: { // stride
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::stride(self, dim);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 543: { // sum
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::sum(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 544: { // sum
          auto dim = readIntArrayRef("dim");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::sum(self, dim, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 545: { // sum
          auto dim = readIntArrayRef("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::sum(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 546: { // sum_to_size
          auto size = readIntArrayRef("size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.sum_to_size(size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 547: { // sqrt
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::sqrt(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 548: { // square
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::square(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 549: { // std
          bool unbiased = readAttribute<int64_t>("unbiased");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::std(self, unbiased);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 550: { // std
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::std(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 551: { // std
          auto dim = readIntArrayRef("dim");
          bool unbiased = readAttribute<int64_t>("unbiased");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::std(self, dim, unbiased, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 552: { // std
          auto dim = readIntArrayRef("dim");
          bool unbiased = readAttribute<int64_t>("unbiased");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::std(self, dim, unbiased);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 553: { // std
          auto dim = readIntArrayRef("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::std(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 554: { // std_mean
          bool unbiased = readAttribute<int64_t>("unbiased");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::std_mean(self, unbiased);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 555: { // std_mean
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::std_mean(self);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 556: { // std_mean
          auto dim = readIntArrayRef("dim");
          bool unbiased = readAttribute<int64_t>("unbiased");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::std_mean(self, dim, unbiased, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 557: { // std_mean
          auto dim = readIntArrayRef("dim");
          bool unbiased = readAttribute<int64_t>("unbiased");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::std_mean(self, dim, unbiased);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 558: { // std_mean
          auto dim = readIntArrayRef("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::std_mean(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 559: { // prod
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::prod(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 560: { // prod
          int64_t dim = readAttribute<int64_t>("dim");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::prod(self, dim, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 561: { // prod
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::prod(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 562: { // t
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::t(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 563: { // tan
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::tan(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 564: { // tanh
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::tanh(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 565: { // tensordot
          auto dims_self = readIntArrayRef("dims_self");
          auto dims_other = readIntArrayRef("dims_other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::tensordot(self, other, dims_self, dims_other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 566: { // threshold
          at::Scalar threshold = readScalarAttribute("threshold");
          at::Scalar value = readScalarAttribute("value");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::threshold(self, threshold, value);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 567: { // threshold_backward
          at::Scalar threshold = readScalarAttribute("threshold");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::threshold_backward(grad_output, self, threshold);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 568: { // transpose
          int64_t dim0 = readAttribute<int64_t>("dim0");
          int64_t dim1 = readAttribute<int64_t>("dim1");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::transpose(self, dim0, dim1);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 569: { // _mkldnn_transpose
          int64_t dim0 = readAttribute<int64_t>("dim0");
          int64_t dim1 = readAttribute<int64_t>("dim1");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_mkldnn_transpose(self, dim0, dim1);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 570: { // one_hot
          int64_t num_classes = readAttribute<int64_t>("num_classes");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::one_hot(self, num_classes);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 571: { // one_hot
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::one_hot(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 572: { // flip
          auto dims = readIntArrayRef("dims");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::flip(self, dims);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 573: { // fliplr
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::fliplr(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 574: { // flipud
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::flipud(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 575: { // roll
          auto shifts = readIntArrayRef("shifts");
          auto dims = readIntArrayRef("dims");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::roll(self, shifts, dims);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 576: { // roll
          auto shifts = readIntArrayRef("shifts");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::roll(self, shifts);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 577: { // rot90
          int64_t k = readAttribute<int64_t>("k");
          auto dims = readIntArrayRef("dims");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::rot90(self, k, dims);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 578: { // rot90
          int64_t k = readAttribute<int64_t>("k");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::rot90(self, k);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 579: { // rot90
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::rot90(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 580: { // trapz
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto y = peek(0, 2);
              auto x = peek(1, 2);
              auto the_result = at::trapz(y, x, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 581: { // trapz
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto y = peek(0, 2);
              auto x = peek(1, 2);
              auto the_result = at::trapz(y, x);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 582: { // trapz
          double dx = readAttribute<float>("dx");
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto y = peek(0, 1);
              auto the_result = at::trapz(y, dx, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 583: { // trapz
          double dx = readAttribute<float>("dx");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto y = peek(0, 1);
              auto the_result = at::trapz(y, dx);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 584: { // trapz
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto y = peek(0, 1);
              auto the_result = at::trapz(y);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 585: { // _trilinear
          auto expand1 = readIntArrayRef("expand1");
          auto expand2 = readIntArrayRef("expand2");
          auto expand3 = readIntArrayRef("expand3");
          auto sumdim = readIntArrayRef("sumdim");
          int64_t unroll_dim = readAttribute<int64_t>("unroll_dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto i1 = peek(0, 3);
              auto i2 = peek(1, 3);
              auto i3 = peek(2, 3);
              auto the_result = at::_trilinear(i1, i2, i3, expand1, expand2, expand3, sumdim, unroll_dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 586: { // _trilinear
          auto expand1 = readIntArrayRef("expand1");
          auto expand2 = readIntArrayRef("expand2");
          auto expand3 = readIntArrayRef("expand3");
          auto sumdim = readIntArrayRef("sumdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto i1 = peek(0, 3);
              auto i2 = peek(1, 3);
              auto i3 = peek(2, 3);
              auto the_result = at::_trilinear(i1, i2, i3, expand1, expand2, expand3, sumdim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 587: { // triplet_margin_loss
          double margin = readAttribute<float>("margin");
          double p = readAttribute<float>("p");
          double eps = readAttribute<float>("eps");
          bool swap = readAttribute<int64_t>("swap");
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto anchor = peek(0, 3);
              auto positive = peek(1, 3);
              auto negative = peek(2, 3);
              auto the_result = at::triplet_margin_loss(anchor, positive, negative, margin, p, eps, swap, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 588: { // triplet_margin_loss
          double margin = readAttribute<float>("margin");
          double p = readAttribute<float>("p");
          double eps = readAttribute<float>("eps");
          bool swap = readAttribute<int64_t>("swap");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto anchor = peek(0, 3);
              auto positive = peek(1, 3);
              auto negative = peek(2, 3);
              auto the_result = at::triplet_margin_loss(anchor, positive, negative, margin, p, eps, swap);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 589: { // triplet_margin_loss
          double margin = readAttribute<float>("margin");
          double p = readAttribute<float>("p");
          double eps = readAttribute<float>("eps");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto anchor = peek(0, 3);
              auto positive = peek(1, 3);
              auto negative = peek(2, 3);
              auto the_result = at::triplet_margin_loss(anchor, positive, negative, margin, p, eps);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 590: { // triplet_margin_loss
          double margin = readAttribute<float>("margin");
          double p = readAttribute<float>("p");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto anchor = peek(0, 3);
              auto positive = peek(1, 3);
              auto negative = peek(2, 3);
              auto the_result = at::triplet_margin_loss(anchor, positive, negative, margin, p);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 591: { // triplet_margin_loss
          double margin = readAttribute<float>("margin");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto anchor = peek(0, 3);
              auto positive = peek(1, 3);
              auto negative = peek(2, 3);
              auto the_result = at::triplet_margin_loss(anchor, positive, negative, margin);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 592: { // triplet_margin_loss
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto anchor = peek(0, 3);
              auto positive = peek(1, 3);
              auto negative = peek(2, 3);
              auto the_result = at::triplet_margin_loss(anchor, positive, negative);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 593: { // true_divide
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::true_divide(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 594: { // true_divide
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::true_divide(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 595: { // trunc
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::trunc(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 596: { // type_as
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = self.type_as(other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 597: { // _has_compatible_shallow_copy_type
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto from = peek(1, 2);
              auto the_result = at::_has_compatible_shallow_copy_type(self, from);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 598: { // _unique
          bool sorted = readAttribute<int64_t>("sorted");
          bool return_inverse = readAttribute<int64_t>("return_inverse");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_unique(self, sorted, return_inverse);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 599: { // _unique
          bool sorted = readAttribute<int64_t>("sorted");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_unique(self, sorted);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 600: { // _unique
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_unique(self);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 601: { // unique_dim
          int64_t dim = readAttribute<int64_t>("dim");
          bool sorted = readAttribute<int64_t>("sorted");
          bool return_inverse = readAttribute<int64_t>("return_inverse");
          bool return_counts = readAttribute<int64_t>("return_counts");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::unique_dim(self, dim, sorted, return_inverse, return_counts);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 602: { // unique_dim
          int64_t dim = readAttribute<int64_t>("dim");
          bool sorted = readAttribute<int64_t>("sorted");
          bool return_inverse = readAttribute<int64_t>("return_inverse");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::unique_dim(self, dim, sorted, return_inverse);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 603: { // unique_dim
          int64_t dim = readAttribute<int64_t>("dim");
          bool sorted = readAttribute<int64_t>("sorted");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::unique_dim(self, dim, sorted);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 604: { // unique_dim
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::unique_dim(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 605: { // unique_consecutive
          bool return_inverse = readAttribute<int64_t>("return_inverse");
          bool return_counts = readAttribute<int64_t>("return_counts");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::unique_consecutive(self, return_inverse, return_counts);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 606: { // unique_consecutive
          bool return_inverse = readAttribute<int64_t>("return_inverse");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::unique_consecutive(self, return_inverse);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 607: { // unique_consecutive
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::unique_consecutive(self);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 608: { // unique_dim_consecutive
          int64_t dim = readAttribute<int64_t>("dim");
          bool return_inverse = readAttribute<int64_t>("return_inverse");
          bool return_counts = readAttribute<int64_t>("return_counts");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::unique_dim_consecutive(self, dim, return_inverse, return_counts);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 609: { // unique_dim_consecutive
          int64_t dim = readAttribute<int64_t>("dim");
          bool return_inverse = readAttribute<int64_t>("return_inverse");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::unique_dim_consecutive(self, dim, return_inverse);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 610: { // unique_dim_consecutive
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::unique_dim_consecutive(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 611: { // _unique2
          bool sorted = readAttribute<int64_t>("sorted");
          bool return_inverse = readAttribute<int64_t>("return_inverse");
          bool return_counts = readAttribute<int64_t>("return_counts");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_unique2(self, sorted, return_inverse, return_counts);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 612: { // _unique2
          bool sorted = readAttribute<int64_t>("sorted");
          bool return_inverse = readAttribute<int64_t>("return_inverse");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_unique2(self, sorted, return_inverse);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 613: { // _unique2
          bool sorted = readAttribute<int64_t>("sorted");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_unique2(self, sorted);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 614: { // _unique2
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_unique2(self);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 615: { // _unsafe_view
          auto size = readIntArrayRef("size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_unsafe_view(self, size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 616: { // unsqueeze
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::unsqueeze(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 617: { // vander
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto x = peek(0, 1);
              auto the_result = at::vander(x);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 618: { // var
          bool unbiased = readAttribute<int64_t>("unbiased");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::var(self, unbiased);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 619: { // var
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::var(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 620: { // var
          auto dim = readIntArrayRef("dim");
          bool unbiased = readAttribute<int64_t>("unbiased");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::var(self, dim, unbiased, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 621: { // var
          auto dim = readIntArrayRef("dim");
          bool unbiased = readAttribute<int64_t>("unbiased");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::var(self, dim, unbiased);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 622: { // var
          auto dim = readIntArrayRef("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::var(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 623: { // var_mean
          bool unbiased = readAttribute<int64_t>("unbiased");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::var_mean(self, unbiased);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 624: { // var_mean
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::var_mean(self);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 625: { // var_mean
          auto dim = readIntArrayRef("dim");
          bool unbiased = readAttribute<int64_t>("unbiased");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::var_mean(self, dim, unbiased, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 626: { // var_mean
          auto dim = readIntArrayRef("dim");
          bool unbiased = readAttribute<int64_t>("unbiased");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::var_mean(self, dim, unbiased);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 627: { // var_mean
          auto dim = readIntArrayRef("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::var_mean(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 628: { // view_as
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = self.view_as(other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 629: { // where
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto condition = peek(0, 3);
              auto self = peek(1, 3);
              auto other = peek(2, 3);
              auto the_result = at::where(condition, self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 630: { // where
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto condition = peek(0, 1);
              auto the_result = at::where(condition);
                if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
              return true;
          };
      } break;
      case 631: { // _s_where
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto condition = peek(0, 3);
              auto self = peek(1, 3);
              auto other = peek(2, 3);
              auto the_result = at::_s_where(condition, self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 632: { // norm_except_dim
          int64_t pow = readAttribute<int64_t>("pow");
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto v = peek(0, 1);
              auto the_result = at::norm_except_dim(v, pow, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 633: { // norm_except_dim
          int64_t pow = readAttribute<int64_t>("pow");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto v = peek(0, 1);
              auto the_result = at::norm_except_dim(v, pow);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 634: { // norm_except_dim
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto v = peek(0, 1);
              auto the_result = at::norm_except_dim(v);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 635: { // _weight_norm
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto v = peek(0, 2);
              auto g = peek(1, 2);
              auto the_result = at::_weight_norm(v, g, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 636: { // _weight_norm
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto v = peek(0, 2);
              auto g = peek(1, 2);
              auto the_result = at::_weight_norm(v, g);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 637: { // _weight_norm_cuda_interface
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto v = peek(0, 2);
              auto g = peek(1, 2);
              auto the_result = at::_weight_norm_cuda_interface(v, g, dim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 638: { // _weight_norm_cuda_interface
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto v = peek(0, 2);
              auto g = peek(1, 2);
              auto the_result = at::_weight_norm_cuda_interface(v, g);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 639: { // _weight_norm_cuda_interface_backward
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_w = peek(0, 4);
              auto saved_v = peek(1, 4);
              auto saved_g = peek(2, 4);
              auto saved_norms = peek(3, 4);
              auto the_result = at::_weight_norm_cuda_interface_backward(grad_w, saved_v, saved_g, saved_norms, dim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 640: { // _weight_norm_differentiable_backward
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_w = peek(0, 4);
              auto saved_v = peek(1, 4);
              auto saved_g = peek(2, 4);
              auto saved_norms = peek(3, 4);
              auto the_result = at::_weight_norm_differentiable_backward(grad_w, saved_v, saved_g, saved_norms, dim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 641: { // _standard_gamma_grad
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto output = peek(1, 2);
              auto the_result = at::_standard_gamma_grad(self, output);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 642: { // _standard_gamma
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_standard_gamma(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 643: { // _dirichlet_grad
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto x = peek(0, 3);
              auto alpha = peek(1, 3);
              auto total = peek(2, 3);
              auto the_result = at::_dirichlet_grad(x, alpha, total);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 644: { // _sample_dirichlet
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_sample_dirichlet(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 645: { // poisson
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::poisson(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 646: { // binomial
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto count = peek(0, 2);
              auto prob = peek(1, 2);
              auto the_result = at::binomial(count, prob);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 647: { // native_norm
          at::Scalar p = readScalarAttribute("p");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::native_norm(self, p);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 648: { // native_norm
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::native_norm(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 649: { // _sparse_sum
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_sparse_sum(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 650: { // _sparse_sum
          auto dim = readIntArrayRef("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_sparse_sum(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 651: { // _sparse_sum_backward
          auto dim = readIntArrayRef("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::_sparse_sum_backward(grad, self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 652: { // _sparse_softmax
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_sparse_softmax(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 653: { // _sparse_softmax
          int64_t dim = readAttribute<int64_t>("dim");
          bool half_to_float = readAttribute<int64_t>("half_to_float");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_sparse_softmax(self, dim, half_to_float);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 654: { // _sparse_softmax_backward_data
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto output = peek(1, 3);
              auto self = peek(2, 3);
              auto the_result = at::_sparse_softmax_backward_data(grad_output, output, dim, self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 655: { // _sparse_log_softmax
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_sparse_log_softmax(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 656: { // _sparse_log_softmax
          int64_t dim = readAttribute<int64_t>("dim");
          bool half_to_float = readAttribute<int64_t>("half_to_float");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_sparse_log_softmax(self, dim, half_to_float);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 657: { // _sparse_log_softmax_backward_data
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto output = peek(1, 3);
              auto self = peek(2, 3);
              auto the_result = at::_sparse_log_softmax_backward_data(grad_output, output, dim, self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 658: { // norm
          at::Scalar p = readScalarAttribute("p");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::norm(self, p);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 659: { // norm
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::norm(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 660: { // frobenius_norm
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::frobenius_norm(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 661: { // frobenius_norm
          auto dim = readIntArrayRef("dim");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::frobenius_norm(self, dim, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 662: { // frobenius_norm
          auto dim = readIntArrayRef("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::frobenius_norm(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 663: { // nuclear_norm
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::nuclear_norm(self, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 664: { // nuclear_norm
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::nuclear_norm(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 665: { // nuclear_norm
          auto dim = readIntArrayRef("dim");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::nuclear_norm(self, dim, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 666: { // nuclear_norm
          auto dim = readIntArrayRef("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::nuclear_norm(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 667: { // clone
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::clone(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 668: { // pow
          at::Scalar exponent = readScalarAttribute("exponent");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::pow(self, exponent);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 669: { // sub
          at::Scalar alpha = readScalarAttribute("alpha");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::sub(self, other, alpha);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 670: { // sub
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::sub(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 671: { // sub
          at::Scalar other = readScalarAttribute("other");
          at::Scalar alpha = readScalarAttribute("alpha");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::sub(self, other, alpha);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 672: { // sub
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::sub(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 673: { // rsub
          at::Scalar alpha = readScalarAttribute("alpha");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::rsub(self, other, alpha);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 674: { // rsub
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::rsub(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 675: { // rsub
          at::Scalar other = readScalarAttribute("other");
          at::Scalar alpha = readScalarAttribute("alpha");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::rsub(self, other, alpha);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 676: { // rsub
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::rsub(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 677: { // _sparse_addmm
          at::Scalar beta = readScalarAttribute("beta");
          at::Scalar alpha = readScalarAttribute("alpha");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto sparse = peek(1, 3);
              auto dense = peek(2, 3);
              auto the_result = at::_sparse_addmm(self, sparse, dense, beta, alpha);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 678: { // _sparse_addmm
          at::Scalar beta = readScalarAttribute("beta");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto sparse = peek(1, 3);
              auto dense = peek(2, 3);
              auto the_result = at::_sparse_addmm(self, sparse, dense, beta);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 679: { // _sparse_addmm
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto sparse = peek(1, 3);
              auto dense = peek(2, 3);
              auto the_result = at::_sparse_addmm(self, sparse, dense);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 680: { // addmm
          at::Scalar beta = readScalarAttribute("beta");
          at::Scalar alpha = readScalarAttribute("alpha");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto mat1 = peek(1, 3);
              auto mat2 = peek(2, 3);
              auto the_result = at::addmm(self, mat1, mat2, beta, alpha);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 681: { // addmm
          at::Scalar beta = readScalarAttribute("beta");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto mat1 = peek(1, 3);
              auto mat2 = peek(2, 3);
              auto the_result = at::addmm(self, mat1, mat2, beta);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 682: { // addmm
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto mat1 = peek(1, 3);
              auto mat2 = peek(2, 3);
              auto the_result = at::addmm(self, mat1, mat2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 683: { // sparse_mask
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto mask = peek(1, 2);
              auto the_result = self.sparse_mask(mask);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 684: { // to_dense
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.to_dense();
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 685: { // to_dense_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 2);
              auto input = peek(1, 2);
              auto the_result = at::to_dense_backward(grad, input);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 686: { // sparse_dim
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.sparse_dim();
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 687: { // _dimI
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self._dimI();
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 688: { // dense_dim
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.dense_dim();
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 689: { // _dimV
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self._dimV();
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 690: { // _nnz
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self._nnz();
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 691: { // coalesce
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.coalesce();
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 692: { // is_coalesced
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.is_coalesced();
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 693: { // _indices
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self._indices();
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 694: { // _values
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self._values();
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 695: { // indices
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.indices();
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 696: { // values
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.values();
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 697: { // hspmm
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto mat1 = peek(0, 2);
              auto mat2 = peek(1, 2);
              auto the_result = at::hspmm(mat1, mat2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 698: { // unbind
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::unbind(self, dim);
                if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
              return true;
          };
      } break;
      case 699: { // unbind
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::unbind(self);
                if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
              return true;
          };
      } break;
      case 700: { // to_sparse
          int64_t sparse_dim = readAttribute<int64_t>("sparse_dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.to_sparse(sparse_dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 701: { // to_sparse
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.to_sparse();
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 702: { // to_mkldnn
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.to_mkldnn();
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 703: { // mkldnn_reorder_conv2d_weight
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          int64_t groups = readAttribute<int64_t>("groups");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mkldnn_reorder_conv2d_weight(self, padding, stride, dilation, groups);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 704: { // mkldnn_reorder_conv2d_weight
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mkldnn_reorder_conv2d_weight(self, padding, stride, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 705: { // mkldnn_reorder_conv2d_weight
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mkldnn_reorder_conv2d_weight(self, padding, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 706: { // mkldnn_reorder_conv2d_weight
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mkldnn_reorder_conv2d_weight(self, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 707: { // mkldnn_reorder_conv2d_weight
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mkldnn_reorder_conv2d_weight(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 708: { // to_mkldnn_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 2);
              auto input = peek(1, 2);
              auto the_result = at::to_mkldnn_backward(grad, input);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 709: { // dequantize
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::dequantize(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 710: { // dequantize
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto tensors = peekSlice(0, InputSize() - 0, InputSize());
              auto the_result = at::dequantize(tensors);
                if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
              return true;
          };
      } break;
      case 711: { // q_zero_point
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::q_zero_point(self);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 712: { // q_per_channel_scales
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::q_per_channel_scales(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 713: { // q_per_channel_zero_points
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::q_per_channel_zero_points(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 714: { // q_per_channel_axis
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::q_per_channel_axis(self);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 715: { // int_repr
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::int_repr(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 716: { // _make_per_tensor_quantized_tensor
          double scale = readAttribute<float>("scale");
          int64_t zero_point = readAttribute<int64_t>("zero_point");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_make_per_tensor_quantized_tensor(self, scale, zero_point);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 717: { // _make_per_channel_quantized_tensor
          int64_t axis = readAttribute<int64_t>("axis");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto scale = peek(1, 3);
              auto zero_point = peek(2, 3);
              auto the_result = at::_make_per_channel_quantized_tensor(self, scale, zero_point, axis);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 718: { // fake_quantize_per_tensor_affine
          double scale = readAttribute<float>("scale");
          int64_t zero_point = readAttribute<int64_t>("zero_point");
          int64_t quant_min = readAttribute<int64_t>("quant_min");
          int64_t quant_max = readAttribute<int64_t>("quant_max");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::fake_quantize_per_tensor_affine(self, scale, zero_point, quant_min, quant_max);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 719: { // fake_quantize_per_tensor_affine_backward
          double scale = readAttribute<float>("scale");
          int64_t zero_point = readAttribute<int64_t>("zero_point");
          int64_t quant_min = readAttribute<int64_t>("quant_min");
          int64_t quant_max = readAttribute<int64_t>("quant_max");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::fake_quantize_per_tensor_affine_backward(grad, self, scale, zero_point, quant_min, quant_max);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 720: { // fake_quantize_per_channel_affine
          int64_t axis = readAttribute<int64_t>("axis");
          int64_t quant_min = readAttribute<int64_t>("quant_min");
          int64_t quant_max = readAttribute<int64_t>("quant_max");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto scale = peek(1, 3);
              auto zero_point = peek(2, 3);
              auto the_result = at::fake_quantize_per_channel_affine(self, scale, zero_point, axis, quant_min, quant_max);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 721: { // fake_quantize_per_channel_affine_backward
          int64_t axis = readAttribute<int64_t>("axis");
          int64_t quant_min = readAttribute<int64_t>("quant_min");
          int64_t quant_max = readAttribute<int64_t>("quant_max");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 4);
              auto self = peek(1, 4);
              auto scale = peek(2, 4);
              auto zero_point = peek(3, 4);
              auto the_result = at::fake_quantize_per_channel_affine_backward(grad, self, scale, zero_point, axis, quant_min, quant_max);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 722: { // meshgrid
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto tensors = peekSlice(0, InputSize() - 0, InputSize());
              auto the_result = at::meshgrid(tensors);
                if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
              return true;
          };
      } break;
      case 723: { // cartesian_prod
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto tensors = peekSlice(0, InputSize() - 0, InputSize());
              auto the_result = at::cartesian_prod(tensors);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 724: { // combinations
          int64_t r = readAttribute<int64_t>("r");
          bool with_replacement = readAttribute<int64_t>("with_replacement");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::combinations(self, r, with_replacement);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 725: { // combinations
          int64_t r = readAttribute<int64_t>("r");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::combinations(self, r);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 726: { // combinations
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::combinations(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 727: { // item
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.item();
                if(OutputSize() > 0) {assignTo(Output(0),the_result.type(), the_result);}
              return true;
          };
      } break;
      case 728: { // _local_scalar_dense
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_local_scalar_dense(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result.type(), the_result);}
              return true;
          };
      } break;
      case 729: { // _thnn_fused_lstm_cell
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input_gates = peek(0, 5);
              auto hidden_gates = peek(1, 5);
              auto cx = peek(2, 5);
              auto input_bias = peek(3, 5);
              auto hidden_bias = peek(4, 5);
              auto the_result = at::_thnn_fused_lstm_cell(input_gates, hidden_gates, cx, input_bias, hidden_bias);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 730: { // _thnn_fused_lstm_cell
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input_gates = peek(0, 4);
              auto hidden_gates = peek(1, 4);
              auto cx = peek(2, 4);
              auto input_bias = peek(3, 4);
              auto the_result = at::_thnn_fused_lstm_cell(input_gates, hidden_gates, cx, input_bias);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 731: { // _thnn_fused_lstm_cell
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input_gates = peek(0, 3);
              auto hidden_gates = peek(1, 3);
              auto cx = peek(2, 3);
              auto the_result = at::_thnn_fused_lstm_cell(input_gates, hidden_gates, cx);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 732: { // _thnn_fused_lstm_cell_backward
          bool has_bias = readAttribute<int64_t>("has_bias");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_hy = peek(0, 5);
              auto grad_cy = peek(1, 5);
              auto cx = peek(2, 5);
              auto cy = peek(3, 5);
              auto workspace = peek(4, 5);
              auto the_result = at::_thnn_fused_lstm_cell_backward(grad_hy, grad_cy, cx, cy, workspace, has_bias);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
                if(OutputSize() > 4) {assignTo(Output(4),std::get<4>(the_result));}
              return true;
          };
      } break;
      case 733: { // _thnn_differentiable_lstm_cell_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_hy = peek(0, 8);
              auto grad_cy = peek(1, 8);
              auto input_gates = peek(2, 8);
              auto hidden_gates = peek(3, 8);
              auto input_bias = peek(4, 8);
              auto hidden_bias = peek(5, 8);
              auto cx = peek(6, 8);
              auto cy = peek(7, 8);
              auto the_result = at::_thnn_differentiable_lstm_cell_backward(grad_hy, grad_cy, input_gates, hidden_gates, input_bias, hidden_bias, cx, cy);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
                if(OutputSize() > 4) {assignTo(Output(4),std::get<4>(the_result));}
              return true;
          };
      } break;
      case 734: { // _thnn_fused_gru_cell
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input_gates = peek(0, 5);
              auto hidden_gates = peek(1, 5);
              auto hx = peek(2, 5);
              auto input_bias = peek(3, 5);
              auto hidden_bias = peek(4, 5);
              auto the_result = at::_thnn_fused_gru_cell(input_gates, hidden_gates, hx, input_bias, hidden_bias);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 735: { // _thnn_fused_gru_cell
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input_gates = peek(0, 4);
              auto hidden_gates = peek(1, 4);
              auto hx = peek(2, 4);
              auto input_bias = peek(3, 4);
              auto the_result = at::_thnn_fused_gru_cell(input_gates, hidden_gates, hx, input_bias);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 736: { // _thnn_fused_gru_cell
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input_gates = peek(0, 3);
              auto hidden_gates = peek(1, 3);
              auto hx = peek(2, 3);
              auto the_result = at::_thnn_fused_gru_cell(input_gates, hidden_gates, hx);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 737: { // _thnn_fused_gru_cell_backward
          bool has_bias = readAttribute<int64_t>("has_bias");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_hy = peek(0, 2);
              auto workspace = peek(1, 2);
              auto the_result = at::_thnn_fused_gru_cell_backward(grad_hy, workspace, has_bias);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
                if(OutputSize() > 4) {assignTo(Output(4),std::get<4>(the_result));}
              return true;
          };
      } break;
      case 738: { // _thnn_differentiable_gru_cell_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_hy = peek(0, 6);
              auto input_gates = peek(1, 6);
              auto hidden_gates = peek(2, 6);
              auto hx = peek(3, 6);
              auto input_bias = peek(4, 6);
              auto hidden_bias = peek(5, 6);
              auto the_result = at::_thnn_differentiable_gru_cell_backward(grad_hy, input_gates, hidden_gates, hx, input_bias, hidden_bias);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
                if(OutputSize() > 3) {assignTo(Output(3),std::get<3>(the_result));}
                if(OutputSize() > 4) {assignTo(Output(4),std::get<4>(the_result));}
              return true;
          };
      } break;
      case 739: { // lstm
          bool has_biases = readAttribute<int64_t>("has_biases");
          int64_t num_layers = readAttribute<int64_t>("num_layers");
          double dropout = readAttribute<float>("dropout");
          bool train = readAttribute<int64_t>("train");
          bool bidirectional = readAttribute<int64_t>("bidirectional");
          bool batch_first = readAttribute<int64_t>("batch_first");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, InputSize());
              auto hx = peekSlice(1, InputSize() - 1, InputSize());
              auto params = peekSlice(1, InputSize() - 1, InputSize());
              auto the_result = at::lstm(input, hx, params, has_biases, num_layers, dropout, train, bidirectional, batch_first);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 740: { // lstm
          bool has_biases = readAttribute<int64_t>("has_biases");
          int64_t num_layers = readAttribute<int64_t>("num_layers");
          double dropout = readAttribute<float>("dropout");
          bool train = readAttribute<int64_t>("train");
          bool bidirectional = readAttribute<int64_t>("bidirectional");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto data = peek(0, InputSize());
              auto batch_sizes = peek(1, InputSize());
              auto hx = peekSlice(2, InputSize() - 2, InputSize());
              auto params = peekSlice(2, InputSize() - 2, InputSize());
              auto the_result = at::lstm(data, batch_sizes, hx, params, has_biases, num_layers, dropout, train, bidirectional);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 741: { // gru
          bool has_biases = readAttribute<int64_t>("has_biases");
          int64_t num_layers = readAttribute<int64_t>("num_layers");
          double dropout = readAttribute<float>("dropout");
          bool train = readAttribute<int64_t>("train");
          bool bidirectional = readAttribute<int64_t>("bidirectional");
          bool batch_first = readAttribute<int64_t>("batch_first");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, InputSize());
              auto hx = peek(1, InputSize());
              auto params = peekSlice(2, InputSize() - 2, InputSize());
              auto the_result = at::gru(input, hx, params, has_biases, num_layers, dropout, train, bidirectional, batch_first);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 742: { // gru
          bool has_biases = readAttribute<int64_t>("has_biases");
          int64_t num_layers = readAttribute<int64_t>("num_layers");
          double dropout = readAttribute<float>("dropout");
          bool train = readAttribute<int64_t>("train");
          bool bidirectional = readAttribute<int64_t>("bidirectional");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto data = peek(0, InputSize());
              auto batch_sizes = peek(1, InputSize());
              auto hx = peek(2, InputSize());
              auto params = peekSlice(3, InputSize() - 3, InputSize());
              auto the_result = at::gru(data, batch_sizes, hx, params, has_biases, num_layers, dropout, train, bidirectional);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 743: { // rnn_tanh
          bool has_biases = readAttribute<int64_t>("has_biases");
          int64_t num_layers = readAttribute<int64_t>("num_layers");
          double dropout = readAttribute<float>("dropout");
          bool train = readAttribute<int64_t>("train");
          bool bidirectional = readAttribute<int64_t>("bidirectional");
          bool batch_first = readAttribute<int64_t>("batch_first");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, InputSize());
              auto hx = peek(1, InputSize());
              auto params = peekSlice(2, InputSize() - 2, InputSize());
              auto the_result = at::rnn_tanh(input, hx, params, has_biases, num_layers, dropout, train, bidirectional, batch_first);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 744: { // rnn_tanh
          bool has_biases = readAttribute<int64_t>("has_biases");
          int64_t num_layers = readAttribute<int64_t>("num_layers");
          double dropout = readAttribute<float>("dropout");
          bool train = readAttribute<int64_t>("train");
          bool bidirectional = readAttribute<int64_t>("bidirectional");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto data = peek(0, InputSize());
              auto batch_sizes = peek(1, InputSize());
              auto hx = peek(2, InputSize());
              auto params = peekSlice(3, InputSize() - 3, InputSize());
              auto the_result = at::rnn_tanh(data, batch_sizes, hx, params, has_biases, num_layers, dropout, train, bidirectional);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 745: { // rnn_relu
          bool has_biases = readAttribute<int64_t>("has_biases");
          int64_t num_layers = readAttribute<int64_t>("num_layers");
          double dropout = readAttribute<float>("dropout");
          bool train = readAttribute<int64_t>("train");
          bool bidirectional = readAttribute<int64_t>("bidirectional");
          bool batch_first = readAttribute<int64_t>("batch_first");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, InputSize());
              auto hx = peek(1, InputSize());
              auto params = peekSlice(2, InputSize() - 2, InputSize());
              auto the_result = at::rnn_relu(input, hx, params, has_biases, num_layers, dropout, train, bidirectional, batch_first);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 746: { // rnn_relu
          bool has_biases = readAttribute<int64_t>("has_biases");
          int64_t num_layers = readAttribute<int64_t>("num_layers");
          double dropout = readAttribute<float>("dropout");
          bool train = readAttribute<int64_t>("train");
          bool bidirectional = readAttribute<int64_t>("bidirectional");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto data = peek(0, InputSize());
              auto batch_sizes = peek(1, InputSize());
              auto hx = peek(2, InputSize());
              auto params = peekSlice(3, InputSize() - 3, InputSize());
              auto the_result = at::rnn_relu(data, batch_sizes, hx, params, has_biases, num_layers, dropout, train, bidirectional);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 747: { // lstm_cell
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, InputSize());
              auto hx = peekSlice(1, InputSize() - 5, InputSize());
              auto w_ih = peek(1, 5);
              auto w_hh = peek(2, 5);
              auto b_ih = peek(3, 5);
              auto b_hh = peek(4, 5);
              auto the_result = at::lstm_cell(input, hx, w_ih, w_hh, b_ih, b_hh);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 748: { // gru_cell
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 6);
              auto hx = peek(1, 6);
              auto w_ih = peek(2, 6);
              auto w_hh = peek(3, 6);
              auto b_ih = peek(4, 6);
              auto b_hh = peek(5, 6);
              auto the_result = at::gru_cell(input, hx, w_ih, w_hh, b_ih, b_hh);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 749: { // gru_cell
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 5);
              auto hx = peek(1, 5);
              auto w_ih = peek(2, 5);
              auto w_hh = peek(3, 5);
              auto b_ih = peek(4, 5);
              auto the_result = at::gru_cell(input, hx, w_ih, w_hh, b_ih);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 750: { // gru_cell
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 4);
              auto hx = peek(1, 4);
              auto w_ih = peek(2, 4);
              auto w_hh = peek(3, 4);
              auto the_result = at::gru_cell(input, hx, w_ih, w_hh);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 751: { // rnn_tanh_cell
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 6);
              auto hx = peek(1, 6);
              auto w_ih = peek(2, 6);
              auto w_hh = peek(3, 6);
              auto b_ih = peek(4, 6);
              auto b_hh = peek(5, 6);
              auto the_result = at::rnn_tanh_cell(input, hx, w_ih, w_hh, b_ih, b_hh);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 752: { // rnn_tanh_cell
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 5);
              auto hx = peek(1, 5);
              auto w_ih = peek(2, 5);
              auto w_hh = peek(3, 5);
              auto b_ih = peek(4, 5);
              auto the_result = at::rnn_tanh_cell(input, hx, w_ih, w_hh, b_ih);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 753: { // rnn_tanh_cell
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 4);
              auto hx = peek(1, 4);
              auto w_ih = peek(2, 4);
              auto w_hh = peek(3, 4);
              auto the_result = at::rnn_tanh_cell(input, hx, w_ih, w_hh);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 754: { // rnn_relu_cell
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 6);
              auto hx = peek(1, 6);
              auto w_ih = peek(2, 6);
              auto w_hh = peek(3, 6);
              auto b_ih = peek(4, 6);
              auto b_hh = peek(5, 6);
              auto the_result = at::rnn_relu_cell(input, hx, w_ih, w_hh, b_ih, b_hh);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 755: { // rnn_relu_cell
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 5);
              auto hx = peek(1, 5);
              auto w_ih = peek(2, 5);
              auto w_hh = peek(3, 5);
              auto b_ih = peek(4, 5);
              auto the_result = at::rnn_relu_cell(input, hx, w_ih, w_hh, b_ih);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 756: { // rnn_relu_cell
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 4);
              auto hx = peek(1, 4);
              auto w_ih = peek(2, 4);
              auto w_hh = peek(3, 4);
              auto the_result = at::rnn_relu_cell(input, hx, w_ih, w_hh);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 757: { // quantized_lstm_cell
          at::Scalar scale_ih = readScalarAttribute("scale_ih");
          at::Scalar scale_hh = readScalarAttribute("scale_hh");
          at::Scalar zero_point_ih = readScalarAttribute("zero_point_ih");
          at::Scalar zero_point_hh = readScalarAttribute("zero_point_hh");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, InputSize());
              auto hx = peekSlice(1, InputSize() - 9, InputSize());
              auto w_ih = peek(1, 9);
              auto w_hh = peek(2, 9);
              auto b_ih = peek(3, 9);
              auto b_hh = peek(4, 9);
              auto packed_ih = peek(5, 9);
              auto packed_hh = peek(6, 9);
              auto col_offsets_ih = peek(7, 9);
              auto col_offsets_hh = peek(8, 9);
              auto the_result = at::quantized_lstm_cell(input, hx, w_ih, w_hh, b_ih, b_hh, packed_ih, packed_hh, col_offsets_ih, col_offsets_hh, scale_ih, scale_hh, zero_point_ih, zero_point_hh);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 758: { // quantized_gru_cell
          at::Scalar scale_ih = readScalarAttribute("scale_ih");
          at::Scalar scale_hh = readScalarAttribute("scale_hh");
          at::Scalar zero_point_ih = readScalarAttribute("zero_point_ih");
          at::Scalar zero_point_hh = readScalarAttribute("zero_point_hh");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 10);
              auto hx = peek(1, 10);
              auto w_ih = peek(2, 10);
              auto w_hh = peek(3, 10);
              auto b_ih = peek(4, 10);
              auto b_hh = peek(5, 10);
              auto packed_ih = peek(6, 10);
              auto packed_hh = peek(7, 10);
              auto col_offsets_ih = peek(8, 10);
              auto col_offsets_hh = peek(9, 10);
              auto the_result = at::quantized_gru_cell(input, hx, w_ih, w_hh, b_ih, b_hh, packed_ih, packed_hh, col_offsets_ih, col_offsets_hh, scale_ih, scale_hh, zero_point_ih, zero_point_hh);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 759: { // quantized_rnn_relu_cell
          at::Scalar scale_ih = readScalarAttribute("scale_ih");
          at::Scalar scale_hh = readScalarAttribute("scale_hh");
          at::Scalar zero_point_ih = readScalarAttribute("zero_point_ih");
          at::Scalar zero_point_hh = readScalarAttribute("zero_point_hh");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 10);
              auto hx = peek(1, 10);
              auto w_ih = peek(2, 10);
              auto w_hh = peek(3, 10);
              auto b_ih = peek(4, 10);
              auto b_hh = peek(5, 10);
              auto packed_ih = peek(6, 10);
              auto packed_hh = peek(7, 10);
              auto col_offsets_ih = peek(8, 10);
              auto col_offsets_hh = peek(9, 10);
              auto the_result = at::quantized_rnn_relu_cell(input, hx, w_ih, w_hh, b_ih, b_hh, packed_ih, packed_hh, col_offsets_ih, col_offsets_hh, scale_ih, scale_hh, zero_point_ih, zero_point_hh);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 760: { // quantized_rnn_tanh_cell
          at::Scalar scale_ih = readScalarAttribute("scale_ih");
          at::Scalar scale_hh = readScalarAttribute("scale_hh");
          at::Scalar zero_point_ih = readScalarAttribute("zero_point_ih");
          at::Scalar zero_point_hh = readScalarAttribute("zero_point_hh");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 10);
              auto hx = peek(1, 10);
              auto w_ih = peek(2, 10);
              auto w_hh = peek(3, 10);
              auto b_ih = peek(4, 10);
              auto b_hh = peek(5, 10);
              auto packed_ih = peek(6, 10);
              auto packed_hh = peek(7, 10);
              auto col_offsets_ih = peek(8, 10);
              auto col_offsets_hh = peek(9, 10);
              auto the_result = at::quantized_rnn_tanh_cell(input, hx, w_ih, w_hh, b_ih, b_hh, packed_ih, packed_hh, col_offsets_ih, col_offsets_hh, scale_ih, scale_hh, zero_point_ih, zero_point_hh);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 761: { // _pack_padded_sequence
          bool batch_first = readAttribute<int64_t>("batch_first");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto input = peek(0, 2);
              auto lengths = peek(1, 2);
              auto the_result = at::_pack_padded_sequence(input, lengths, batch_first);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 762: { // _pack_padded_sequence_backward
          auto input_size = readIntArrayRef("input_size");
          bool batch_first = readAttribute<int64_t>("batch_first");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad = peek(0, 2);
              auto batch_sizes = peek(1, 2);
              auto the_result = at::_pack_padded_sequence_backward(grad, input_size, batch_sizes, batch_first);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 763: { // _pad_packed_sequence
          bool batch_first = readAttribute<int64_t>("batch_first");
          at::Scalar padding_value = readScalarAttribute("padding_value");
          int64_t total_length = readAttribute<int64_t>("total_length");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto data = peek(0, 2);
              auto batch_sizes = peek(1, 2);
              auto the_result = at::_pad_packed_sequence(data, batch_sizes, batch_first, padding_value, total_length);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 764: { // is_set_to
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto tensor = peek(1, 2);
              auto the_result = self.is_set_to(tensor);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 765: { // masked_fill
          at::Scalar value = readScalarAttribute("value");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto mask = peek(1, 2);
              auto the_result = at::masked_fill(self, mask, value);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 766: { // masked_fill
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto mask = peek(1, 3);
              auto value = peek(2, 3);
              auto the_result = at::masked_fill(self, mask, value);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 767: { // masked_scatter
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto mask = peek(1, 3);
              auto source = peek(2, 3);
              auto the_result = at::masked_scatter(self, mask, source);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 768: { // view
          auto size = readIntArrayRef("size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.view(size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 769: { // index_add
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto index = peek(1, 3);
              auto source = peek(2, 3);
              auto the_result = at::index_add(self, dim, index, source);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 770: { // index_fill
          int64_t dim = readAttribute<int64_t>("dim");
          at::Scalar value = readScalarAttribute("value");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto index = peek(1, 2);
              auto the_result = at::index_fill(self, dim, index, value);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 771: { // index_fill
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto index = peek(1, 3);
              auto value = peek(2, 3);
              auto the_result = at::index_fill(self, dim, index, value);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 772: { // scatter
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto index = peek(1, 3);
              auto src = peek(2, 3);
              auto the_result = at::scatter(self, dim, index, src);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 773: { // scatter
          int64_t dim = readAttribute<int64_t>("dim");
          at::Scalar value = readScalarAttribute("value");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto index = peek(1, 2);
              auto the_result = at::scatter(self, dim, index, value);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 774: { // scatter_add
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto index = peek(1, 3);
              auto src = peek(2, 3);
              auto the_result = at::scatter_add(self, dim, index, src);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 775: { // bitwise_and
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::bitwise_and(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 776: { // bitwise_and
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::bitwise_and(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 777: { // __and__
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::__and__(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 778: { // __and__
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::__and__(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 779: { // bitwise_or
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::bitwise_or(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 780: { // bitwise_or
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::bitwise_or(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 781: { // __or__
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::__or__(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 782: { // __or__
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::__or__(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 783: { // bitwise_xor
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::bitwise_xor(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 784: { // bitwise_xor
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::bitwise_xor(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 785: { // __xor__
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::__xor__(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 786: { // __xor__
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::__xor__(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 787: { // __lshift__
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::__lshift__(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 788: { // __lshift__
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::__lshift__(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 789: { // __rshift__
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::__rshift__(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 790: { // __rshift__
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::__rshift__(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 791: { // addbmm
          at::Scalar beta = readScalarAttribute("beta");
          at::Scalar alpha = readScalarAttribute("alpha");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto batch1 = peek(1, 3);
              auto batch2 = peek(2, 3);
              auto the_result = at::addbmm(self, batch1, batch2, beta, alpha);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 792: { // addbmm
          at::Scalar beta = readScalarAttribute("beta");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto batch1 = peek(1, 3);
              auto batch2 = peek(2, 3);
              auto the_result = at::addbmm(self, batch1, batch2, beta);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 793: { // addbmm
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto batch1 = peek(1, 3);
              auto batch2 = peek(2, 3);
              auto the_result = at::addbmm(self, batch1, batch2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 794: { // diag
          int64_t diagonal = readAttribute<int64_t>("diagonal");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::diag(self, diagonal);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 795: { // diag
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::diag(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 796: { // cross
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::cross(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 797: { // triu
          int64_t diagonal = readAttribute<int64_t>("diagonal");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::triu(self, diagonal);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 798: { // triu
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::triu(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 799: { // tril
          int64_t diagonal = readAttribute<int64_t>("diagonal");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::tril(self, diagonal);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 800: { // tril
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::tril(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 801: { // trace
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::trace(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 802: { // ne
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::ne(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 803: { // ne
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::ne(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 804: { // eq
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::eq(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 805: { // eq
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::eq(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 806: { // ge
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::ge(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 807: { // ge
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::ge(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 808: { // le
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::le(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 809: { // le
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::le(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 810: { // gt
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::gt(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 811: { // gt
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::gt(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 812: { // lt
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::lt(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 813: { // lt
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::lt(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 814: { // take
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto index = peek(1, 2);
              auto the_result = at::take(self, index);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 815: { // index_select
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto index = peek(1, 2);
              auto the_result = at::index_select(self, dim, index);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 816: { // masked_select
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto mask = peek(1, 2);
              auto the_result = at::masked_select(self, mask);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 817: { // nonzero
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::nonzero(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 818: { // nonzero_numpy
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::nonzero_numpy(self);
                if(OutputSize() > 0) {assignListStartingAt(0, the_result);}
              return true;
          };
      } break;
      case 819: { // gather
          int64_t dim = readAttribute<int64_t>("dim");
          bool sparse_grad = readAttribute<int64_t>("sparse_grad");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto index = peek(1, 2);
              auto the_result = at::gather(self, dim, index, sparse_grad);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 820: { // gather
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto index = peek(1, 2);
              auto the_result = at::gather(self, dim, index);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 821: { // _gather_sparse_backward
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto index = peek(1, 3);
              auto grad = peek(2, 3);
              auto the_result = at::_gather_sparse_backward(self, dim, index, grad);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 822: { // addcmul
          at::Scalar value = readScalarAttribute("value");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto tensor1 = peek(1, 3);
              auto tensor2 = peek(2, 3);
              auto the_result = at::addcmul(self, tensor1, tensor2, value);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 823: { // addcmul
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto tensor1 = peek(1, 3);
              auto tensor2 = peek(2, 3);
              auto the_result = at::addcmul(self, tensor1, tensor2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 824: { // addcdiv
          at::Scalar value = readScalarAttribute("value");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto tensor1 = peek(1, 3);
              auto tensor2 = peek(2, 3);
              auto the_result = at::addcdiv(self, tensor1, tensor2, value);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 825: { // addcdiv
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto tensor1 = peek(1, 3);
              auto tensor2 = peek(2, 3);
              auto the_result = at::addcdiv(self, tensor1, tensor2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 826: { // lstsq
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto A = peek(1, 2);
              auto the_result = at::lstsq(self, A);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 827: { // triangular_solve
          bool upper = readAttribute<int64_t>("upper");
          bool transpose = readAttribute<int64_t>("transpose");
          bool unitriangular = readAttribute<int64_t>("unitriangular");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto A = peek(1, 2);
              auto the_result = at::triangular_solve(self, A, upper, transpose, unitriangular);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 828: { // triangular_solve
          bool upper = readAttribute<int64_t>("upper");
          bool transpose = readAttribute<int64_t>("transpose");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto A = peek(1, 2);
              auto the_result = at::triangular_solve(self, A, upper, transpose);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 829: { // triangular_solve
          bool upper = readAttribute<int64_t>("upper");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto A = peek(1, 2);
              auto the_result = at::triangular_solve(self, A, upper);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 830: { // triangular_solve
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto A = peek(1, 2);
              auto the_result = at::triangular_solve(self, A);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 831: { // _triangular_solve_helper
          bool upper = readAttribute<int64_t>("upper");
          bool transpose = readAttribute<int64_t>("transpose");
          bool unitriangular = readAttribute<int64_t>("unitriangular");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto A = peek(1, 2);
              auto the_result = at::_triangular_solve_helper(self, A, upper, transpose, unitriangular);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 832: { // symeig
          bool eigenvectors = readAttribute<int64_t>("eigenvectors");
          bool upper = readAttribute<int64_t>("upper");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::symeig(self, eigenvectors, upper);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 833: { // symeig
          bool eigenvectors = readAttribute<int64_t>("eigenvectors");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::symeig(self, eigenvectors);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 834: { // symeig
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::symeig(self);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 835: { // _symeig_helper
          bool eigenvectors = readAttribute<int64_t>("eigenvectors");
          bool upper = readAttribute<int64_t>("upper");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_symeig_helper(self, eigenvectors, upper);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 836: { // eig
          bool eigenvectors = readAttribute<int64_t>("eigenvectors");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::eig(self, eigenvectors);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 837: { // eig
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::eig(self);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 838: { // svd
          bool some = readAttribute<int64_t>("some");
          bool compute_uv = readAttribute<int64_t>("compute_uv");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::svd(self, some, compute_uv);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 839: { // svd
          bool some = readAttribute<int64_t>("some");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::svd(self, some);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 840: { // svd
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::svd(self);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 841: { // _svd_helper
          bool some = readAttribute<int64_t>("some");
          bool compute_uv = readAttribute<int64_t>("compute_uv");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_svd_helper(self, some, compute_uv);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 842: { // cholesky
          bool upper = readAttribute<int64_t>("upper");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::cholesky(self, upper);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 843: { // cholesky
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::cholesky(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 844: { // _cholesky_helper
          bool upper = readAttribute<int64_t>("upper");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cholesky_helper(self, upper);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 845: { // cholesky_solve
          bool upper = readAttribute<int64_t>("upper");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto input2 = peek(1, 2);
              auto the_result = at::cholesky_solve(self, input2, upper);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 846: { // cholesky_solve
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto input2 = peek(1, 2);
              auto the_result = at::cholesky_solve(self, input2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 847: { // _cholesky_solve_helper
          bool upper = readAttribute<int64_t>("upper");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto A = peek(1, 2);
              auto the_result = at::_cholesky_solve_helper(self, A, upper);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 848: { // solve
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto A = peek(1, 2);
              auto the_result = at::solve(self, A);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 849: { // _solve_helper
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto A = peek(1, 2);
              auto the_result = at::_solve_helper(self, A);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 850: { // cholesky_inverse
          bool upper = readAttribute<int64_t>("upper");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::cholesky_inverse(self, upper);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 851: { // cholesky_inverse
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::cholesky_inverse(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 852: { // qr
          bool some = readAttribute<int64_t>("some");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::qr(self, some);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 853: { // qr
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::qr(self);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 854: { // _qr_helper
          bool some = readAttribute<int64_t>("some");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_qr_helper(self, some);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 855: { // geqrf
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::geqrf(self);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 856: { // orgqr
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto input2 = peek(1, 2);
              auto the_result = at::orgqr(self, input2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 857: { // ormqr
          bool left = readAttribute<int64_t>("left");
          bool transpose = readAttribute<int64_t>("transpose");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto input2 = peek(1, 3);
              auto input3 = peek(2, 3);
              auto the_result = at::ormqr(self, input2, input3, left, transpose);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 858: { // ormqr
          bool left = readAttribute<int64_t>("left");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto input2 = peek(1, 3);
              auto input3 = peek(2, 3);
              auto the_result = at::ormqr(self, input2, input3, left);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 859: { // ormqr
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto input2 = peek(1, 3);
              auto input3 = peek(2, 3);
              auto the_result = at::ormqr(self, input2, input3);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 860: { // _lu_with_info
          bool pivot = readAttribute<int64_t>("pivot");
          bool check_errors = readAttribute<int64_t>("check_errors");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_lu_with_info(self, pivot, check_errors);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 861: { // _lu_with_info
          bool pivot = readAttribute<int64_t>("pivot");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_lu_with_info(self, pivot);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 862: { // _lu_with_info
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_lu_with_info(self);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 863: { // lu_solve
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto LU_data = peek(1, 3);
              auto LU_pivots = peek(2, 3);
              auto the_result = at::lu_solve(self, LU_data, LU_pivots);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 864: { // _lu_solve_helper
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto LU_data = peek(1, 3);
              auto LU_pivots = peek(2, 3);
              auto the_result = at::_lu_solve_helper(self, LU_data, LU_pivots);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 865: { // multinomial
          int64_t num_samples = readAttribute<int64_t>("num_samples");
          bool replacement = readAttribute<int64_t>("replacement");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::multinomial(self, num_samples, replacement);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 866: { // multinomial
          int64_t num_samples = readAttribute<int64_t>("num_samples");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::multinomial(self, num_samples);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 867: { // _multinomial_alias_setup
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto probs = peek(0, 1);
              auto the_result = at::_multinomial_alias_setup(probs);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 868: { // _multinomial_alias_draw
          int64_t num_samples = readAttribute<int64_t>("num_samples");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto J = peek(0, 2);
              auto q = peek(1, 2);
              auto the_result = at::_multinomial_alias_draw(J, q, num_samples);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 869: { // lgamma
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::lgamma(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 870: { // digamma
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::digamma(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 871: { // polygamma
          int64_t n = readAttribute<int64_t>("n");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::polygamma(n, self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 872: { // erfinv
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::erfinv(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 873: { // sign
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::sign(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 874: { // dist
          at::Scalar p = readScalarAttribute("p");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::dist(self, other, p);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 875: { // dist
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::dist(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 876: { // atan2
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::atan2(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 877: { // lerp
          at::Scalar weight = readScalarAttribute("weight");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto end = peek(1, 2);
              auto the_result = at::lerp(self, end, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 878: { // lerp
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto end = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::lerp(self, end, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 879: { // histc
          int64_t bins = readAttribute<int64_t>("bins");
          at::Scalar min = readScalarAttribute("min");
          at::Scalar max = readScalarAttribute("max");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::histc(self, bins, min, max);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 880: { // histc
          int64_t bins = readAttribute<int64_t>("bins");
          at::Scalar min = readScalarAttribute("min");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::histc(self, bins, min);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 881: { // histc
          int64_t bins = readAttribute<int64_t>("bins");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::histc(self, bins);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 882: { // histc
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::histc(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 883: { // fmod
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::fmod(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 884: { // fmod
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::fmod(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 885: { // remainder
          at::Scalar other = readScalarAttribute("other");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::remainder(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 886: { // remainder
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::remainder(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 887: { // min
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::min(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 888: { // min
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::min(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 889: { // max
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::max(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 890: { // max
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 891: { // median
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::median(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 892: { // sort
          int64_t dim = readAttribute<int64_t>("dim");
          bool descending = readAttribute<int64_t>("descending");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::sort(self, dim, descending);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 893: { // sort
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::sort(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 894: { // sort
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::sort(self);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 895: { // argsort
          int64_t dim = readAttribute<int64_t>("dim");
          bool descending = readAttribute<int64_t>("descending");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::argsort(self, dim, descending);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 896: { // argsort
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::argsort(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 897: { // argsort
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::argsort(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 898: { // topk
          int64_t k = readAttribute<int64_t>("k");
          int64_t dim = readAttribute<int64_t>("dim");
          bool largest = readAttribute<int64_t>("largest");
          bool sorted = readAttribute<int64_t>("sorted");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::topk(self, k, dim, largest, sorted);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 899: { // topk
          int64_t k = readAttribute<int64_t>("k");
          int64_t dim = readAttribute<int64_t>("dim");
          bool largest = readAttribute<int64_t>("largest");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::topk(self, k, dim, largest);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 900: { // topk
          int64_t k = readAttribute<int64_t>("k");
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::topk(self, k, dim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 901: { // topk
          int64_t k = readAttribute<int64_t>("k");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::topk(self, k);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 902: { // all
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::all(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 903: { // any
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::any(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 904: { // renorm
          at::Scalar p = readScalarAttribute("p");
          int64_t dim = readAttribute<int64_t>("dim");
          at::Scalar maxnorm = readScalarAttribute("maxnorm");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::renorm(self, p, dim, maxnorm);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 905: { // unfold
          int64_t dimension = readAttribute<int64_t>("dimension");
          int64_t size = readAttribute<int64_t>("size");
          int64_t step = readAttribute<int64_t>("step");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = self.unfold(dimension, size, step);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 906: { // unfold_backward
          auto input_sizes = readIntArrayRef("input_sizes");
          int64_t dim = readAttribute<int64_t>("dim");
          int64_t size = readAttribute<int64_t>("size");
          int64_t step = readAttribute<int64_t>("step");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_in = peek(0, 1);
              auto the_result = at::unfold_backward(grad_in, input_sizes, dim, size, step);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 907: { // equal
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::equal(self, other);
                if(OutputSize() > 0) {assignToValue<int64_t>(Output(0),the_result);}
              return true;
          };
      } break;
      case 908: { // pow
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto exponent = peek(1, 2);
              auto the_result = at::pow(self, exponent);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 909: { // pow
          at::Scalar self = readScalarAttribute("self");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto exponent = peek(0, 1);
              auto the_result = at::pow(self, exponent);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 910: { // alias
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::alias(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 911: { // _addr
          at::Scalar beta = readScalarAttribute("beta");
          at::Scalar alpha = readScalarAttribute("alpha");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto vec1 = peek(1, 3);
              auto vec2 = peek(2, 3);
              auto the_result = at::_addr(self, vec1, vec2, beta, alpha);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 912: { // _addr
          at::Scalar beta = readScalarAttribute("beta");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto vec1 = peek(1, 3);
              auto vec2 = peek(2, 3);
              auto the_result = at::_addr(self, vec1, vec2, beta);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 913: { // _addr
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto vec1 = peek(1, 3);
              auto vec2 = peek(2, 3);
              auto the_result = at::_addr(self, vec1, vec2);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 914: { // _cumsum
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cumsum(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 915: { // _cumprod
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_cumprod(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 916: { // _amp_update_scale
          double scale_growth_factor = readAttribute<float>("scale_growth_factor");
          double scale_backoff_factor = readAttribute<float>("scale_backoff_factor");
          int64_t growth_interval = readAttribute<int64_t>("growth_interval");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto growth_tracker = peek(0, 3);
              auto current_scale = peek(1, 3);
              auto found_inf = peek(2, 3);
              auto the_result = at::_amp_update_scale(growth_tracker, current_scale, found_inf, scale_growth_factor, scale_backoff_factor, growth_interval);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 917: { // _cat
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto tensors = peekSlice(0, InputSize() - 0, InputSize());
              auto the_result = at::_cat(tensors, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 918: { // _cat
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto tensors = peekSlice(0, InputSize() - 0, InputSize());
              auto the_result = at::_cat(tensors);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 919: { // _mode
          int64_t dim = readAttribute<int64_t>("dim");
          bool keepdim = readAttribute<int64_t>("keepdim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_mode(self, dim, keepdim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 920: { // _mode
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_mode(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 921: { // _mode
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_mode(self);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 922: { // bucketize
          bool out_int32 = readAttribute<int64_t>("out_int32");
          bool right = readAttribute<int64_t>("right");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto boundaries = peek(1, 2);
              auto the_result = at::bucketize(self, boundaries, out_int32, right);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 923: { // bucketize
          bool out_int32 = readAttribute<int64_t>("out_int32");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto boundaries = peek(1, 2);
              auto the_result = at::bucketize(self, boundaries, out_int32);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 924: { // bucketize
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto boundaries = peek(1, 2);
              auto the_result = at::bucketize(self, boundaries);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 925: { // bucketize
          at::Scalar self = readScalarAttribute("self");
          bool out_int32 = readAttribute<int64_t>("out_int32");
          bool right = readAttribute<int64_t>("right");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto boundaries = peek(0, 1);
              auto the_result = at::bucketize(self, boundaries, out_int32, right);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 926: { // bucketize
          at::Scalar self = readScalarAttribute("self");
          bool out_int32 = readAttribute<int64_t>("out_int32");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto boundaries = peek(0, 1);
              auto the_result = at::bucketize(self, boundaries, out_int32);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 927: { // bucketize
          at::Scalar self = readScalarAttribute("self");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto boundaries = peek(0, 1);
              auto the_result = at::bucketize(self, boundaries);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 928: { // searchsorted
          bool out_int32 = readAttribute<int64_t>("out_int32");
          bool right = readAttribute<int64_t>("right");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto sorted_sequence = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::searchsorted(sorted_sequence, self, out_int32, right);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 929: { // searchsorted
          bool out_int32 = readAttribute<int64_t>("out_int32");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto sorted_sequence = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::searchsorted(sorted_sequence, self, out_int32);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 930: { // searchsorted
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto sorted_sequence = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::searchsorted(sorted_sequence, self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 931: { // searchsorted
          at::Scalar self = readScalarAttribute("self");
          bool out_int32 = readAttribute<int64_t>("out_int32");
          bool right = readAttribute<int64_t>("right");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto sorted_sequence = peek(0, 1);
              auto the_result = at::searchsorted(sorted_sequence, self, out_int32, right);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 932: { // searchsorted
          at::Scalar self = readScalarAttribute("self");
          bool out_int32 = readAttribute<int64_t>("out_int32");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto sorted_sequence = peek(0, 1);
              auto the_result = at::searchsorted(sorted_sequence, self, out_int32);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 933: { // searchsorted
          at::Scalar self = readScalarAttribute("self");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto sorted_sequence = peek(0, 1);
              auto the_result = at::searchsorted(sorted_sequence, self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 934: { // mse_loss
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::mse_loss(self, target, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 935: { // mse_loss
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::mse_loss(self, target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 936: { // mse_loss_backward
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto target = peek(2, 3);
              auto the_result = at::mse_loss_backward(grad_output, self, target, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 937: { // l1_loss
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::l1_loss(self, target, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 938: { // l1_loss
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::l1_loss(self, target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 939: { // l1_loss_backward
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto target = peek(2, 3);
              auto the_result = at::l1_loss_backward(grad_output, self, target, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 940: { // multi_margin_loss
          at::Scalar p = readScalarAttribute("p");
          at::Scalar margin = readScalarAttribute("margin");
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto target = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::multi_margin_loss(self, target, p, margin, weight, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 941: { // multi_margin_loss
          at::Scalar p = readScalarAttribute("p");
          at::Scalar margin = readScalarAttribute("margin");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto target = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::multi_margin_loss(self, target, p, margin, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 942: { // multi_margin_loss
          at::Scalar p = readScalarAttribute("p");
          at::Scalar margin = readScalarAttribute("margin");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::multi_margin_loss(self, target, p, margin);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 943: { // multi_margin_loss
          at::Scalar p = readScalarAttribute("p");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::multi_margin_loss(self, target, p);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 944: { // multi_margin_loss
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::multi_margin_loss(self, target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 945: { // multi_margin_loss_backward
          at::Scalar p = readScalarAttribute("p");
          at::Scalar margin = readScalarAttribute("margin");
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 4);
              auto self = peek(1, 4);
              auto target = peek(2, 4);
              auto weight = peek(3, 4);
              auto the_result = at::multi_margin_loss_backward(grad_output, self, target, p, margin, weight, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 946: { // multi_margin_loss_backward
          at::Scalar p = readScalarAttribute("p");
          at::Scalar margin = readScalarAttribute("margin");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 4);
              auto self = peek(1, 4);
              auto target = peek(2, 4);
              auto weight = peek(3, 4);
              auto the_result = at::multi_margin_loss_backward(grad_output, self, target, p, margin, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 947: { // multi_margin_loss_backward
          at::Scalar p = readScalarAttribute("p");
          at::Scalar margin = readScalarAttribute("margin");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto target = peek(2, 3);
              auto the_result = at::multi_margin_loss_backward(grad_output, self, target, p, margin);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 948: { // multilabel_margin_loss
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::multilabel_margin_loss(self, target, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 949: { // multilabel_margin_loss
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::multilabel_margin_loss(self, target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 950: { // multilabel_margin_loss_forward
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::multilabel_margin_loss_forward(self, target, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 951: { // multilabel_margin_loss_backward
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 4);
              auto self = peek(1, 4);
              auto target = peek(2, 4);
              auto is_target = peek(3, 4);
              auto the_result = at::multilabel_margin_loss_backward(grad_output, self, target, reduction, is_target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 952: { // nll_loss
          int64_t reduction = readAttribute<int64_t>("reduction");
          int64_t ignore_index = readAttribute<int64_t>("ignore_index");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto target = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::nll_loss(self, target, weight, reduction, ignore_index);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 953: { // nll_loss
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto target = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::nll_loss(self, target, weight, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 954: { // nll_loss
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto target = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::nll_loss(self, target, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 955: { // nll_loss
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::nll_loss(self, target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 956: { // nll_loss_forward
          int64_t reduction = readAttribute<int64_t>("reduction");
          int64_t ignore_index = readAttribute<int64_t>("ignore_index");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto target = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::nll_loss_forward(self, target, weight, reduction, ignore_index);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 957: { // nll_loss_backward
          int64_t reduction = readAttribute<int64_t>("reduction");
          int64_t ignore_index = readAttribute<int64_t>("ignore_index");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 5);
              auto self = peek(1, 5);
              auto target = peek(2, 5);
              auto weight = peek(3, 5);
              auto total_weight = peek(4, 5);
              auto the_result = at::nll_loss_backward(grad_output, self, target, weight, reduction, ignore_index, total_weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 958: { // nll_loss2d
          int64_t reduction = readAttribute<int64_t>("reduction");
          int64_t ignore_index = readAttribute<int64_t>("ignore_index");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto target = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::nll_loss2d(self, target, weight, reduction, ignore_index);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 959: { // nll_loss2d
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto target = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::nll_loss2d(self, target, weight, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 960: { // nll_loss2d
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto target = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::nll_loss2d(self, target, weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 961: { // nll_loss2d
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::nll_loss2d(self, target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 962: { // nll_loss2d_forward
          int64_t reduction = readAttribute<int64_t>("reduction");
          int64_t ignore_index = readAttribute<int64_t>("ignore_index");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto target = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::nll_loss2d_forward(self, target, weight, reduction, ignore_index);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 963: { // nll_loss2d_backward
          int64_t reduction = readAttribute<int64_t>("reduction");
          int64_t ignore_index = readAttribute<int64_t>("ignore_index");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 5);
              auto self = peek(1, 5);
              auto target = peek(2, 5);
              auto weight = peek(3, 5);
              auto total_weight = peek(4, 5);
              auto the_result = at::nll_loss2d_backward(grad_output, self, target, weight, reduction, ignore_index, total_weight);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 964: { // smooth_l1_loss
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::smooth_l1_loss(self, target, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 965: { // smooth_l1_loss
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::smooth_l1_loss(self, target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 966: { // smooth_l1_loss_backward
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto target = peek(2, 3);
              auto the_result = at::smooth_l1_loss_backward(grad_output, self, target, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 967: { // soft_margin_loss
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::soft_margin_loss(self, target, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 968: { // soft_margin_loss
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto target = peek(1, 2);
              auto the_result = at::soft_margin_loss(self, target);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 969: { // soft_margin_loss_backward
          int64_t reduction = readAttribute<int64_t>("reduction");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto target = peek(2, 3);
              auto the_result = at::soft_margin_loss_backward(grad_output, self, target, reduction);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 970: { // elu
          at::Scalar alpha = readScalarAttribute("alpha");
          at::Scalar scale = readScalarAttribute("scale");
          at::Scalar input_scale = readScalarAttribute("input_scale");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::elu(self, alpha, scale, input_scale);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 971: { // elu
          at::Scalar alpha = readScalarAttribute("alpha");
          at::Scalar scale = readScalarAttribute("scale");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::elu(self, alpha, scale);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 972: { // elu
          at::Scalar alpha = readScalarAttribute("alpha");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::elu(self, alpha);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 973: { // elu
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::elu(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 974: { // elu_backward
          at::Scalar alpha = readScalarAttribute("alpha");
          at::Scalar scale = readScalarAttribute("scale");
          at::Scalar input_scale = readScalarAttribute("input_scale");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto output = peek(1, 2);
              auto the_result = at::elu_backward(grad_output, alpha, scale, input_scale, output);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 975: { // glu
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::glu(self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 976: { // glu
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::glu(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 977: { // glu_backward
          int64_t dim = readAttribute<int64_t>("dim");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::glu_backward(grad_output, self, dim);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 978: { // hardsigmoid
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::hardsigmoid(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 979: { // hardsigmoid_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::hardsigmoid_backward(grad_output, self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 980: { // hardtanh
          at::Scalar min_val = readScalarAttribute("min_val");
          at::Scalar max_val = readScalarAttribute("max_val");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::hardtanh(self, min_val, max_val);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 981: { // hardtanh
          at::Scalar min_val = readScalarAttribute("min_val");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::hardtanh(self, min_val);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 982: { // hardtanh
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::hardtanh(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 983: { // hardtanh_backward
          at::Scalar min_val = readScalarAttribute("min_val");
          at::Scalar max_val = readScalarAttribute("max_val");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::hardtanh_backward(grad_output, self, min_val, max_val);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 984: { // hardswish
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::hardswish(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 985: { // hardswish_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::hardswish_backward(grad_output, self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 986: { // leaky_relu
          at::Scalar negative_slope = readScalarAttribute("negative_slope");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::leaky_relu(self, negative_slope);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 987: { // leaky_relu
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::leaky_relu(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 988: { // leaky_relu_backward
          at::Scalar negative_slope = readScalarAttribute("negative_slope");
          bool self_is_result = readAttribute<int64_t>("self_is_result");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::leaky_relu_backward(grad_output, self, negative_slope, self_is_result);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 989: { // log_sigmoid
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::log_sigmoid(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 990: { // log_sigmoid_forward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::log_sigmoid_forward(self);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 991: { // log_sigmoid_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto buffer = peek(2, 3);
              auto the_result = at::log_sigmoid_backward(grad_output, self, buffer);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 992: { // rrelu_with_noise
          at::Scalar lower = readScalarAttribute("lower");
          at::Scalar upper = readScalarAttribute("upper");
          bool training = readAttribute<int64_t>("training");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto noise = peek(1, 2);
              auto the_result = at::rrelu_with_noise(self, noise, lower, upper, training);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 993: { // rrelu_with_noise
          at::Scalar lower = readScalarAttribute("lower");
          at::Scalar upper = readScalarAttribute("upper");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto noise = peek(1, 2);
              auto the_result = at::rrelu_with_noise(self, noise, lower, upper);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 994: { // rrelu_with_noise
          at::Scalar lower = readScalarAttribute("lower");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto noise = peek(1, 2);
              auto the_result = at::rrelu_with_noise(self, noise, lower);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 995: { // rrelu_with_noise
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto noise = peek(1, 2);
              auto the_result = at::rrelu_with_noise(self, noise);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 996: { // rrelu_with_noise_backward
          at::Scalar lower = readScalarAttribute("lower");
          at::Scalar upper = readScalarAttribute("upper");
          bool training = readAttribute<int64_t>("training");
          bool self_is_result = readAttribute<int64_t>("self_is_result");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto noise = peek(2, 3);
              auto the_result = at::rrelu_with_noise_backward(grad_output, self, noise, lower, upper, training, self_is_result);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 997: { // softplus
          at::Scalar beta = readScalarAttribute("beta");
          at::Scalar threshold = readScalarAttribute("threshold");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::softplus(self, beta, threshold);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 998: { // softplus
          at::Scalar beta = readScalarAttribute("beta");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::softplus(self, beta);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 999: { // softplus
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::softplus(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1000: { // softplus_backward
          at::Scalar beta = readScalarAttribute("beta");
          at::Scalar threshold = readScalarAttribute("threshold");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto output = peek(2, 3);
              auto the_result = at::softplus_backward(grad_output, self, beta, threshold, output);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1001: { // softshrink
          at::Scalar lambd = readScalarAttribute("lambd");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::softshrink(self, lambd);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1002: { // softshrink
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::softshrink(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1003: { // softshrink_backward
          at::Scalar lambd = readScalarAttribute("lambd");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::softshrink_backward(grad_output, self, lambd);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1004: { // adaptive_avg_pool2d
          auto output_size = readIntArrayRef("output_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::adaptive_avg_pool2d(self, output_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1005: { // mkldnn_adaptive_avg_pool2d
          auto output_size = readIntArrayRef("output_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::mkldnn_adaptive_avg_pool2d(self, output_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1006: { // _adaptive_avg_pool2d
          auto output_size = readIntArrayRef("output_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::_adaptive_avg_pool2d(self, output_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1007: { // _adaptive_avg_pool2d_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::_adaptive_avg_pool2d_backward(grad_output, self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1008: { // adaptive_avg_pool3d
          auto output_size = readIntArrayRef("output_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::adaptive_avg_pool3d(self, output_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1009: { // adaptive_avg_pool3d_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::adaptive_avg_pool3d_backward(grad_output, self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1010: { // adaptive_max_pool2d
          auto output_size = readIntArrayRef("output_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::adaptive_max_pool2d(self, output_size);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 1011: { // adaptive_max_pool2d_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto indices = peek(2, 3);
              auto the_result = at::adaptive_max_pool2d_backward(grad_output, self, indices);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1012: { // adaptive_max_pool3d
          auto output_size = readIntArrayRef("output_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::adaptive_max_pool3d(self, output_size);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 1013: { // adaptive_max_pool3d_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto indices = peek(2, 3);
              auto the_result = at::adaptive_max_pool3d_backward(grad_output, self, indices);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1014: { // avg_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          bool ceil_mode = readAttribute<int64_t>("ceil_mode");
          bool count_include_pad = readAttribute<int64_t>("count_include_pad");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::avg_pool2d(self, kernel_size, stride, padding, ceil_mode, count_include_pad);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1015: { // avg_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          bool ceil_mode = readAttribute<int64_t>("ceil_mode");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::avg_pool2d(self, kernel_size, stride, padding, ceil_mode);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1016: { // avg_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::avg_pool2d(self, kernel_size, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1017: { // avg_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::avg_pool2d(self, kernel_size, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1018: { // avg_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::avg_pool2d(self, kernel_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1019: { // avg_pool3d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          bool ceil_mode = readAttribute<int64_t>("ceil_mode");
          bool count_include_pad = readAttribute<int64_t>("count_include_pad");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::avg_pool3d(self, kernel_size, stride, padding, ceil_mode, count_include_pad);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1020: { // avg_pool3d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          bool ceil_mode = readAttribute<int64_t>("ceil_mode");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::avg_pool3d(self, kernel_size, stride, padding, ceil_mode);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1021: { // avg_pool3d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::avg_pool3d(self, kernel_size, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1022: { // avg_pool3d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::avg_pool3d(self, kernel_size, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1023: { // avg_pool3d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::avg_pool3d(self, kernel_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1024: { // fractional_max_pool2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto output_size = readIntArrayRef("output_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto random_samples = peek(1, 2);
              auto the_result = at::fractional_max_pool2d(self, kernel_size, output_size, random_samples);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 1025: { // fractional_max_pool2d_backward
          auto kernel_size = readIntArrayRef("kernel_size");
          auto output_size = readIntArrayRef("output_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto indices = peek(2, 3);
              auto the_result = at::fractional_max_pool2d_backward(grad_output, self, kernel_size, output_size, indices);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1026: { // fractional_max_pool3d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto output_size = readIntArrayRef("output_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto random_samples = peek(1, 2);
              auto the_result = at::fractional_max_pool3d(self, kernel_size, output_size, random_samples);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 1027: { // fractional_max_pool3d_backward
          auto kernel_size = readIntArrayRef("kernel_size");
          auto output_size = readIntArrayRef("output_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto indices = peek(2, 3);
              auto the_result = at::fractional_max_pool3d_backward(grad_output, self, kernel_size, output_size, indices);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1028: { // max_pool2d_with_indices
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          bool ceil_mode = readAttribute<int64_t>("ceil_mode");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool2d_with_indices(self, kernel_size, stride, padding, dilation, ceil_mode);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 1029: { // max_pool2d_with_indices
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool2d_with_indices(self, kernel_size, stride, padding, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 1030: { // max_pool2d_with_indices
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool2d_with_indices(self, kernel_size, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 1031: { // max_pool2d_with_indices
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool2d_with_indices(self, kernel_size, stride);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 1032: { // max_pool2d_with_indices
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool2d_with_indices(self, kernel_size);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 1033: { // max_pool2d_with_indices_backward
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          bool ceil_mode = readAttribute<int64_t>("ceil_mode");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto indices = peek(2, 3);
              auto the_result = at::max_pool2d_with_indices_backward(grad_output, self, kernel_size, stride, padding, dilation, ceil_mode, indices);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1034: { // max_pool3d_with_indices
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          bool ceil_mode = readAttribute<int64_t>("ceil_mode");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool3d_with_indices(self, kernel_size, stride, padding, dilation, ceil_mode);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 1035: { // max_pool3d_with_indices
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool3d_with_indices(self, kernel_size, stride, padding, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 1036: { // max_pool3d_with_indices
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool3d_with_indices(self, kernel_size, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 1037: { // max_pool3d_with_indices
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool3d_with_indices(self, kernel_size, stride);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 1038: { // max_pool3d_with_indices
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::max_pool3d_with_indices(self, kernel_size);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 1039: { // max_pool3d_with_indices_backward
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          bool ceil_mode = readAttribute<int64_t>("ceil_mode");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto indices = peek(2, 3);
              auto the_result = at::max_pool3d_with_indices_backward(grad_output, self, kernel_size, stride, padding, dilation, ceil_mode, indices);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1040: { // max_unpool2d
          auto output_size = readIntArrayRef("output_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto indices = peek(1, 2);
              auto the_result = at::max_unpool2d(self, indices, output_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1041: { // max_unpool2d_backward
          auto output_size = readIntArrayRef("output_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto indices = peek(2, 3);
              auto the_result = at::max_unpool2d_backward(grad_output, self, indices, output_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1042: { // max_unpool3d
          auto output_size = readIntArrayRef("output_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto indices = peek(1, 2);
              auto the_result = at::max_unpool3d(self, indices, output_size, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1043: { // max_unpool3d_backward
          auto output_size = readIntArrayRef("output_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto indices = peek(2, 3);
              auto the_result = at::max_unpool3d_backward(grad_output, self, indices, output_size, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1044: { // reflection_pad1d
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::reflection_pad1d(self, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1045: { // reflection_pad1d_backward
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::reflection_pad1d_backward(grad_output, self, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1046: { // reflection_pad2d
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::reflection_pad2d(self, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1047: { // reflection_pad2d_backward
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::reflection_pad2d_backward(grad_output, self, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1048: { // replication_pad1d
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::replication_pad1d(self, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1049: { // replication_pad1d_backward
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::replication_pad1d_backward(grad_output, self, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1050: { // replication_pad2d
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::replication_pad2d(self, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1051: { // replication_pad2d_backward
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::replication_pad2d_backward(grad_output, self, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1052: { // replication_pad3d
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::replication_pad3d(self, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1053: { // replication_pad3d_backward
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto self = peek(1, 2);
              auto the_result = at::replication_pad3d_backward(grad_output, self, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1054: { // upsample_linear1d
          auto output_size = readIntArrayRef("output_size");
          bool align_corners = readAttribute<int64_t>("align_corners");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::upsample_linear1d(self, output_size, align_corners);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1055: { // upsample_linear1d_backward
          auto output_size = readIntArrayRef("output_size");
          auto input_size = readIntArrayRef("input_size");
          bool align_corners = readAttribute<int64_t>("align_corners");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 1);
              auto the_result = at::upsample_linear1d_backward(grad_output, output_size, input_size, align_corners);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1056: { // upsample_bilinear2d
          auto output_size = readIntArrayRef("output_size");
          bool align_corners = readAttribute<int64_t>("align_corners");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::upsample_bilinear2d(self, output_size, align_corners);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1057: { // upsample_bilinear2d_backward
          auto output_size = readIntArrayRef("output_size");
          auto input_size = readIntArrayRef("input_size");
          bool align_corners = readAttribute<int64_t>("align_corners");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 1);
              auto the_result = at::upsample_bilinear2d_backward(grad_output, output_size, input_size, align_corners);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1058: { // upsample_bicubic2d
          auto output_size = readIntArrayRef("output_size");
          bool align_corners = readAttribute<int64_t>("align_corners");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::upsample_bicubic2d(self, output_size, align_corners);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1059: { // upsample_bicubic2d_backward
          auto output_size = readIntArrayRef("output_size");
          auto input_size = readIntArrayRef("input_size");
          bool align_corners = readAttribute<int64_t>("align_corners");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 1);
              auto the_result = at::upsample_bicubic2d_backward(grad_output, output_size, input_size, align_corners);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1060: { // upsample_trilinear3d
          auto output_size = readIntArrayRef("output_size");
          bool align_corners = readAttribute<int64_t>("align_corners");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::upsample_trilinear3d(self, output_size, align_corners);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1061: { // upsample_trilinear3d_backward
          auto output_size = readIntArrayRef("output_size");
          auto input_size = readIntArrayRef("input_size");
          bool align_corners = readAttribute<int64_t>("align_corners");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 1);
              auto the_result = at::upsample_trilinear3d_backward(grad_output, output_size, input_size, align_corners);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1062: { // upsample_nearest1d
          auto output_size = readIntArrayRef("output_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::upsample_nearest1d(self, output_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1063: { // upsample_nearest1d_backward
          auto output_size = readIntArrayRef("output_size");
          auto input_size = readIntArrayRef("input_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 1);
              auto the_result = at::upsample_nearest1d_backward(grad_output, output_size, input_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1064: { // upsample_nearest2d
          auto output_size = readIntArrayRef("output_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::upsample_nearest2d(self, output_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1065: { // upsample_nearest2d_backward
          auto output_size = readIntArrayRef("output_size");
          auto input_size = readIntArrayRef("input_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 1);
              auto the_result = at::upsample_nearest2d_backward(grad_output, output_size, input_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1066: { // upsample_nearest3d
          auto output_size = readIntArrayRef("output_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::upsample_nearest3d(self, output_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1067: { // upsample_nearest3d_backward
          auto output_size = readIntArrayRef("output_size");
          auto input_size = readIntArrayRef("input_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 1);
              auto the_result = at::upsample_nearest3d_backward(grad_output, output_size, input_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1068: { // sigmoid_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto output = peek(1, 2);
              auto the_result = at::sigmoid_backward(grad_output, output);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1069: { // tanh_backward
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 2);
              auto output = peek(1, 2);
              auto the_result = at::tanh_backward(grad_output, output);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1070: { // slow_conv_transpose2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv_transpose2d(self, weight, kernel_size, bias, stride, padding, output_padding, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1071: { // slow_conv_transpose2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv_transpose2d(self, weight, kernel_size, bias, stride, padding, output_padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1072: { // slow_conv_transpose2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv_transpose2d(self, weight, kernel_size, bias, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1073: { // slow_conv_transpose2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv_transpose2d(self, weight, kernel_size, bias, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1074: { // slow_conv_transpose2d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv_transpose2d(self, weight, kernel_size, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1075: { // slow_conv_transpose2d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::slow_conv_transpose2d(self, weight, kernel_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1076: { // slow_conv_transpose2d_backward
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          auto dilation = readIntArrayRef("dilation");
          auto output_mask = readBoolMask<3>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 5);
              auto self = peek(1, 5);
              auto weight = peek(2, 5);
              auto columns = peek(3, 5);
              auto ones = peek(4, 5);
              auto the_result = at::slow_conv_transpose2d_backward(grad_output, self, weight, kernel_size, stride, padding, output_padding, dilation, columns, ones, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 1077: { // slow_conv_transpose3d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv_transpose3d(self, weight, kernel_size, bias, stride, padding, output_padding, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1078: { // slow_conv_transpose3d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv_transpose3d(self, weight, kernel_size, bias, stride, padding, output_padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1079: { // slow_conv_transpose3d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv_transpose3d(self, weight, kernel_size, bias, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1080: { // slow_conv_transpose3d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv_transpose3d(self, weight, kernel_size, bias, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1081: { // slow_conv_transpose3d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv_transpose3d(self, weight, kernel_size, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1082: { // slow_conv_transpose3d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::slow_conv_transpose3d(self, weight, kernel_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1083: { // slow_conv_transpose3d_backward
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto output_padding = readIntArrayRef("output_padding");
          auto dilation = readIntArrayRef("dilation");
          auto output_mask = readBoolMask<3>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 5);
              auto self = peek(1, 5);
              auto weight = peek(2, 5);
              auto finput = peek(3, 5);
              auto fgrad_input = peek(4, 5);
              auto the_result = at::slow_conv_transpose3d_backward(grad_output, self, weight, kernel_size, stride, padding, output_padding, dilation, finput, fgrad_input, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 1084: { // thnn_conv2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::thnn_conv2d(self, weight, kernel_size, bias, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1085: { // thnn_conv2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::thnn_conv2d(self, weight, kernel_size, bias, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1086: { // thnn_conv2d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::thnn_conv2d(self, weight, kernel_size, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1087: { // thnn_conv2d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::thnn_conv2d(self, weight, kernel_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1088: { // thnn_conv2d_forward
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::thnn_conv2d_forward(self, weight, kernel_size, bias, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 1089: { // thnn_conv2d_backward
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto output_mask = readBoolMask<3>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 5);
              auto self = peek(1, 5);
              auto weight = peek(2, 5);
              auto finput = peek(3, 5);
              auto fgrad_input = peek(4, 5);
              auto the_result = at::thnn_conv2d_backward(grad_output, self, weight, kernel_size, stride, padding, finput, fgrad_input, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 1090: { // thnn_conv_depthwise2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::thnn_conv_depthwise2d(self, weight, kernel_size, bias, stride, padding, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1091: { // thnn_conv_depthwise2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::thnn_conv_depthwise2d(self, weight, kernel_size, bias, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1092: { // thnn_conv_depthwise2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::thnn_conv_depthwise2d(self, weight, kernel_size, bias, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1093: { // thnn_conv_depthwise2d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::thnn_conv_depthwise2d(self, weight, kernel_size, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1094: { // thnn_conv_depthwise2d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::thnn_conv_depthwise2d(self, weight, kernel_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1095: { // thnn_conv_depthwise2d_forward
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::thnn_conv_depthwise2d_forward(self, weight, kernel_size, bias, stride, padding, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1096: { // thnn_conv_depthwise2d_backward
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          auto output_mask = readBoolMask<2>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::thnn_conv_depthwise2d_backward(grad_output, self, weight, kernel_size, stride, padding, dilation, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
              return true;
          };
      } break;
      case 1097: { // slow_conv3d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv3d(self, weight, kernel_size, bias, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1098: { // slow_conv3d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv3d(self, weight, kernel_size, bias, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1099: { // slow_conv3d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv3d(self, weight, kernel_size, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1100: { // slow_conv3d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::slow_conv3d(self, weight, kernel_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1101: { // slow_conv3d_forward
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv3d_forward(self, weight, kernel_size, bias, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 1102: { // slow_conv3d_backward
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto output_mask = readBoolMask<3>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 5);
              auto self = peek(1, 5);
              auto weight = peek(2, 5);
              auto finput = peek(3, 5);
              auto fgrad_input = peek(4, 5);
              auto the_result = at::slow_conv3d_backward(grad_output, self, weight, kernel_size, stride, padding, finput, fgrad_input, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 1103: { // slow_conv_dilated2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv_dilated2d(self, weight, kernel_size, bias, stride, padding, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1104: { // slow_conv_dilated2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv_dilated2d(self, weight, kernel_size, bias, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1105: { // slow_conv_dilated2d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv_dilated2d(self, weight, kernel_size, bias, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1106: { // slow_conv_dilated2d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv_dilated2d(self, weight, kernel_size, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1107: { // slow_conv_dilated2d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::slow_conv_dilated2d(self, weight, kernel_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1108: { // slow_conv_dilated2d_backward
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          auto output_mask = readBoolMask<3>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::slow_conv_dilated2d_backward(grad_output, self, weight, kernel_size, stride, padding, dilation, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 1109: { // slow_conv_dilated3d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv_dilated3d(self, weight, kernel_size, bias, stride, padding, dilation);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1110: { // slow_conv_dilated3d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv_dilated3d(self, weight, kernel_size, bias, stride, padding);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1111: { // slow_conv_dilated3d
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv_dilated3d(self, weight, kernel_size, bias, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1112: { // slow_conv_dilated3d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 3);
              auto weight = peek(1, 3);
              auto bias = peek(2, 3);
              auto the_result = at::slow_conv_dilated3d(self, weight, kernel_size, bias);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1113: { // slow_conv_dilated3d
          auto kernel_size = readIntArrayRef("kernel_size");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto weight = peek(1, 2);
              auto the_result = at::slow_conv_dilated3d(self, weight, kernel_size);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1114: { // slow_conv_dilated3d_backward
          auto kernel_size = readIntArrayRef("kernel_size");
          auto stride = readIntArrayRef("stride");
          auto padding = readIntArrayRef("padding");
          auto dilation = readIntArrayRef("dilation");
          auto output_mask = readBoolMask<3>("output_mask");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 3);
              auto self = peek(1, 3);
              auto weight = peek(2, 3);
              auto the_result = at::slow_conv_dilated3d_backward(grad_output, self, weight, kernel_size, stride, padding, dilation, output_mask);
                if(OutputSize() > 0) {assignTo(Output(0),std::get<0>(the_result));}
                if(OutputSize() > 1) {assignTo(Output(1),std::get<1>(the_result));}
                if(OutputSize() > 2) {assignTo(Output(2),std::get<2>(the_result));}
              return true;
          };
      } break;
      case 1115: { // col2im
          auto output_size = readIntArrayRef("output_size");
          auto kernel_size = readIntArrayRef("kernel_size");
          auto dilation = readIntArrayRef("dilation");
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::col2im(self, output_size, kernel_size, dilation, padding, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1116: { // col2im_backward
          auto kernel_size = readIntArrayRef("kernel_size");
          auto dilation = readIntArrayRef("dilation");
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 1);
              auto the_result = at::col2im_backward(grad_output, kernel_size, dilation, padding, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1117: { // im2col
          auto kernel_size = readIntArrayRef("kernel_size");
          auto dilation = readIntArrayRef("dilation");
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::im2col(self, kernel_size, dilation, padding, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1118: { // im2col_backward
          auto input_size = readIntArrayRef("input_size");
          auto kernel_size = readIntArrayRef("kernel_size");
          auto dilation = readIntArrayRef("dilation");
          auto padding = readIntArrayRef("padding");
          auto stride = readIntArrayRef("stride");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto grad_output = peek(0, 1);
              auto the_result = at::im2col_backward(grad_output, input_size, kernel_size, dilation, padding, stride);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1119: { // isfinite
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::isfinite(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1120: { // isinf
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 1);
              auto the_result = at::isinf(self);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1121: { // _test_serialization_subcmul
          at::Scalar alpha = readScalarAttribute("alpha");
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::_test_serialization_subcmul(self, other, alpha);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      case 1122: { // _test_serialization_subcmul
      
          run_op = [=] {
              at::AutoNonVariableTypeMode guard;
              auto self = peek(0, 2);
              auto other = peek(1, 2);
              auto the_result = at::_test_serialization_subcmul(self, other);
                if(OutputSize() > 0) {assignTo(Output(0),the_result);}
              return true;
          };
      } break;
      default:
        CAFFE_THROW("Unexpected key value for aten operator");
    }
  }
  USE_OPERATOR_CONTEXT_FUNCTIONS;

  bool RunOnDevice() override {
    return run_op();
  }
private:
  // actual operator implementation is initialized in ctor.
  std::function<bool()> run_op;
  at::Backend backend() const;

  TypeMeta typeMetaFor(const at::Tensor & t) {
    return typeMetaFor(t.scalar_type());
  }
  TypeMeta typeMetaFor(at::ScalarType st) {
    #define DEFINE_CASE(ctype,aten_name) \
      case at::k##aten_name: \
        return TypeMeta::Make<ctype>();
    switch(st) {
      AT_FORALL_SCALAR_TYPES_AND3(Bool, Half, BFloat16, DEFINE_CASE)
    default:
      CAFFE_THROW("Unknown ATen Type");
    }
    #undef DEFINE_CASE
  }

  at::TensorOptions optionsFor(const Tensor& ten) {
    at::Device device = ten.GetDevice();
#ifdef __HIP_PLATFORM_HCC__
    if (backend() == at::Backend::HIP) {
      device = at::Device(kCUDA, device.index());
    }
#endif
    return at::TensorOptions(device).dtype(ten.dtype());
  }

  at::Tensor tensorWrapping(const Tensor& ten_) {
    auto& ten = const_cast<Tensor&>(ten_);
    return at::from_blob(
        ten.raw_mutable_data(),
        ten.sizes(),
        optionsFor(ten));
  }

  at::Tensor peek(size_t i, size_t N) {
    auto real_idx = InputSize() - N + i;
    return tensorWrapping(Input(real_idx));
  }

  std::vector<at::Tensor> peekSlice(size_t i, size_t len, size_t N) {
    std::vector<at::Tensor> results;
    for (size_t ii = i; ii < i + len; ++ii) {
      results.push_back(peek(ii, N));
    }
    return results;
  }

  void assignTo(Tensor* dst, const at::Tensor& src_) {
    at::Tensor src = src_.contiguous();
    auto at_sizes = src.sizes();
    caffe2::TypeMeta type_meta = typeMetaFor(src);
    at::Device device = src.device();
#ifdef __HIP_PLATFORM_HCC__
    if (device.type() == at::DeviceType::CUDA) {
      device = at::Device(at::DeviceType::HIP, device.index());
    }
#endif
    at::TensorImpl* src_impl = src.unsafeReleaseTensorImpl();
    std::vector<int64_t> dims(at_sizes.begin(), at_sizes.end());
    dst->Resize(dims);
    dst->ShareExternalPointer(
        at::DataPtr(
            src_impl->data(),
            static_cast<void*>(src_impl),
            [](void* t_ptr) -> void {
              at::TensorImpl* local_impl = static_cast<at::TensorImpl*>(t_ptr);
              c10::raw::intrusive_ptr::decref(local_impl);
            },
            device),
        type_meta,
        0);
  }
  void assignListStartingAt(
      size_t offset,
      const std::vector<at::Tensor>& tensors) {
    for (size_t i = 0; i < tensors.size(); i++) {
      assignTo(Output(offset + i), tensors[i]);
    }
  }

  template<typename T,
          typename std::enable_if<std::numeric_limits<T>::is_integer, bool>::type* =
              nullptr>
  int64_t extract(const at::Scalar &s) {
    return s.toLong();
  }

  template<typename T,
          typename std::enable_if<!std::numeric_limits<T>::is_integer, bool>::type* =
              nullptr>
  int64_t extract(const at::Scalar &s) {
    return s.toDouble();
  }

  void assignTo(Tensor* dst, at::ScalarType scalar_type, at::Scalar scalar) {
    switch(scalar_type) {
      #define DEFINE_CASE(ctype,aten_name) \
        case at::k##aten_name: { \
          auto value = extract<ctype>(scalar); \
          assignToValue<ctype>(dst, at::convert<ctype,decltype(value)>(value)); \
        } break;
      AT_FORALL_SCALAR_TYPES_AND3(Bool, Half, BFloat16, DEFINE_CASE)
#undef DEFINE_CASE
      default:
        CAFFE_THROW("Unknown ATen Type");
    }
  }
  template <typename T>
  void assignToValue(Tensor* dst, T v) {
    dst->Resize(std::vector<int64_t>());
    math::Set(1, v, dst->template mutable_data<T>(), &context_);
  }
  int findImplementation(const OperatorDef& operator_def) {
    CAFFE_ENFORCE(HasArgument("operator"));
    std::string op = OperatorBase::GetSingleArgument<std::string>("operator", "");
    // construct descriptor string ([DESCRIPTORS]) given the attributes
    // and inputs of this operator_def, and look up the implementation key
    // for this variant
    std::stringstream descriptor;
    descriptor << op;
    std::vector<std::string> attrs;
    for(size_t i = 0; i < operator_def.arg_size(); i++) {
      auto & attr = operator_def.arg(i);
      if(attr.name() == "operator" || attr.name() == "type" )
        continue;
      attrs.push_back(attr.name());
    }
    std::sort(attrs.begin(), attrs.end());
    for(auto & a : attrs)
      descriptor << "-" << a;

    std::string descriptor_sized =
        descriptor.str() + "-" + c10::to_string(InputSize());
    std::string descriptor_var_args = descriptor.str() + "-*";
    if (op_to_key.count(descriptor_sized) > 0) {
      return op_to_key[descriptor_sized];
    }
    if (op_to_key.count(descriptor_var_args) > 0) {
      return op_to_key[descriptor_var_args];
    }
    std::stringstream ss;
    ss << "Attempting to run unknown ATen operator configuration: "
       << descriptor_sized;
    CAFFE_THROW(ss.str());
  }
  at::Scalar readScalarAttribute(const std::string & name) {
    if(OperatorBase::HasSingleArgumentOfType<int64_t>(name)) {
      return OperatorBase::GetSingleArgument<int64_t>(name, 0);
    } else {
      CAFFE_ENFORCE(OperatorBase::HasSingleArgumentOfType<float>(name));
      return OperatorBase::GetSingleArgument<float>(name, 0);
    }
  }
  template<typename T>
  T readAttribute(const std::string & name) {
    CAFFE_ENFORCE(OperatorBase::HasSingleArgumentOfType<T>(name));
    return OperatorBase::GetSingleArgument<T>(name, 0);
  }
  std::vector<int64_t> readIntArrayRef(const std::string & name) {
    CAFFE_ENFORCE(OperatorBase::HasArgument(name));
    return OperatorBase::GetRepeatedArgument<int64_t>(name, {});
  }
  template <int N>
  std::array<bool, N> readBoolMask(const std::string& name) {
    CAFFE_ENFORCE(OperatorBase::HasArgument(name));
    std::vector<int64_t> ints =
        OperatorBase::GetRepeatedArgument<int64_t>(name, {});
    std::array<bool, N> result;
    for (size_t i = 0; i < N; ++i) {
      result[i] = ints.at(i);
    }
    return result;
  }
};

}
